@@ -1,11 +1,11 @@
 /* valaccodebreakstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEBREAKSTATEMENT_H__
-#define __VALACCODEBREAKSTATEMENT_H__
+#ifndef __CCODE_VALACCODEBREAKSTATEMENT_H__
+#define __CCODE_VALACCODEBREAKSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -53,6 +53,7 @@ struct _ValaCCodeBreakStatementClass {
 	ValaCCodeStatementClass parent;
 };
 
+ValaCCodeBreakStatement* vala_ccode_break_statement_new (void);
 GType vala_ccode_break_statement_get_type (void);
 
 G_END_DECLS
