@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODECASTEXPRESSION_H__
-#define __VALACCODECASTEXPRESSION_H__
+#ifndef __CCODE_VALACCODECASTEXPRESSION_H__
+#define __CCODE_VALACCODECASTEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -60,7 +60,7 @@ ValaCCodeExpression* vala_ccode_cast_expression_get_inner (ValaCCodeCastExpressi
 void vala_ccode_cast_expression_set_inner (ValaCCodeCastExpression* self, ValaCCodeExpression* value);
 char* vala_ccode_cast_expression_get_type_name (ValaCCodeCastExpression* self);
 void vala_ccode_cast_expression_set_type_name (ValaCCodeCastExpression* self, const char* value);
-GType vala_ccode_cast_expression_get_type ();
+GType vala_ccode_cast_expression_get_type (void);
 
 G_END_DECLS
 
