@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEENUM_H__
-#define __VALACCODEENUM_H__
+#ifndef __CCODE_VALACCODEENUM_H__
+#define __CCODE_VALACCODEENUM_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -55,11 +55,11 @@ struct _ValaCCodeEnumClass {
 	ValaCCodeNodeClass parent;
 };
 
-ValaCCodeEnum* vala_ccode_enum_new (const char* n);
+ValaCCodeEnum* vala_ccode_enum_new (const char* name);
 void vala_ccode_enum_add_value (ValaCCodeEnum* self, const char* name, const char* value);
 char* vala_ccode_enum_get_name (ValaCCodeEnum* self);
 void vala_ccode_enum_set_name (ValaCCodeEnum* self, const char* value);
-GType vala_ccode_enum_get_type ();
+GType vala_ccode_enum_get_type (void);
 
 G_END_DECLS
 
