@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,51 +19,25 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
-#include "valaccodeexpression.h"
+#include <ccode/valaccodeexpression.h>
 
-struct _ValaCCodeExpressionPrivate {
-};
-#define VALA_CCODE_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_EXPRESSION, ValaCCodeExpressionPrivate))
 enum  {
-	VALA_CCODE_EXPRESSION_DUMMY_PROPERTY,
+	VALA_CCODE_EXPRESSION_DUMMY_PROPERTY
 };
 static gpointer vala_ccode_expression_parent_class = NULL;
 
 
-static void vala_ccode_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
-	ValaCCodeExpression * self = VALA_CCODE_EXPRESSION (object);
-	switch (property_id) {
-	}
-}
-
-
-static void vala_ccode_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
-	ValaCCodeExpression * self = VALA_CCODE_EXPRESSION (object);
-	switch (property_id) {
-	}
-}
-
-
-static void vala_ccode_expression_class_init (ValaCCodeExpressionClass * klass)
-{
+static void vala_ccode_expression_class_init (ValaCCodeExpressionClass * klass) {
 	vala_ccode_expression_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_expression_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_expression_set_property;
 }
 
 
-static void vala_ccode_expression_init (ValaCCodeExpression * self)
-{
+static void vala_ccode_expression_init (ValaCCodeExpression * self) {
 }
 
 
-GType vala_ccode_expression_get_type ()
-{
+GType vala_ccode_expression_get_type (void) {
 	static GType vala_ccode_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpression), 0, (GInstanceInitFunc) vala_ccode_expression_init };
