@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,12 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEFRAGMENT_H__
-#define __VALACCODEFRAGMENT_H__
-typedef struct _ValaCCodeFragment ValaCCodeFragment;
-typedef struct _ValaCCodeFragmentClass ValaCCodeFragmentClass;
-typedef struct _ValaCCodeFragmentPrivate ValaCCodeFragmentPrivate;
+#ifndef __CCODE_VALACCODEFRAGMENT_H__
+#define __CCODE_VALACCODEFRAGMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collection.h>
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodewriter.h>
 
@@ -41,6 +39,9 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_FRAGMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_FRAGMENT))
 #define VALA_CCODE_FRAGMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_FRAGMENT, ValaCCodeFragmentClass))
 
+typedef struct _ValaCCodeFragment ValaCCodeFragment;
+typedef struct _ValaCCodeFragmentClass ValaCCodeFragmentClass;
+typedef struct _ValaCCodeFragmentPrivate ValaCCodeFragmentPrivate;
 
 /**
  * Represents a container for C code nodes.
@@ -54,8 +55,9 @@ struct _ValaCCodeFragmentClass {
 };
 
 void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node);
-GList* vala_ccode_fragment_get_children (ValaCCodeFragment* self);
-GType vala_ccode_fragment_get_type ();
+GeeCollection* vala_ccode_fragment_get_children (ValaCCodeFragment* self);
+ValaCCodeFragment* vala_ccode_fragment_new (void);
+GType vala_ccode_fragment_get_type (void);
 
 G_END_DECLS
 
