@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,13 +20,12 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodefunctioncall.h"
+#include <ccode/valaccodefunctioncall.h>
 #include <gee/arraylist.h>
 #include <gee/collection.h>
 #include <gee/readonlylist.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodefunctioncall.h>
 #include <ccode/valaccodenode.h>
 
 struct _ValaCCodeFunctionCallPrivate {
@@ -43,8 +42,7 @@ static gpointer vala_ccode_function_call_parent_class = NULL;
 static void vala_ccode_function_call_dispose (GObject * obj);
 
 
-ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call)
-{
+ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call) {
 	ValaCCodeFunctionCall * self;
 	g_return_val_if_fail (call == NULL || VALA_IS_CCODE_EXPRESSION (call), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_CALL, 0, NULL);
@@ -58,8 +56,7 @@ ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call)
  *
  * @param expr a C code expression
  */
-void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCodeExpression* expr)
-{
+void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self));
 	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->arguments), expr);
@@ -71,18 +68,16 @@ void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCo
  *
  * @return list of arguments
  */
-GeeList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self)
-{
+GeeList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self), NULL);
 	return GEE_LIST (gee_read_only_list_new (g_object_ref, g_object_unref, self->priv->arguments));
 }
 
 
-static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFunctionCall * self;
 	gboolean first;
-	self = ((ValaCCodeFunctionCall*) base);
+	self = VALA_CCODE_FUNCTION_CALL (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_function_call_get_call (self)), writer);
 	vala_ccode_writer_write_string (writer, " (");
@@ -113,15 +108,13 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 }
 
 
-ValaCCodeExpression* vala_ccode_function_call_get_call (ValaCCodeFunctionCall* self)
-{
+ValaCCodeExpression* vala_ccode_function_call_get_call (ValaCCodeFunctionCall* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self), NULL);
 	return self->priv->_call;
 }
 
 
-void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value)
-{
+void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value) {
 	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self));
@@ -131,8 +124,7 @@ void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeEx
 }
 
 
-static void vala_ccode_function_call_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_function_call_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeFunctionCall * self;
 	self = VALA_CCODE_FUNCTION_CALL (object);
 	switch (property_id) {
@@ -146,8 +138,7 @@ static void vala_ccode_function_call_get_property (GObject * object, guint prope
 }
 
 
-static void vala_ccode_function_call_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_function_call_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeFunctionCall * self;
 	self = VALA_CCODE_FUNCTION_CALL (object);
 	switch (property_id) {
@@ -161,41 +152,33 @@ static void vala_ccode_function_call_set_property (GObject * object, guint prope
 }
 
 
-static void vala_ccode_function_call_class_init (ValaCCodeFunctionCallClass * klass)
-{
+static void vala_ccode_function_call_class_init (ValaCCodeFunctionCallClass * klass) {
 	vala_ccode_function_call_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeFunctionCallPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_function_call_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_function_call_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_function_call_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_function_call_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_CALL_CALL, g_param_spec_object ("call", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_CALL_CALL, g_param_spec_object ("call", "call", "call", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_function_call_init (ValaCCodeFunctionCall * self)
-{
+static void vala_ccode_function_call_init (ValaCCodeFunctionCall * self) {
 	self->priv = VALA_CCODE_FUNCTION_CALL_GET_PRIVATE (self);
 	self->priv->arguments = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_function_call_dispose (GObject * obj)
-{
+static void vala_ccode_function_call_dispose (GObject * obj) {
 	ValaCCodeFunctionCall * self;
-	ValaCCodeFunctionCallClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_FUNCTION_CALL (obj);
 	(self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL)));
 	(self->priv->arguments == NULL ? NULL : (self->priv->arguments = (g_object_unref (self->priv->arguments), NULL)));
-	klass = VALA_CCODE_FUNCTION_CALL_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FUNCTION_CALL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_function_call_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_function_call_get_type (void)
-{
+GType vala_ccode_function_call_get_type (void) {
 	static GType vala_ccode_function_call_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_function_call_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionCallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_call_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionCall), 0, (GInstanceInitFunc) vala_ccode_function_call_init };
