@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodefunctiondeclarator.h"
+#include <ccode/valaccodefunctiondeclarator.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/collection.h>
-#include <ccode/valaccodefunctiondeclarator.h>
 
 struct _ValaCCodeFunctionDeclaratorPrivate {
 	char* _name;
@@ -41,8 +40,7 @@ static gpointer vala_ccode_function_declarator_parent_class = NULL;
 static void vala_ccode_function_declarator_dispose (GObject * obj);
 
 
-ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_new (const char* name)
-{
+ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_new (const char* name) {
 	ValaCCodeFunctionDeclarator * self;
 	g_return_val_if_fail (name != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_DECLARATOR, 0, NULL);
@@ -56,28 +54,25 @@ ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_new (const char* nam
  *
  * @param param a formal parameter
  */
-void vala_ccode_function_declarator_add_parameter (ValaCCodeFunctionDeclarator* self, ValaCCodeFormalParameter* param)
-{
+void vala_ccode_function_declarator_add_parameter (ValaCCodeFunctionDeclarator* self, ValaCCodeFormalParameter* param) {
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_DECLARATOR (self));
 	g_return_if_fail (VALA_IS_CCODE_FORMAL_PARAMETER (param));
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
 }
 
 
-static void vala_ccode_function_declarator_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_function_declarator_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFunctionDeclarator * self;
-	self = ((ValaCCodeFunctionDeclarator*) base);
+	self = VALA_CCODE_FUNCTION_DECLARATOR (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_node_write_declaration (VALA_CCODE_NODE (self), writer);
 }
 
 
-static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFunctionDeclarator * self;
 	gboolean first;
-	self = ((ValaCCodeFunctionDeclarator*) base);
+	self = VALA_CCODE_FUNCTION_DECLARATOR (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(*");
 	vala_ccode_writer_write_string (writer, vala_ccode_function_declarator_get_name (self));
@@ -107,15 +102,13 @@ static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode
 }
 
 
-char* vala_ccode_function_declarator_get_name (ValaCCodeFunctionDeclarator* self)
-{
+char* vala_ccode_function_declarator_get_name (ValaCCodeFunctionDeclarator* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION_DECLARATOR (self), NULL);
 	return self->priv->_name;
 }
 
 
-void vala_ccode_function_declarator_set_name (ValaCCodeFunctionDeclarator* self, const char* value)
-{
+void vala_ccode_function_declarator_set_name (ValaCCodeFunctionDeclarator* self, const char* value) {
 	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_DECLARATOR (self));
 	_tmp1 = NULL;
@@ -123,8 +116,7 @@ void vala_ccode_function_declarator_set_name (ValaCCodeFunctionDeclarator* self,
 }
 
 
-static void vala_ccode_function_declarator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_function_declarator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeFunctionDeclarator * self;
 	self = VALA_CCODE_FUNCTION_DECLARATOR (object);
 	switch (property_id) {
@@ -138,8 +130,7 @@ static void vala_ccode_function_declarator_get_property (GObject * object, guint
 }
 
 
-static void vala_ccode_function_declarator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_function_declarator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeFunctionDeclarator * self;
 	self = VALA_CCODE_FUNCTION_DECLARATOR (object);
 	switch (property_id) {
@@ -153,8 +144,7 @@ static void vala_ccode_function_declarator_set_property (GObject * object, guint
 }
 
 
-static void vala_ccode_function_declarator_class_init (ValaCCodeFunctionDeclaratorClass * klass)
-{
+static void vala_ccode_function_declarator_class_init (ValaCCodeFunctionDeclaratorClass * klass) {
 	vala_ccode_function_declarator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeFunctionDeclaratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_function_declarator_get_property;
@@ -162,33 +152,26 @@ static void vala_ccode_function_declarator_class_init (ValaCCodeFunctionDeclarat
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_function_declarator_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_function_declarator_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_function_declarator_real_write_declaration;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_DECLARATOR_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_DECLARATOR_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_function_declarator_init (ValaCCodeFunctionDeclarator * self)
-{
+static void vala_ccode_function_declarator_init (ValaCCodeFunctionDeclarator * self) {
 	self->priv = VALA_CCODE_FUNCTION_DECLARATOR_GET_PRIVATE (self);
 	self->priv->parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_function_declarator_dispose (GObject * obj)
-{
+static void vala_ccode_function_declarator_dispose (GObject * obj) {
 	ValaCCodeFunctionDeclarator * self;
-	ValaCCodeFunctionDeclaratorClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_FUNCTION_DECLARATOR (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	klass = VALA_CCODE_FUNCTION_DECLARATOR_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FUNCTION_DECLARATOR));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_function_declarator_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_function_declarator_get_type (void)
-{
+GType vala_ccode_function_declarator_get_type (void) {
 	static GType vala_ccode_function_declarator_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_function_declarator_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionDeclaratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_declarator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionDeclarator), 0, (GInstanceInitFunc) vala_ccode_function_declarator_init };
