@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodelabel.h"
 #include <ccode/valaccodelabel.h>
+#include <ccode/valaccodelinedirective.h>
 
 struct _ValaCCodeLabelPrivate {
 	char* _name;
@@ -36,8 +36,7 @@ static gpointer vala_ccode_label_parent_class = NULL;
 static void vala_ccode_label_dispose (GObject * obj);
 
 
-ValaCCodeLabel* vala_ccode_label_new (const char* name)
-{
+ValaCCodeLabel* vala_ccode_label_new (const char* name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeLabel * self;
@@ -55,27 +54,24 @@ ValaCCodeLabel* vala_ccode_label_new (const char* name)
 }
 
 
-static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeLabel * self;
-	self = ((ValaCCodeLabel*) base);
+	self = VALA_CCODE_LABEL (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_indent (writer);
+	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, vala_ccode_label_get_name (self));
 	vala_ccode_writer_write_string (writer, ":");
 	vala_ccode_writer_write_newline (writer);
 }
 
 
-char* vala_ccode_label_get_name (ValaCCodeLabel* self)
-{
+char* vala_ccode_label_get_name (ValaCCodeLabel* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_LABEL (self), NULL);
 	return self->priv->_name;
 }
 
 
-void vala_ccode_label_set_name (ValaCCodeLabel* self, const char* value)
-{
+void vala_ccode_label_set_name (ValaCCodeLabel* self, const char* value) {
 	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_LABEL (self));
 	_tmp1 = NULL;
@@ -83,8 +79,7 @@ void vala_ccode_label_set_name (ValaCCodeLabel* self, const char* value)
 }
 
 
-static void vala_ccode_label_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_label_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeLabel * self;
 	self = VALA_CCODE_LABEL (object);
 	switch (property_id) {
@@ -98,8 +93,7 @@ static void vala_ccode_label_get_property (GObject * object, guint property_id,
 }
 
 
-static void vala_ccode_label_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_label_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeLabel * self;
 	self = VALA_CCODE_LABEL (object);
 	switch (property_id) {
@@ -113,39 +107,31 @@ static void vala_ccode_label_set_property (GObject * object, guint property_id,
 }
 
 
-static void vala_ccode_label_class_init (ValaCCodeLabelClass * klass)
-{
+static void vala_ccode_label_class_init (ValaCCodeLabelClass * klass) {
 	vala_ccode_label_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeLabelPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_label_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_label_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_label_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_label_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_LABEL_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_LABEL_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_label_init (ValaCCodeLabel * self)
-{
+static void vala_ccode_label_init (ValaCCodeLabel * self) {
 	self->priv = VALA_CCODE_LABEL_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_label_dispose (GObject * obj)
-{
+static void vala_ccode_label_dispose (GObject * obj) {
 	ValaCCodeLabel * self;
-	ValaCCodeLabelClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_LABEL (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	klass = VALA_CCODE_LABEL_CLASS (g_type_class_peek (VALA_TYPE_CCODE_LABEL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_label_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_label_get_type (void)
-{
+GType vala_ccode_label_get_type (void) {
 	static GType vala_ccode_label_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_label_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLabel), 0, (GInstanceInitFunc) vala_ccode_label_init };
