@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodemacroreplacement.h"
 #include <ccode/valaccodemacroreplacement.h>
+#include <ccode/valaccodelinedirective.h>
 
 struct _ValaCCodeMacroReplacementPrivate {
 	char* _name;
@@ -38,8 +38,7 @@ static gpointer vala_ccode_macro_replacement_parent_class = NULL;
 static void vala_ccode_macro_replacement_dispose (GObject * obj);
 
 
-ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* n, const char* replace)
-{
+ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* n, const char* replace) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMacroReplacement * self;
@@ -59,12 +58,11 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* n, cons
 }
 
 
-static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeMacroReplacement * self;
-	self = ((ValaCCodeMacroReplacement*) base);
+	self = VALA_CCODE_MACRO_REPLACEMENT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_indent (writer);
+	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#define ");
 	vala_ccode_writer_write_string (writer, vala_ccode_macro_replacement_get_name (self));
 	vala_ccode_writer_write_string (writer, " ");
@@ -73,15 +71,13 @@ static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCC
 }
 
 
-char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self)
-{
+char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self), NULL);
 	return self->priv->_name;
 }
 
 
-void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, const char* value)
-{
+void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, const char* value) {
 	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self));
 	_tmp1 = NULL;
@@ -89,15 +85,13 @@ void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, con
 }
 
 
-char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* self)
-{
+char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self), NULL);
 	return self->priv->_replacement;
 }
 
 
-void vala_ccode_macro_replacement_set_replacement (ValaCCodeMacroReplacement* self, const char* value)
-{
+void vala_ccode_macro_replacement_set_replacement (ValaCCodeMacroReplacement* self, const char* value) {
 	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self));
 	_tmp1 = NULL;
@@ -105,8 +99,7 @@ void vala_ccode_macro_replacement_set_replacement (ValaCCodeMacroReplacement* se
 }
 
 
-static void vala_ccode_macro_replacement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_macro_replacement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeMacroReplacement * self;
 	self = VALA_CCODE_MACRO_REPLACEMENT (object);
 	switch (property_id) {
@@ -123,8 +116,7 @@ static void vala_ccode_macro_replacement_get_property (GObject * object, guint p
 }
 
 
-static void vala_ccode_macro_replacement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_macro_replacement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeMacroReplacement * self;
 	self = VALA_CCODE_MACRO_REPLACEMENT (object);
 	switch (property_id) {
@@ -141,41 +133,33 @@ static void vala_ccode_macro_replacement_set_property (GObject * object, guint p
 }
 
 
-static void vala_ccode_macro_replacement_class_init (ValaCCodeMacroReplacementClass * klass)
-{
+static void vala_ccode_macro_replacement_class_init (ValaCCodeMacroReplacementClass * klass) {
 	vala_ccode_macro_replacement_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeMacroReplacementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_macro_replacement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_macro_replacement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_macro_replacement_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_macro_replacement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MACRO_REPLACEMENT_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT, g_param_spec_string ("replacement", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MACRO_REPLACEMENT_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT, g_param_spec_string ("replacement", "replacement", "replacement", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_macro_replacement_init (ValaCCodeMacroReplacement * self)
-{
+static void vala_ccode_macro_replacement_init (ValaCCodeMacroReplacement * self) {
 	self->priv = VALA_CCODE_MACRO_REPLACEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_macro_replacement_dispose (GObject * obj)
-{
+static void vala_ccode_macro_replacement_dispose (GObject * obj) {
 	ValaCCodeMacroReplacement * self;
-	ValaCCodeMacroReplacementClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_MACRO_REPLACEMENT (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_replacement = (g_free (self->priv->_replacement), NULL));
-	klass = VALA_CCODE_MACRO_REPLACEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_MACRO_REPLACEMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_macro_replacement_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_macro_replacement_get_type (void)
-{
+GType vala_ccode_macro_replacement_get_type (void) {
 	static GType vala_ccode_macro_replacement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_macro_replacement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMacroReplacementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_macro_replacement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMacroReplacement), 0, (GInstanceInitFunc) vala_ccode_macro_replacement_init };
