@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodenewline.h"
+#include <ccode/valaccodenewline.h>
 
 enum  {
 	VALA_CCODE_NEWLINE_DUMMY_PROPERTY
@@ -29,29 +29,35 @@ static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter*
 static gpointer vala_ccode_newline_parent_class = NULL;
 
 
-static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeNewline * self;
-	self = ((ValaCCodeNewline*) base);
+	self = VALA_CCODE_NEWLINE (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_newline (writer);
 }
 
 
-static void vala_ccode_newline_class_init (ValaCCodeNewlineClass * klass)
-{
+/**
+ * Represents a line break in the C code.
+ */
+ValaCCodeNewline* vala_ccode_newline_new (void) {
+	ValaCCodeNewline * self;
+	self = g_object_newv (VALA_TYPE_CCODE_NEWLINE, 0, NULL);
+	return self;
+}
+
+
+static void vala_ccode_newline_class_init (ValaCCodeNewlineClass * klass) {
 	vala_ccode_newline_parent_class = g_type_class_peek_parent (klass);
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_newline_real_write;
 }
 
 
-static void vala_ccode_newline_init (ValaCCodeNewline * self)
-{
+static void vala_ccode_newline_init (ValaCCodeNewline * self) {
 }
 
 
-GType vala_ccode_newline_get_type (void)
-{
+GType vala_ccode_newline_get_type (void) {
 	static GType vala_ccode_newline_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_newline_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeNewlineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_newline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeNewline), 0, (GInstanceInitFunc) vala_ccode_newline_init };
