@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodeparenthesizedexpression.h"
+#include <ccode/valaccodeparenthesizedexpression.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodeparenthesizedexpression.h>
 #include <ccode/valaccodenode.h>
 
 struct _ValaCCodeParenthesizedExpressionPrivate {
@@ -39,8 +38,7 @@ static gpointer vala_ccode_parenthesized_expression_parent_class = NULL;
 static void vala_ccode_parenthesized_expression_dispose (GObject * obj);
 
 
-ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr)
-{
+ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeParenthesizedExpression * self;
@@ -58,10 +56,9 @@ ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaC
 }
 
 
-static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeParenthesizedExpression * self;
-	self = ((ValaCCodeParenthesizedExpression*) base);
+	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(");
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_parenthesized_expression_get_inner (self)), writer);
@@ -69,15 +66,13 @@ static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base,
 }
 
 
-ValaCCodeExpression* vala_ccode_parenthesized_expression_get_inner (ValaCCodeParenthesizedExpression* self)
-{
+ValaCCodeExpression* vala_ccode_parenthesized_expression_get_inner (ValaCCodeParenthesizedExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (self), NULL);
 	return self->priv->_inner;
 }
 
 
-void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpression* self, ValaCCodeExpression* value)
-{
+void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpression* self, ValaCCodeExpression* value) {
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (self));
 	_tmp1 = NULL;
@@ -85,8 +80,7 @@ void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpres
 }
 
 
-static void vala_ccode_parenthesized_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_parenthesized_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeParenthesizedExpression * self;
 	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (object);
 	switch (property_id) {
@@ -100,8 +94,7 @@ static void vala_ccode_parenthesized_expression_get_property (GObject * object,
 }
 
 
-static void vala_ccode_parenthesized_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_parenthesized_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeParenthesizedExpression * self;
 	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (object);
 	switch (property_id) {
@@ -115,39 +108,31 @@ static void vala_ccode_parenthesized_expression_set_property (GObject * object,
 }
 
 
-static void vala_ccode_parenthesized_expression_class_init (ValaCCodeParenthesizedExpressionClass * klass)
-{
+static void vala_ccode_parenthesized_expression_class_init (ValaCCodeParenthesizedExpressionClass * klass) {
 	vala_ccode_parenthesized_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeParenthesizedExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_parenthesized_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_parenthesized_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_parenthesized_expression_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_parenthesized_expression_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_parenthesized_expression_init (ValaCCodeParenthesizedExpression * self)
-{
+static void vala_ccode_parenthesized_expression_init (ValaCCodeParenthesizedExpression * self) {
 	self->priv = VALA_CCODE_PARENTHESIZED_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_parenthesized_expression_dispose (GObject * obj)
-{
+static void vala_ccode_parenthesized_expression_dispose (GObject * obj) {
 	ValaCCodeParenthesizedExpression * self;
-	ValaCCodeParenthesizedExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	klass = VALA_CCODE_PARENTHESIZED_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_PARENTHESIZED_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_parenthesized_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_parenthesized_expression_get_type (void)
-{
+GType vala_ccode_parenthesized_expression_get_type (void) {
 	static GType vala_ccode_parenthesized_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_parenthesized_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeParenthesizedExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_parenthesized_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeParenthesizedExpression), 0, (GInstanceInitFunc) vala_ccode_parenthesized_expression_init };
