@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,13 +20,12 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEUNARYEXPRESSION_H__
-#define __VALACCODEUNARYEXPRESSION_H__
+#ifndef __CCODE_VALACCODEUNARYEXPRESSION_H__
+#define __CCODE_VALACCODEUNARYEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <ccode/valaccodeexpression.h>
-#include <ccode/valaccodeunaryexpression.h>
 #include <ccode/valaccodewriter.h>
 
 G_BEGIN_DECLS
@@ -71,7 +70,7 @@ ValaCCodeUnaryOperator vala_ccode_unary_expression_get_operator (ValaCCodeUnaryE
 void vala_ccode_unary_expression_set_operator (ValaCCodeUnaryExpression* self, ValaCCodeUnaryOperator value);
 ValaCCodeExpression* vala_ccode_unary_expression_get_inner (ValaCCodeUnaryExpression* self);
 void vala_ccode_unary_expression_set_inner (ValaCCodeUnaryExpression* self, ValaCCodeExpression* value);
-GType vala_ccode_unary_expression_get_type ();
+GType vala_ccode_unary_expression_get_type (void);
 
 G_END_DECLS
 
