@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,54 +20,74 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "collection.h"
+#include <gee/collection.h>
 
 
 
-gboolean gee_collection_contains (GeeCollection* self, gpointer item)
-{
+/**
+ * Determines whether this collection contains the specified item.
+ *
+ * @param item the item to locate in the collection
+ *
+ * @return     true if item is found, false otherwise
+ */
+gboolean gee_collection_contains (GeeCollection* self, gpointer item) {
 	return GEE_COLLECTION_GET_INTERFACE (self)->contains (self, item);
 }
 
 
-gboolean gee_collection_add (GeeCollection* self, gpointer item)
-{
+/**
+ * Adds an item to this collection. Must not be called on read-only
+ * collections.
+ *
+ * @param item the item to add to the collection
+ *
+ * @return     true if the collection has been changed, false otherwise
+ */
+gboolean gee_collection_add (GeeCollection* self, gpointer item) {
 	return GEE_COLLECTION_GET_INTERFACE (self)->add (self, item);
 }
 
 
-gboolean gee_collection_remove (GeeCollection* self, gpointer item)
-{
+/**
+ * Removes the first occurence of an item from this collection. Must not
+ * be called on read-only collections.
+ *
+ * @param item the item to remove from the collection
+ *
+ * @return     true if the collection has been changed, false otherwise
+ */
+gboolean gee_collection_remove (GeeCollection* self, gpointer item) {
 	return GEE_COLLECTION_GET_INTERFACE (self)->remove (self, item);
 }
 
 
-void gee_collection_clear (GeeCollection* self)
-{
+/**
+ * Removes all items from this collection. Must not be called on
+ * read-only collections.
+ */
+void gee_collection_clear (GeeCollection* self) {
 	GEE_COLLECTION_GET_INTERFACE (self)->clear (self);
 }
 
 
-gint gee_collection_get_size (GeeCollection* self)
-{
+gint gee_collection_get_size (GeeCollection* self) {
 	gint value;
 	g_object_get (G_OBJECT (self), "size", &value, NULL);
 	return value;
 }
 
 
-static void gee_collection_base_init (GeeCollectionIface * iface)
-{
+static void gee_collection_base_init (GeeCollectionIface * iface) {
 	static gboolean initialized = FALSE;
 	if (!initialized) {
 		initialized = TRUE;
-		g_object_interface_install_property (iface, g_param_spec_int ("size", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+		g_object_interface_install_property (iface, g_param_spec_int ("size", "size", "size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 	}
 }
 
 
-GType gee_collection_get_type (void)
-{
+GType gee_collection_get_type (void) {
 	static GType gee_collection_type_id = 0;
 	if (G_UNLIKELY (gee_collection_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeCollectionIface), (GBaseInitFunc) gee_collection_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
