@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,18 +20,23 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "iterable.h"
+#include <gee/iterable.h>
 
 
 
-GeeIterator* gee_iterable_iterator (GeeIterable* self)
-{
+/**
+ * Returns a Iterator that can be used for simple iteration over a
+ * collection.
+ *
+ * @return a Iterator that can be used for simple iteration over a
+ *         collection
+ */
+GeeIterator* gee_iterable_iterator (GeeIterable* self) {
 	return GEE_ITERABLE_GET_INTERFACE (self)->iterator (self);
 }
 
 
-static void gee_iterable_base_init (GeeIterableIface * iface)
-{
+static void gee_iterable_base_init (GeeIterableIface * iface) {
 	static gboolean initialized = FALSE;
 	if (!initialized) {
 		initialized = TRUE;
@@ -39,8 +44,7 @@ static void gee_iterable_base_init (GeeIterableIface * iface)
 }
 
 
-GType gee_iterable_get_type (void)
-{
+GType gee_iterable_get_type (void) {
 	static GType gee_iterable_type_id = 0;
 	if (G_UNLIKELY (gee_iterable_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeIterableIface), (GBaseInitFunc) gee_iterable_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
