@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,42 +20,66 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "list.h"
+#include <gee/list.h>
 
 
 
-gpointer gee_list_get (GeeList* self, gint index)
-{
-	GEE_LIST_GET_INTERFACE (self)->get (self, index);
+/**
+ * Returns the item at the specified index in this list.
+ *
+ * @param index zero-based index of the item to be returned
+ *
+ * @return      the item at the specified index in the list
+ */
+gpointer gee_list_get (GeeList* self, gint index) {
+	return GEE_LIST_GET_INTERFACE (self)->get (self, index);
 }
 
 
-void gee_list_set (GeeList* self, gint index, gpointer item)
-{
+/**
+ * Sets the item at the specified index in this list.
+ *
+ * @param index zero-based index of the item to be set
+ */
+void gee_list_set (GeeList* self, gint index, gpointer item) {
 	GEE_LIST_GET_INTERFACE (self)->set (self, index, item);
 }
 
 
-gint gee_list_index_of (GeeList* self, gpointer item)
-{
+/**
+ * Returns the index of the first occurence of the specified item in
+ * this list.
+ *
+ * @return the index of the first occurence of the specified item, or
+ *         -1 if the item could not be found
+ */
+gint gee_list_index_of (GeeList* self, gpointer item) {
 	return GEE_LIST_GET_INTERFACE (self)->index_of (self, item);
 }
 
 
-void gee_list_insert (GeeList* self, gint index, gpointer item)
-{
+/**
+ * Inserts an item into this list at the specified position.
+ *
+ * @param index zero-based index at which item is inserted
+ * @param item  item to insert into the list
+ */
+void gee_list_insert (GeeList* self, gint index, gpointer item) {
 	GEE_LIST_GET_INTERFACE (self)->insert (self, index, item);
 }
 
 
-void gee_list_remove_at (GeeList* self, gint index)
-{
+/**
+ * Removes the item at the specified index of this list.
+ *
+ * @param index zero-based index of the item to be removed
+ */
+void gee_list_remove_at (GeeList* self, gint index) {
 	GEE_LIST_GET_INTERFACE (self)->remove_at (self, index);
 }
 
 
-static void gee_list_base_init (GeeListIface * iface)
-{
+static void gee_list_base_init (GeeListIface * iface) {
 	static gboolean initialized = FALSE;
 	if (!initialized) {
 		initialized = TRUE;
@@ -63,8 +87,7 @@ static void gee_list_base_init (GeeListIface * iface)
 }
 
 
-GType gee_list_get_type (void)
-{
+GType gee_list_get_type (void) {
 	static GType gee_list_type_id = 0;
 	if (G_UNLIKELY (gee_list_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeListIface), (GBaseInitFunc) gee_list_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
