@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,6 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "readonlycollection.h"
 #include <gee/readonlycollection.h>
 
 typedef struct _GeeReadOnlyCollectionIterator GeeReadOnlyCollectionIterator;
@@ -71,6 +70,7 @@ enum  {
 };
 static gboolean gee_read_only_collection_iterator_real_next (GeeIterator* base);
 static gpointer gee_read_only_collection_iterator_real_get (GeeIterator* base);
+static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static gpointer gee_read_only_collection_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_read_only_collection_iterator_gee_iterator_parent_iface = NULL;
 static GType gee_read_only_collection_iterator_get_type (void);
@@ -80,8 +80,7 @@ static GeeCollectionIface* gee_read_only_collection_gee_collection_parent_iface
 static void gee_read_only_collection_dispose (GObject * obj);
 
 
-GeeReadOnlyCollection* gee_read_only_collection_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection)
-{
+GeeReadOnlyCollection* gee_read_only_collection_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection) {
 	GeeReadOnlyCollection * self;
 	g_return_val_if_fail (collection == NULL || GEE_IS_COLLECTION (collection), NULL);
 	self = g_object_newv (GEE_TYPE_READ_ONLY_COLLECTION, 0, NULL);
@@ -92,21 +91,19 @@ GeeReadOnlyCollection* gee_read_only_collection_new (GBoxedCopyFunc g_dup_func,
 }
 
 
-static GeeIterator* gee_read_only_collection_real_iterator (GeeIterable* base)
-{
+static GeeIterator* gee_read_only_collection_real_iterator (GeeIterable* base) {
 	GeeReadOnlyCollection * self;
-	self = ((GeeReadOnlyCollection*) base);
+	self = GEE_READ_ONLY_COLLECTION (base);
 	if (self->priv->_collection == NULL) {
-		return GEE_ITERATOR (g_object_new (GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, NULL));
+		return GEE_ITERATOR (gee_read_only_collection_iterator_new (self->priv->g_dup_func, self->priv->g_destroy_func));
 	}
 	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_collection));
 }
 
 
-static gboolean gee_read_only_collection_real_contains (GeeCollection* base, gpointer item)
-{
+static gboolean gee_read_only_collection_real_contains (GeeCollection* base, gpointer item) {
 	GeeReadOnlyCollection * self;
-	self = ((GeeReadOnlyCollection*) base);
+	self = GEE_READ_ONLY_COLLECTION (base);
 	if (self->priv->_collection == NULL) {
 		return FALSE;
 	}
@@ -114,41 +111,36 @@ static gboolean gee_read_only_collection_real_contains (GeeCollection* base, gpo
 }
 
 
-static gboolean gee_read_only_collection_real_add (GeeCollection* base, gpointer item)
-{
+static gboolean gee_read_only_collection_real_add (GeeCollection* base, gpointer item) {
 	GeeReadOnlyCollection * self;
-	self = ((GeeReadOnlyCollection*) base);
+	self = GEE_READ_ONLY_COLLECTION (base);
 	g_assert_not_reached ();
 	return FALSE;
 }
 
 
-static gboolean gee_read_only_collection_real_remove (GeeCollection* base, gpointer item)
-{
+static gboolean gee_read_only_collection_real_remove (GeeCollection* base, gpointer item) {
 	GeeReadOnlyCollection * self;
-	self = ((GeeReadOnlyCollection*) base);
+	self = GEE_READ_ONLY_COLLECTION (base);
 	g_assert_not_reached ();
 	return FALSE;
 }
 
 
-static void gee_read_only_collection_real_clear (GeeCollection* base)
-{
+static void gee_read_only_collection_real_clear (GeeCollection* base) {
 	GeeReadOnlyCollection * self;
-	self = ((GeeReadOnlyCollection*) base);
+	self = GEE_READ_ONLY_COLLECTION (base);
 	g_assert_not_reached ();
 }
 
 
-static gint gee_read_only_collection_real_get_size (GeeReadOnlyCollection* self)
-{
+static gint gee_read_only_collection_real_get_size (GeeReadOnlyCollection* self) {
 	g_return_val_if_fail (GEE_IS_READ_ONLY_COLLECTION (self), 0);
 	return gee_collection_get_size (self->priv->_collection);
 }
 
 
-void gee_read_only_collection_set_collection (GeeReadOnlyCollection* self, GeeCollection* value)
-{
+void gee_read_only_collection_set_collection (GeeReadOnlyCollection* self, GeeCollection* value) {
 	GeeCollection* _tmp1;
 	GeeCollection* _tmp0;
 	g_return_if_fail (GEE_IS_READ_ONLY_COLLECTION (self));
@@ -158,24 +150,30 @@ void gee_read_only_collection_set_collection (GeeReadOnlyCollection* self, GeeCo
 }
 
 
-static gboolean gee_read_only_collection_iterator_real_next (GeeIterator* base)
-{
+static gboolean gee_read_only_collection_iterator_real_next (GeeIterator* base) {
 	GeeReadOnlyCollectionIterator * self;
-	self = ((GeeReadOnlyCollectionIterator*) base);
+	self = GEE_READ_ONLY_COLLECTION_ITERATOR (base);
 	return FALSE;
 }
 
 
-static gpointer gee_read_only_collection_iterator_real_get (GeeIterator* base)
-{
+static gpointer gee_read_only_collection_iterator_real_get (GeeIterator* base) {
 	GeeReadOnlyCollectionIterator * self;
-	self = ((GeeReadOnlyCollectionIterator*) base);
+	self = GEE_READ_ONLY_COLLECTION_ITERATOR (base);
 	return NULL;
 }
 
 
-static void gee_read_only_collection_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	GeeReadOnlyCollectionIterator * self;
+	self = g_object_newv (GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, 0, NULL);
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
+	return self;
+}
+
+
+static void gee_read_only_collection_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyCollectionIterator * self;
 	self = GEE_READ_ONLY_COLLECTION_ITERATOR (object);
 	switch (property_id) {
@@ -186,8 +184,7 @@ static void gee_read_only_collection_iterator_get_property (GObject * object, gu
 }
 
 
-static void gee_read_only_collection_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void gee_read_only_collection_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyCollectionIterator * self;
 	self = GEE_READ_ONLY_COLLECTION_ITERATOR (object);
 	switch (property_id) {
@@ -201,8 +198,7 @@ static void gee_read_only_collection_iterator_set_property (GObject * object, gu
 }
 
 
-static void gee_read_only_collection_iterator_class_init (GeeReadOnlyCollectionIteratorClass * klass)
-{
+static void gee_read_only_collection_iterator_class_init (GeeReadOnlyCollectionIteratorClass * klass) {
 	gee_read_only_collection_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyCollectionIteratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_collection_iterator_get_property;
@@ -212,22 +208,19 @@ static void gee_read_only_collection_iterator_class_init (GeeReadOnlyCollectionI
 }
 
 
-static void gee_read_only_collection_iterator_gee_iterator_interface_init (GeeIteratorIface * iface)
-{
+static void gee_read_only_collection_iterator_gee_iterator_interface_init (GeeIteratorIface * iface) {
 	gee_read_only_collection_iterator_gee_iterator_parent_iface = g_type_interface_peek_parent (iface);
 	iface->next = gee_read_only_collection_iterator_real_next;
 	iface->get = gee_read_only_collection_iterator_real_get;
 }
 
 
-static void gee_read_only_collection_iterator_init (GeeReadOnlyCollectionIterator * self)
-{
+static void gee_read_only_collection_iterator_init (GeeReadOnlyCollectionIterator * self) {
 	self->priv = GEE_READ_ONLY_COLLECTION_ITERATOR_GET_PRIVATE (self);
 }
 
 
-static GType gee_read_only_collection_iterator_get_type (void)
-{
+static GType gee_read_only_collection_iterator_get_type (void) {
 	static GType gee_read_only_collection_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_collection_iterator_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollectionIterator), 0, (GInstanceInitFunc) gee_read_only_collection_iterator_init };
@@ -239,8 +232,7 @@ static GType gee_read_only_collection_iterator_get_type (void)
 }
 
 
-static void gee_read_only_collection_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void gee_read_only_collection_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (object);
 	switch (property_id) {
@@ -254,8 +246,7 @@ static void gee_read_only_collection_get_property (GObject * object, guint prope
 }
 
 
-static void gee_read_only_collection_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void gee_read_only_collection_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (object);
 	switch (property_id) {
@@ -272,8 +263,7 @@ static void gee_read_only_collection_set_property (GObject * object, guint prope
 }
 
 
-static void gee_read_only_collection_class_init (GeeReadOnlyCollectionClass * klass)
-{
+static void gee_read_only_collection_class_init (GeeReadOnlyCollectionClass * klass) {
 	gee_read_only_collection_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyCollectionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_collection_get_property;
@@ -282,19 +272,17 @@ static void gee_read_only_collection_class_init (GeeReadOnlyCollectionClass * kl
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_SIZE, "size");
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_COLLECTION, g_param_spec_object ("collection", "foo", "bar", GEE_TYPE_COLLECTION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_COLLECTION, g_param_spec_object ("collection", "collection", "collection", GEE_TYPE_COLLECTION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
-static void gee_read_only_collection_gee_iterable_interface_init (GeeIterableIface * iface)
-{
+static void gee_read_only_collection_gee_iterable_interface_init (GeeIterableIface * iface) {
 	gee_read_only_collection_gee_iterable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->iterator = gee_read_only_collection_real_iterator;
 }
 
 
-static void gee_read_only_collection_gee_collection_interface_init (GeeCollectionIface * iface)
-{
+static void gee_read_only_collection_gee_collection_interface_init (GeeCollectionIface * iface) {
 	gee_read_only_collection_gee_collection_parent_iface = g_type_interface_peek_parent (iface);
 	iface->contains = gee_read_only_collection_real_contains;
 	iface->add = gee_read_only_collection_real_add;
@@ -303,27 +291,20 @@ static void gee_read_only_collection_gee_collection_interface_init (GeeCollectio
 }
 
 
-static void gee_read_only_collection_init (GeeReadOnlyCollection * self)
-{
+static void gee_read_only_collection_init (GeeReadOnlyCollection * self) {
 	self->priv = GEE_READ_ONLY_COLLECTION_GET_PRIVATE (self);
 }
 
 
-static void gee_read_only_collection_dispose (GObject * obj)
-{
+static void gee_read_only_collection_dispose (GObject * obj) {
 	GeeReadOnlyCollection * self;
-	GeeReadOnlyCollectionClass * klass;
-	GObjectClass * parent_class;
 	self = GEE_READ_ONLY_COLLECTION (obj);
 	(self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL)));
-	klass = GEE_READ_ONLY_COLLECTION_CLASS (g_type_class_peek (GEE_TYPE_READ_ONLY_COLLECTION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (gee_read_only_collection_parent_class)->dispose (obj);
 }
 
 
-GType gee_read_only_collection_get_type (void)
-{
+GType gee_read_only_collection_get_type (void) {
 	static GType gee_read_only_collection_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_collection_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollection), 0, (GInstanceInitFunc) gee_read_only_collection_init };
