@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,6 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "readonlylist.h"
 #include <gee/readonlylist.h>
 
 typedef struct _GeeReadOnlyListIterator GeeReadOnlyListIterator;
@@ -76,6 +75,7 @@ enum  {
 };
 static gboolean gee_read_only_list_iterator_real_next (GeeIterator* base);
 static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base);
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static gpointer gee_read_only_list_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_read_only_list_iterator_gee_iterator_parent_iface = NULL;
 static GType gee_read_only_list_iterator_get_type (void);
@@ -86,8 +86,7 @@ static GeeListIface* gee_read_only_list_gee_list_parent_iface = NULL;
 static void gee_read_only_list_dispose (GObject * obj);
 
 
-GeeReadOnlyList* gee_read_only_list_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list)
-{
+GeeReadOnlyList* gee_read_only_list_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list) {
 	GeeReadOnlyList * self;
 	g_return_val_if_fail (list == NULL || GEE_IS_LIST (list), NULL);
 	self = g_object_newv (GEE_TYPE_READ_ONLY_LIST, 0, NULL);
@@ -98,21 +97,19 @@ GeeReadOnlyList* gee_read_only_list_new (GBoxedCopyFunc g_dup_func, GDestroyNoti
 }
 
 
-static GeeIterator* gee_read_only_list_real_iterator (GeeIterable* base)
-{
+static GeeIterator* gee_read_only_list_real_iterator (GeeIterable* base) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	if (self->priv->_list == NULL) {
-		return GEE_ITERATOR (g_object_new (GEE_READ_ONLY_LIST_TYPE_ITERATOR, NULL));
+		return GEE_ITERATOR (gee_read_only_list_iterator_new (self->priv->g_dup_func, self->priv->g_destroy_func));
 	}
 	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_list));
 }
 
 
-static gboolean gee_read_only_list_real_contains (GeeCollection* base, gpointer item)
-{
+static gboolean gee_read_only_list_real_contains (GeeCollection* base, gpointer item) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	if (self->priv->_list == NULL) {
 		return FALSE;
 	}
@@ -120,10 +117,9 @@ static gboolean gee_read_only_list_real_contains (GeeCollection* base, gpointer
 }
 
 
-static gint gee_read_only_list_real_index_of (GeeList* base, gpointer item)
-{
+static gint gee_read_only_list_real_index_of (GeeList* base, gpointer item) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	if (self->priv->_list == NULL) {
 		return -1;
 	}
@@ -131,44 +127,39 @@ static gint gee_read_only_list_real_index_of (GeeList* base, gpointer item)
 }
 
 
-static gboolean gee_read_only_list_real_add (GeeCollection* base, gpointer item)
-{
+static gboolean gee_read_only_list_real_add (GeeCollection* base, gpointer item) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	g_assert_not_reached ();
 	return FALSE;
 }
 
 
-static gboolean gee_read_only_list_real_remove (GeeCollection* base, gpointer item)
-{
+static gboolean gee_read_only_list_real_remove (GeeCollection* base, gpointer item) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	g_assert_not_reached ();
 	return FALSE;
 }
 
 
-static void gee_read_only_list_real_insert (GeeList* base, gint index, gpointer item)
-{
+static void gee_read_only_list_real_insert (GeeList* base, gint index, gpointer item) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	g_assert_not_reached ();
 }
 
 
-static void gee_read_only_list_real_remove_at (GeeList* base, gint index)
-{
+static void gee_read_only_list_real_remove_at (GeeList* base, gint index) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	g_assert_not_reached ();
 }
 
 
-static gpointer gee_read_only_list_real_get (GeeList* base, gint index)
-{
+static gpointer gee_read_only_list_real_get (GeeList* base, gint index) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	if (self->priv->_list == NULL) {
 		return NULL;
 	}
@@ -176,31 +167,27 @@ static gpointer gee_read_only_list_real_get (GeeList* base, gint index)
 }
 
 
-static void gee_read_only_list_real_set (GeeList* base, gint index, gpointer o)
-{
+static void gee_read_only_list_real_set (GeeList* base, gint index, gpointer o) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	g_assert_not_reached ();
 }
 
 
-static void gee_read_only_list_real_clear (GeeCollection* base)
-{
+static void gee_read_only_list_real_clear (GeeCollection* base) {
 	GeeReadOnlyList * self;
-	self = ((GeeReadOnlyList*) base);
+	self = GEE_READ_ONLY_LIST (base);
 	g_assert_not_reached ();
 }
 
 
-static gint gee_read_only_list_real_get_size (GeeReadOnlyList* self)
-{
+static gint gee_read_only_list_real_get_size (GeeReadOnlyList* self) {
 	g_return_val_if_fail (GEE_IS_READ_ONLY_LIST (self), 0);
-	return gee_collection_get_size (((GeeCollection*) self->priv->_list));
+	return gee_collection_get_size (GEE_COLLECTION (self->priv->_list));
 }
 
 
-void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value)
-{
+void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value) {
 	GeeList* _tmp1;
 	GeeList* _tmp0;
 	g_return_if_fail (GEE_IS_READ_ONLY_LIST (self));
@@ -210,24 +197,30 @@ void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value)
 }
 
 
-static gboolean gee_read_only_list_iterator_real_next (GeeIterator* base)
-{
+static gboolean gee_read_only_list_iterator_real_next (GeeIterator* base) {
 	GeeReadOnlyListIterator * self;
-	self = ((GeeReadOnlyListIterator*) base);
+	self = GEE_READ_ONLY_LIST_ITERATOR (base);
 	return FALSE;
 }
 
 
-static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base)
-{
+static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base) {
 	GeeReadOnlyListIterator * self;
-	self = ((GeeReadOnlyListIterator*) base);
+	self = GEE_READ_ONLY_LIST_ITERATOR (base);
 	return NULL;
 }
 
 
-static void gee_read_only_list_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	GeeReadOnlyListIterator * self;
+	self = g_object_newv (GEE_READ_ONLY_LIST_TYPE_ITERATOR, 0, NULL);
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
+	return self;
+}
+
+
+static void gee_read_only_list_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyListIterator * self;
 	self = GEE_READ_ONLY_LIST_ITERATOR (object);
 	switch (property_id) {
@@ -238,8 +231,7 @@ static void gee_read_only_list_iterator_get_property (GObject * object, guint pr
 }
 
 
-static void gee_read_only_list_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void gee_read_only_list_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyListIterator * self;
 	self = GEE_READ_ONLY_LIST_ITERATOR (object);
 	switch (property_id) {
@@ -253,8 +245,7 @@ static void gee_read_only_list_iterator_set_property (GObject * object, guint pr
 }
 
 
-static void gee_read_only_list_iterator_class_init (GeeReadOnlyListIteratorClass * klass)
-{
+static void gee_read_only_list_iterator_class_init (GeeReadOnlyListIteratorClass * klass) {
 	gee_read_only_list_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyListIteratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_list_iterator_get_property;
@@ -264,22 +255,19 @@ static void gee_read_only_list_iterator_class_init (GeeReadOnlyListIteratorClass
 }
 
 
-static void gee_read_only_list_iterator_gee_iterator_interface_init (GeeIteratorIface * iface)
-{
+static void gee_read_only_list_iterator_gee_iterator_interface_init (GeeIteratorIface * iface) {
 	gee_read_only_list_iterator_gee_iterator_parent_iface = g_type_interface_peek_parent (iface);
 	iface->next = gee_read_only_list_iterator_real_next;
 	iface->get = gee_read_only_list_iterator_real_get;
 }
 
 
-static void gee_read_only_list_iterator_init (GeeReadOnlyListIterator * self)
-{
+static void gee_read_only_list_iterator_init (GeeReadOnlyListIterator * self) {
 	self->priv = GEE_READ_ONLY_LIST_ITERATOR_GET_PRIVATE (self);
 }
 
 
-static GType gee_read_only_list_iterator_get_type (void)
-{
+static GType gee_read_only_list_iterator_get_type (void) {
 	static GType gee_read_only_list_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_list_iterator_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyListIterator), 0, (GInstanceInitFunc) gee_read_only_list_iterator_init };
@@ -291,8 +279,7 @@ static GType gee_read_only_list_iterator_get_type (void)
 }
 
 
-static void gee_read_only_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void gee_read_only_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyList * self;
 	self = GEE_READ_ONLY_LIST (object);
 	switch (property_id) {
@@ -306,8 +293,7 @@ static void gee_read_only_list_get_property (GObject * object, guint property_id
 }
 
 
-static void gee_read_only_list_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void gee_read_only_list_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyList * self;
 	self = GEE_READ_ONLY_LIST (object);
 	switch (property_id) {
@@ -324,8 +310,7 @@ static void gee_read_only_list_set_property (GObject * object, guint property_id
 }
 
 
-static void gee_read_only_list_class_init (GeeReadOnlyListClass * klass)
-{
+static void gee_read_only_list_class_init (GeeReadOnlyListClass * klass) {
 	gee_read_only_list_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyListPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_list_get_property;
@@ -334,19 +319,17 @@ static void gee_read_only_list_class_init (GeeReadOnlyListClass * klass)
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_SIZE, "size");
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_LIST, g_param_spec_object ("list", "foo", "bar", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_LIST, g_param_spec_object ("list", "list", "list", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
-static void gee_read_only_list_gee_iterable_interface_init (GeeIterableIface * iface)
-{
+static void gee_read_only_list_gee_iterable_interface_init (GeeIterableIface * iface) {
 	gee_read_only_list_gee_iterable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->iterator = gee_read_only_list_real_iterator;
 }
 
 
-static void gee_read_only_list_gee_collection_interface_init (GeeCollectionIface * iface)
-{
+static void gee_read_only_list_gee_collection_interface_init (GeeCollectionIface * iface) {
 	gee_read_only_list_gee_collection_parent_iface = g_type_interface_peek_parent (iface);
 	iface->contains = gee_read_only_list_real_contains;
 	iface->add = gee_read_only_list_real_add;
@@ -355,8 +338,7 @@ static void gee_read_only_list_gee_collection_interface_init (GeeCollectionIface
 }
 
 
-static void gee_read_only_list_gee_list_interface_init (GeeListIface * iface)
-{
+static void gee_read_only_list_gee_list_interface_init (GeeListIface * iface) {
 	gee_read_only_list_gee_list_parent_iface = g_type_interface_peek_parent (iface);
 	iface->index_of = gee_read_only_list_real_index_of;
 	iface->insert = gee_read_only_list_real_insert;
@@ -366,27 +348,20 @@ static void gee_read_only_list_gee_list_interface_init (GeeListIface * iface)
 }
 
 
-static void gee_read_only_list_init (GeeReadOnlyList * self)
-{
+static void gee_read_only_list_init (GeeReadOnlyList * self) {
 	self->priv = GEE_READ_ONLY_LIST_GET_PRIVATE (self);
 }
 
 
-static void gee_read_only_list_dispose (GObject * obj)
-{
+static void gee_read_only_list_dispose (GObject * obj) {
 	GeeReadOnlyList * self;
-	GeeReadOnlyListClass * klass;
-	GObjectClass * parent_class;
 	self = GEE_READ_ONLY_LIST (obj);
 	(self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL)));
-	klass = GEE_READ_ONLY_LIST_CLASS (g_type_class_peek (GEE_TYPE_READ_ONLY_LIST));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (gee_read_only_list_parent_class)->dispose (obj);
 }
 
 
-GType gee_read_only_list_get_type (void)
-{
+GType gee_read_only_list_get_type (void) {
 	static GType gee_read_only_list_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_list_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyList), 0, (GInstanceInitFunc) gee_read_only_list_init };
