@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,6 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "readonlymap.h"
 #include <gee/readonlymap.h>
 #include <gee/readonlyset.h>
 #include <gee/readonlycollection.h>
@@ -54,8 +53,7 @@ static GeeMapIface* gee_read_only_map_gee_map_parent_iface = NULL;
 static void gee_read_only_map_dispose (GObject * obj);
 
 
-GeeReadOnlyMap* gee_read_only_map_new (GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map)
-{
+GeeReadOnlyMap* gee_read_only_map_new (GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map) {
 	GeeReadOnlyMap * self;
 	g_return_val_if_fail (map == NULL || GEE_IS_MAP (map), NULL);
 	self = g_object_newv (GEE_TYPE_READ_ONLY_MAP, 0, NULL);
@@ -68,10 +66,9 @@ GeeReadOnlyMap* gee_read_only_map_new (GBoxedCopyFunc k_dup_func, GDestroyNotify
 }
 
 
-static GeeSet* gee_read_only_map_real_get_keys (GeeMap* base)
-{
+static GeeSet* gee_read_only_map_real_get_keys (GeeMap* base) {
 	GeeReadOnlyMap * self;
-	self = ((GeeReadOnlyMap*) base);
+	self = GEE_READ_ONLY_MAP (base);
 	if (self->priv->_map == NULL) {
 		return GEE_SET (gee_read_only_set_new (self->priv->k_dup_func, self->priv->k_destroy_func, NULL));
 	}
@@ -79,10 +76,9 @@ static GeeSet* gee_read_only_map_real_get_keys (GeeMap* base)
 }
 
 
-static GeeCollection* gee_read_only_map_real_get_values (GeeMap* base)
-{
+static GeeCollection* gee_read_only_map_real_get_values (GeeMap* base) {
 	GeeReadOnlyMap * self;
-	self = ((GeeReadOnlyMap*) base);
+	self = GEE_READ_ONLY_MAP (base);
 	if (self->priv->_map == NULL) {
 		return GEE_COLLECTION (gee_read_only_collection_new (self->priv->v_dup_func, self->priv->v_destroy_func, NULL));
 	}
@@ -90,10 +86,9 @@ static GeeCollection* gee_read_only_map_real_get_values (GeeMap* base)
 }
 
 
-static gboolean gee_read_only_map_real_contains (GeeMap* base, gpointer key)
-{
+static gboolean gee_read_only_map_real_contains (GeeMap* base, gpointer key) {
 	GeeReadOnlyMap * self;
-	self = ((GeeReadOnlyMap*) base);
+	self = GEE_READ_ONLY_MAP (base);
 	if (self->priv->_map == NULL) {
 		return FALSE;
 	}
@@ -101,10 +96,9 @@ static gboolean gee_read_only_map_real_contains (GeeMap* base, gpointer key)
 }
 
 
-static gpointer gee_read_only_map_real_get (GeeMap* base, gpointer key)
-{
+static gpointer gee_read_only_map_real_get (GeeMap* base, gpointer key) {
 	GeeReadOnlyMap * self;
-	self = ((GeeReadOnlyMap*) base);
+	self = GEE_READ_ONLY_MAP (base);
 	if (self->priv->_map == NULL) {
 		return NULL;
 	}
@@ -112,40 +106,35 @@ static gpointer gee_read_only_map_real_get (GeeMap* base, gpointer key)
 }
 
 
-static void gee_read_only_map_real_set (GeeMap* base, gpointer key, gpointer value)
-{
+static void gee_read_only_map_real_set (GeeMap* base, gpointer key, gpointer value) {
 	GeeReadOnlyMap * self;
-	self = ((GeeReadOnlyMap*) base);
+	self = GEE_READ_ONLY_MAP (base);
 	g_assert_not_reached ();
 }
 
 
-static gboolean gee_read_only_map_real_remove (GeeMap* base, gpointer key)
-{
+static gboolean gee_read_only_map_real_remove (GeeMap* base, gpointer key) {
 	GeeReadOnlyMap * self;
-	self = ((GeeReadOnlyMap*) base);
+	self = GEE_READ_ONLY_MAP (base);
 	g_assert_not_reached ();
 	return FALSE;
 }
 
 
-static void gee_read_only_map_real_clear (GeeMap* base)
-{
+static void gee_read_only_map_real_clear (GeeMap* base) {
 	GeeReadOnlyMap * self;
-	self = ((GeeReadOnlyMap*) base);
+	self = GEE_READ_ONLY_MAP (base);
 	g_assert_not_reached ();
 }
 
 
-static gint gee_read_only_map_real_get_size (GeeReadOnlyMap* self)
-{
+static gint gee_read_only_map_real_get_size (GeeReadOnlyMap* self) {
 	g_return_val_if_fail (GEE_IS_READ_ONLY_MAP (self), 0);
 	return gee_map_get_size (self->priv->_map);
 }
 
 
-void gee_read_only_map_set_map (GeeReadOnlyMap* self, GeeMap* value)
-{
+void gee_read_only_map_set_map (GeeReadOnlyMap* self, GeeMap* value) {
 	GeeMap* _tmp1;
 	GeeMap* _tmp0;
 	g_return_if_fail (GEE_IS_READ_ONLY_MAP (self));
@@ -155,8 +144,7 @@ void gee_read_only_map_set_map (GeeReadOnlyMap* self, GeeMap* value)
 }
 
 
-static void gee_read_only_map_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void gee_read_only_map_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyMap * self;
 	self = GEE_READ_ONLY_MAP (object);
 	switch (property_id) {
@@ -170,8 +158,7 @@ static void gee_read_only_map_get_property (GObject * object, guint property_id,
 }
 
 
-static void gee_read_only_map_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void gee_read_only_map_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyMap * self;
 	self = GEE_READ_ONLY_MAP (object);
 	switch (property_id) {
@@ -191,8 +178,7 @@ static void gee_read_only_map_set_property (GObject * object, guint property_id,
 }
 
 
-static void gee_read_only_map_class_init (GeeReadOnlyMapClass * klass)
-{
+static void gee_read_only_map_class_init (GeeReadOnlyMapClass * klass) {
 	gee_read_only_map_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyMapPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_map_get_property;
@@ -203,12 +189,11 @@ static void gee_read_only_map_class_init (GeeReadOnlyMapClass * klass)
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_MAP_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_MAP_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_MAP_SIZE, "size");
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_MAP_MAP, g_param_spec_object ("map", "foo", "bar", GEE_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_MAP_MAP, g_param_spec_object ("map", "map", "map", GEE_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
-static void gee_read_only_map_gee_map_interface_init (GeeMapIface * iface)
-{
+static void gee_read_only_map_gee_map_interface_init (GeeMapIface * iface) {
 	gee_read_only_map_gee_map_parent_iface = g_type_interface_peek_parent (iface);
 	iface->get_keys = gee_read_only_map_real_get_keys;
 	iface->get_values = gee_read_only_map_real_get_values;
@@ -220,27 +205,20 @@ static void gee_read_only_map_gee_map_interface_init (GeeMapIface * iface)
 }
 
 
-static void gee_read_only_map_init (GeeReadOnlyMap * self)
-{
+static void gee_read_only_map_init (GeeReadOnlyMap * self) {
 	self->priv = GEE_READ_ONLY_MAP_GET_PRIVATE (self);
 }
 
 
-static void gee_read_only_map_dispose (GObject * obj)
-{
+static void gee_read_only_map_dispose (GObject * obj) {
 	GeeReadOnlyMap * self;
-	GeeReadOnlyMapClass * klass;
-	GObjectClass * parent_class;
 	self = GEE_READ_ONLY_MAP (obj);
 	(self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL)));
-	klass = GEE_READ_ONLY_MAP_CLASS (g_type_class_peek (GEE_TYPE_READ_ONLY_MAP));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (gee_read_only_map_parent_class)->dispose (obj);
 }
 
 
-GType gee_read_only_map_get_type (void)
-{
+GType gee_read_only_map_get_type (void) {
 	static GType gee_read_only_map_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_map_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyMap), 0, (GInstanceInitFunc) gee_read_only_map_init };
