@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,9 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaaddressofexpression.h"
-#include <vala/valasourcereference.h>
 #include <vala/valaaddressofexpression.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaAddressofExpressionPrivate {
@@ -45,8 +44,7 @@ static void vala_addressof_expression_dispose (GObject * obj);
  * @param inner variable whose address is to be computed
  * @return      newly created address-of expression
  */
-ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, ValaSourceReference* source_reference)
-{
+ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, ValaSourceReference* source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaAddressofExpression * self;
@@ -66,20 +64,18 @@ ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, V
 }
 
 
-static void vala_addressof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_addressof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaAddressofExpression * self;
-	self = ((ValaAddressofExpression*) base);
+	self = VALA_ADDRESSOF_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_addressof_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_addressof_expression (visitor, self);
 }
 
 
-static void vala_addressof_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
-{
+static void vala_addressof_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
 	ValaAddressofExpression * self;
-	self = ((ValaAddressofExpression*) base);
+	self = VALA_ADDRESSOF_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_addressof_expression_get_inner (self)) == old_node) {
@@ -88,15 +84,13 @@ static void vala_addressof_expression_real_replace (ValaCodeNode* base, ValaCode
 }
 
 
-ValaExpression* vala_addressof_expression_get_inner (ValaAddressofExpression* self)
-{
+ValaExpression* vala_addressof_expression_get_inner (ValaAddressofExpression* self) {
 	g_return_val_if_fail (VALA_IS_ADDRESSOF_EXPRESSION (self), NULL);
 	return self->priv->_inner;
 }
 
 
-void vala_addressof_expression_set_inner (ValaAddressofExpression* self, ValaExpression* value)
-{
+void vala_addressof_expression_set_inner (ValaAddressofExpression* self, ValaExpression* value) {
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_ADDRESSOF_EXPRESSION (self));
 	_tmp1 = NULL;
@@ -105,8 +99,7 @@ void vala_addressof_expression_set_inner (ValaAddressofExpression* self, ValaExp
 }
 
 
-static void vala_addressof_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_addressof_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaAddressofExpression * self;
 	self = VALA_ADDRESSOF_EXPRESSION (object);
 	switch (property_id) {
@@ -120,8 +113,7 @@ static void vala_addressof_expression_get_property (GObject * object, guint prop
 }
 
 
-static void vala_addressof_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_addressof_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaAddressofExpression * self;
 	self = VALA_ADDRESSOF_EXPRESSION (object);
 	switch (property_id) {
@@ -135,8 +127,7 @@ static void vala_addressof_expression_set_property (GObject * object, guint prop
 }
 
 
-static void vala_addressof_expression_class_init (ValaAddressofExpressionClass * klass)
-{
+static void vala_addressof_expression_class_init (ValaAddressofExpressionClass * klass) {
 	vala_addressof_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaAddressofExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_addressof_expression_get_property;
@@ -144,31 +135,24 @@ static void vala_addressof_expression_class_init (ValaAddressofExpressionClass *
 	G_OBJECT_CLASS (klass)->dispose = vala_addressof_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_addressof_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace = vala_addressof_expression_real_replace;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ADDRESSOF_EXPRESSION_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ADDRESSOF_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_addressof_expression_init (ValaAddressofExpression * self)
-{
+static void vala_addressof_expression_init (ValaAddressofExpression * self) {
 	self->priv = VALA_ADDRESSOF_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_addressof_expression_dispose (GObject * obj)
-{
+static void vala_addressof_expression_dispose (GObject * obj) {
 	ValaAddressofExpression * self;
-	ValaAddressofExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_ADDRESSOF_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	klass = VALA_ADDRESSOF_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_ADDRESSOF_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_addressof_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_addressof_expression_get_type (void)
-{
+GType vala_addressof_expression_get_type (void) {
 	static GType vala_addressof_expression_type_id = 0;
 	if (G_UNLIKELY (vala_addressof_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaAddressofExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_addressof_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAddressofExpression), 0, (GInstanceInitFunc) vala_addressof_expression_init };
