@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaattribute.h"
+#include <vala/valaattribute.h>
 #include <gee/arraylist.h>
 #include <gee/collection.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaattribute.h>
 #include <vala/valanamedargument.h>
 #include <vala/valaliteralexpression.h>
 #include <vala/valaliteral.h>
@@ -51,8 +50,7 @@ static void vala_attribute_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created attribute
  */
-ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source_reference)
-{
+ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source_reference) {
 	ValaAttribute * self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
@@ -68,8 +66,7 @@ ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source
  *
  * @param arg named argument
  */
-void vala_attribute_add_argument (ValaAttribute* self, ValaNamedArgument* arg)
-{
+void vala_attribute_add_argument (ValaAttribute* self, ValaNamedArgument* arg) {
 	g_return_if_fail (VALA_IS_ATTRIBUTE (self));
 	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (arg));
 	gee_collection_add (GEE_COLLECTION (self->args), arg);
@@ -82,8 +79,7 @@ void vala_attribute_add_argument (ValaAttribute* self, ValaNamedArgument* arg)
  * @param name argument name
  * @return     true if the argument has been found, false otherwise
  */
-gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name)
-{
+gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
 	{
@@ -115,8 +111,7 @@ gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name)
  * @param name argument name
  * @return     string value
  */
-char* vala_attribute_get_string (ValaAttribute* self, const char* name)
-{
+char* vala_attribute_get_string (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	{
@@ -158,8 +153,7 @@ char* vala_attribute_get_string (ValaAttribute* self, const char* name)
  * @param name argument name
  * @return     integer value
  */
-gint vala_attribute_get_integer (ValaAttribute* self, const char* name)
-{
+gint vala_attribute_get_integer (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), 0);
 	g_return_val_if_fail (name != NULL, 0);
 	{
@@ -200,8 +194,7 @@ gint vala_attribute_get_integer (ValaAttribute* self, const char* name)
  * @param name argument name
  * @return     boolean value
  */
-gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name)
-{
+gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
 	{
@@ -236,15 +229,13 @@ gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name)
 }
 
 
-char* vala_attribute_get_name (ValaAttribute* self)
-{
+char* vala_attribute_get_name (ValaAttribute* self) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), NULL);
 	return self->priv->_name;
 }
 
 
-void vala_attribute_set_name (ValaAttribute* self, const char* value)
-{
+void vala_attribute_set_name (ValaAttribute* self, const char* value) {
 	char* _tmp1;
 	g_return_if_fail (VALA_IS_ATTRIBUTE (self));
 	_tmp1 = NULL;
@@ -252,8 +243,7 @@ void vala_attribute_set_name (ValaAttribute* self, const char* value)
 }
 
 
-static void vala_attribute_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_attribute_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaAttribute * self;
 	self = VALA_ATTRIBUTE (object);
 	switch (property_id) {
@@ -267,8 +257,7 @@ static void vala_attribute_get_property (GObject * object, guint property_id, GV
 }
 
 
-static void vala_attribute_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_attribute_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaAttribute * self;
 	self = VALA_ATTRIBUTE (object);
 	switch (property_id) {
@@ -282,40 +271,32 @@ static void vala_attribute_set_property (GObject * object, guint property_id, co
 }
 
 
-static void vala_attribute_class_init (ValaAttributeClass * klass)
-{
+static void vala_attribute_class_init (ValaAttributeClass * klass) {
 	vala_attribute_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaAttributePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_attribute_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_attribute_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_attribute_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ATTRIBUTE_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ATTRIBUTE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_attribute_init (ValaAttribute * self)
-{
+static void vala_attribute_init (ValaAttribute * self) {
 	self->priv = VALA_ATTRIBUTE_GET_PRIVATE (self);
 	self->args = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_attribute_dispose (GObject * obj)
-{
+static void vala_attribute_dispose (GObject * obj) {
 	ValaAttribute * self;
-	ValaAttributeClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_ATTRIBUTE (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->args == NULL ? NULL : (self->args = (g_object_unref (self->args), NULL)));
-	klass = VALA_ATTRIBUTE_CLASS (g_type_class_peek (VALA_TYPE_ATTRIBUTE));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_attribute_parent_class)->dispose (obj);
 }
 
 
-GType vala_attribute_get_type (void)
-{
+GType vala_attribute_get_type (void) {
 	static GType vala_attribute_type_id = 0;
 	if (G_UNLIKELY (vala_attribute_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAttribute), 0, (GInstanceInitFunc) vala_attribute_init };
