@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,13 +19,10 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
-#include "valabaseaccess.h"
+#include <vala/valabaseaccess.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valabaseaccess.h>
 
 enum  {
 	VALA_BASE_ACCESS_DUMMY_PROPERTY
@@ -41,22 +38,16 @@ static gpointer vala_base_access_parent_class = NULL;
  * @param source reference to source code
  * @return       newly created base access expression
  */
-ValaBaseAccess* vala_base_access_new (ValaSourceReference* source)
-{
-	GParameter * __params;
-	GParameter * __params_it;
+ValaBaseAccess* vala_base_access_new (ValaSourceReference* source) {
 	ValaBaseAccess * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_BASE_ACCESS, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_BASE_ACCESS, 0, NULL);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
-static void vala_base_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_base_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBaseAccess * self;
 	self = VALA_BASE_ACCESS (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
@@ -64,29 +55,25 @@ static void vala_base_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* v
 }
 
 
-static char* vala_base_access_real_to_string (ValaCodeNode* base)
-{
+static char* vala_base_access_real_to_string (ValaCodeNode* base) {
 	ValaBaseAccess * self;
 	self = VALA_BASE_ACCESS (base);
 	return g_strdup ("base");
 }
 
 
-static void vala_base_access_class_init (ValaBaseAccessClass * klass)
-{
+static void vala_base_access_class_init (ValaBaseAccessClass * klass) {
 	vala_base_access_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_base_access_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_base_access_real_to_string;
 }
 
 
-static void vala_base_access_init (ValaBaseAccess * self)
-{
+static void vala_base_access_init (ValaBaseAccess * self) {
 }
 
 
-GType vala_base_access_get_type ()
-{
+GType vala_base_access_get_type (void) {
 	static GType vala_base_access_type_id = 0;
 	if (G_UNLIKELY (vala_base_access_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaBaseAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_base_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBaseAccess), 0, (GInstanceInitFunc) vala_base_access_init };
