@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valacallback.h"
+#include <vala/valacallback.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
@@ -28,7 +28,6 @@
 #include <gee/iterator.h>
 #include <vala/valatypereference.h>
 #include <vala/valasourcereference.h>
-#include <vala/valacallback.h>
 #include <vala/valasymbol.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valascope.h>
@@ -71,8 +70,7 @@ static void vala_callback_dispose (GObject * obj);
  * @param source      reference to source code
  * @return            newly created callback
  */
-ValaCallback* vala_callback_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference)
-{
+ValaCallback* vala_callback_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference) {
 	ValaCallback * self;
 	g_return_val_if_fail (return_type == NULL || VALA_IS_TYPE_REFERENCE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
@@ -89,13 +87,12 @@ ValaCallback* vala_callback_new (const char* name, ValaTypeReference* return_typ
  *
  * @param p a type parameter
  */
-void vala_callback_add_type_parameter (ValaCallback* self, ValaTypeParameter* p)
-{
+void vala_callback_add_type_parameter (ValaCallback* self, ValaTypeParameter* p) {
 	g_return_if_fail (VALA_IS_CALLBACK (self));
 	g_return_if_fail (VALA_IS_TYPE_PARAMETER (p));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_parameters), p);
 	p->type = VALA_DATA_TYPE (self);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) p)), VALA_SYMBOL (p));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (p)), VALA_SYMBOL (p));
 }
 
 
@@ -104,12 +101,11 @@ void vala_callback_add_type_parameter (ValaCallback* self, ValaTypeParameter* p)
  *
  * @param param a formal parameter
  */
-void vala_callback_add_parameter (ValaCallback* self, ValaFormalParameter* param)
-{
+void vala_callback_add_parameter (ValaCallback* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_CALLBACK (self));
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) param)), VALA_SYMBOL (param));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (param)), VALA_SYMBOL (param));
 }
 
 
@@ -118,8 +114,7 @@ void vala_callback_add_parameter (ValaCallback* self, ValaFormalParameter* param
  *
  * @return parameter list
  */
-GeeCollection* vala_callback_get_parameters (ValaCallback* self)
-{
+GeeCollection* vala_callback_get_parameters (ValaCallback* self) {
 	g_return_val_if_fail (VALA_IS_CALLBACK (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->parameters)));
 }
@@ -132,8 +127,7 @@ GeeCollection* vala_callback_get_parameters (ValaCallback* self)
  * @param m a method
  * @return  true if the specified method is compatible to this callback
  */
-gboolean vala_callback_matches_method (ValaCallback* self, ValaMethod* m)
-{
+gboolean vala_callback_matches_method (ValaCallback* self, ValaMethod* m) {
 	GeeCollection* method_params;
 	GeeIterator* method_params_it;
 	gboolean first;
@@ -192,19 +186,17 @@ gboolean vala_callback_matches_method (ValaCallback* self, ValaMethod* m)
 }
 
 
-static void vala_callback_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_callback_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCallback * self;
-	self = ((ValaCallback*) base);
+	self = VALA_CALLBACK (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_callback (visitor, self);
 }
 
 
-static void vala_callback_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_callback_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCallback * self;
-	self = ((ValaCallback*) base);
+	self = VALA_CALLBACK (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* p_collection;
@@ -240,17 +232,16 @@ static void vala_callback_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 }
 
 
-static char* vala_callback_real_get_cname (ValaDataType* base, gboolean const_type)
-{
+static char* vala_callback_real_get_cname (ValaDataType* base, gboolean const_type) {
 	ValaCallback * self;
 	const char* _tmp2;
-	self = ((ValaCallback*) base);
+	self = VALA_CALLBACK (base);
 	if (self->priv->cname == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 		(_tmp0 = (g_free (_tmp0), NULL));
 	}
 	_tmp2 = NULL;
@@ -263,8 +254,7 @@ static char* vala_callback_real_get_cname (ValaDataType* base, gboolean const_ty
  *
  * @param cname the name to be used in C code
  */
-void vala_callback_set_cname (ValaCallback* self, const char* cname)
-{
+void vala_callback_set_cname (ValaCallback* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_CALLBACK (self));
@@ -274,8 +264,7 @@ void vala_callback_set_cname (ValaCallback* self, const char* cname)
 }
 
 
-static void vala_callback_process_ccode_attribute (ValaCallback* self, ValaAttribute* a)
-{
+static void vala_callback_process_ccode_attribute (ValaCallback* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_CALLBACK (self));
 	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
@@ -290,13 +279,12 @@ static void vala_callback_process_ccode_attribute (ValaCallback* self, ValaAttri
 /**
  * Process all associated attributes.
  */
-void vala_callback_process_attributes (ValaCallback* self)
-{
+void vala_callback_process_attributes (ValaCallback* self) {
 	g_return_if_fail (VALA_IS_CALLBACK (self));
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = ((ValaCodeNode*) self)->attributes;
+		a_collection = VALA_CODE_NODE (self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
@@ -313,55 +301,48 @@ void vala_callback_process_attributes (ValaCallback* self)
 }
 
 
-static gboolean vala_callback_real_is_reference_type (ValaDataType* base)
-{
+static gboolean vala_callback_real_is_reference_type (ValaDataType* base) {
 	ValaCallback * self;
-	self = ((ValaCallback*) base);
+	self = VALA_CALLBACK (base);
 	return FALSE;
 }
 
 
-static char* vala_callback_real_get_type_id (ValaDataType* base)
-{
+static char* vala_callback_real_get_type_id (ValaDataType* base) {
 	ValaCallback * self;
-	self = ((ValaCallback*) base);
+	self = VALA_CALLBACK (base);
 	return g_strdup ("G_TYPE_POINTER");
 }
 
 
-static char* vala_callback_real_get_marshaller_type_name (ValaDataType* base)
-{
+static char* vala_callback_real_get_marshaller_type_name (ValaDataType* base) {
 	ValaCallback * self;
-	self = ((ValaCallback*) base);
+	self = VALA_CALLBACK (base);
 	return g_strdup ("POINTER");
 }
 
 
-static char* vala_callback_real_get_get_value_function (ValaDataType* base)
-{
+static char* vala_callback_real_get_get_value_function (ValaDataType* base) {
 	ValaCallback * self;
-	self = ((ValaCallback*) base);
+	self = VALA_CALLBACK (base);
 	return g_strdup ("g_value_get_pointer");
 }
 
 
-static char* vala_callback_real_get_set_value_function (ValaDataType* base)
-{
+static char* vala_callback_real_get_set_value_function (ValaDataType* base) {
 	ValaCallback * self;
-	self = ((ValaCallback*) base);
+	self = VALA_CALLBACK (base);
 	return g_strdup ("g_value_set_pointer");
 }
 
 
-ValaTypeReference* vala_callback_get_return_type (ValaCallback* self)
-{
+ValaTypeReference* vala_callback_get_return_type (ValaCallback* self) {
 	g_return_val_if_fail (VALA_IS_CALLBACK (self), NULL);
 	return self->priv->_return_type;
 }
 
 
-void vala_callback_set_return_type (ValaCallback* self, ValaTypeReference* value)
-{
+void vala_callback_set_return_type (ValaCallback* self, ValaTypeReference* value) {
 	ValaTypeReference* _tmp2;
 	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_CALLBACK (self));
@@ -371,22 +352,19 @@ void vala_callback_set_return_type (ValaCallback* self, ValaTypeReference* value
 }
 
 
-gboolean vala_callback_get_instance (ValaCallback* self)
-{
+gboolean vala_callback_get_instance (ValaCallback* self) {
 	g_return_val_if_fail (VALA_IS_CALLBACK (self), FALSE);
 	return self->priv->_instance;
 }
 
 
-void vala_callback_set_instance (ValaCallback* self, gboolean value)
-{
+void vala_callback_set_instance (ValaCallback* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CALLBACK (self));
 	self->priv->_instance = value;
 }
 
 
-static void vala_callback_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_callback_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCallback * self;
 	self = VALA_CALLBACK (object);
 	switch (property_id) {
@@ -403,8 +381,7 @@ static void vala_callback_get_property (GObject * object, guint property_id, GVa
 }
 
 
-static void vala_callback_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_callback_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCallback * self;
 	self = VALA_CALLBACK (object);
 	switch (property_id) {
@@ -421,8 +398,7 @@ static void vala_callback_set_property (GObject * object, guint property_id, con
 }
 
 
-static void vala_callback_class_init (ValaCallbackClass * klass)
-{
+static void vala_callback_class_init (ValaCallbackClass * klass) {
 	vala_callback_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCallbackPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_callback_get_property;
@@ -436,37 +412,30 @@ static void vala_callback_class_init (ValaCallbackClass * klass)
 	VALA_DATA_TYPE_CLASS (klass)->get_marshaller_type_name = vala_callback_real_get_marshaller_type_name;
 	VALA_DATA_TYPE_CLASS (klass)->get_get_value_function = vala_callback_real_get_get_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_set_value_function = vala_callback_real_get_set_value_function;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CALLBACK_RETURN_TYPE, g_param_spec_object ("return-type", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CALLBACK_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CALLBACK_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CALLBACK_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_callback_init (ValaCallback * self)
-{
+static void vala_callback_init (ValaCallback * self) {
 	self->priv = VALA_CALLBACK_GET_PRIVATE (self);
 	self->priv->type_parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_callback_dispose (GObject * obj)
-{
+static void vala_callback_dispose (GObject * obj) {
 	ValaCallback * self;
-	ValaCallbackClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CALLBACK (obj);
 	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
-	klass = VALA_CALLBACK_CLASS (g_type_class_peek (VALA_TYPE_CALLBACK));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_callback_parent_class)->dispose (obj);
 }
 
 
-GType vala_callback_get_type (void)
-{
+GType vala_callback_get_type (void) {
 	static GType vala_callback_type_id = 0;
 	if (G_UNLIKELY (vala_callback_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCallbackClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_callback_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCallback), 0, (GInstanceInitFunc) vala_callback_init };
