@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,8 +21,8 @@
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
 
-#ifndef __VALACODEVISITOR_H__
-#define __VALACODEVISITOR_H__
+#ifndef __VALA_VALACODEVISITOR_H__
+#define __VALA_VALACODEVISITOR_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -72,8 +72,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_type_parameter) (ValaCodeVisitor* self, ValaTypeParameter* p);
 	void (*visit_namespace_reference) (ValaCodeVisitor* self, ValaNamespaceReference* ns);
 	void (*visit_type_reference) (ValaCodeVisitor* self, ValaTypeReference* type);
-	void (*visit_begin_block) (ValaCodeVisitor* self, ValaBlock* b);
-	void (*visit_end_block) (ValaCodeVisitor* self, ValaBlock* b);
+	void (*visit_block) (ValaCodeVisitor* self, ValaBlock* b);
 	void (*visit_empty_statement) (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
 	void (*visit_declaration_statement) (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
 	void (*visit_local_variable_declaration) (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl);
@@ -87,12 +86,10 @@ struct _ValaCodeVisitorClass {
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
-	void (*visit_begin_foreach_statement) (ValaCodeVisitor* self, ValaForeachStatement* stmt);
-	void (*visit_end_foreach_statement) (ValaCodeVisitor* self, ValaForeachStatement* stmt);
+	void (*visit_foreach_statement) (ValaCodeVisitor* self, ValaForeachStatement* stmt);
 	void (*visit_break_statement) (ValaCodeVisitor* self, ValaBreakStatement* stmt);
 	void (*visit_continue_statement) (ValaCodeVisitor* self, ValaContinueStatement* stmt);
-	void (*visit_begin_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
-	void (*visit_end_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
+	void (*visit_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 	void (*visit_throw_statement) (ValaCodeVisitor* self, ValaThrowStatement* stmt);
 	void (*visit_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
 	void (*visit_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
@@ -107,13 +104,11 @@ struct _ValaCodeVisitorClass {
 	void (*visit_literal_expression) (ValaCodeVisitor* self, ValaLiteralExpression* expr);
 	void (*visit_parenthesized_expression) (ValaCodeVisitor* self, ValaParenthesizedExpression* expr);
 	void (*visit_member_access) (ValaCodeVisitor* self, ValaMemberAccess* expr);
-	void (*visit_begin_invocation_expression) (ValaCodeVisitor* self, ValaInvocationExpression* expr);
-	void (*visit_end_invocation_expression) (ValaCodeVisitor* self, ValaInvocationExpression* expr);
+	void (*visit_invocation_expression) (ValaCodeVisitor* self, ValaInvocationExpression* expr);
 	void (*visit_element_access) (ValaCodeVisitor* self, ValaElementAccess* expr);
 	void (*visit_base_access) (ValaCodeVisitor* self, ValaBaseAccess* expr);
 	void (*visit_postfix_expression) (ValaCodeVisitor* self, ValaPostfixExpression* expr);
-	void (*visit_begin_object_creation_expression) (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
-	void (*visit_end_object_creation_expression) (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
+	void (*visit_object_creation_expression) (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
 	void (*visit_sizeof_expression) (ValaCodeVisitor* self, ValaSizeofExpression* expr);
 	void (*visit_typeof_expression) (ValaCodeVisitor* self, ValaTypeofExpression* expr);
 	void (*visit_unary_expression) (ValaCodeVisitor* self, ValaUnaryExpression* expr);
@@ -124,10 +119,8 @@ struct _ValaCodeVisitorClass {
 	void (*visit_binary_expression) (ValaCodeVisitor* self, ValaBinaryExpression* expr);
 	void (*visit_type_check) (ValaCodeVisitor* self, ValaTypeCheck* expr);
 	void (*visit_conditional_expression) (ValaCodeVisitor* self, ValaConditionalExpression* expr);
-	void (*visit_begin_lambda_expression) (ValaCodeVisitor* self, ValaLambdaExpression* expr);
-	void (*visit_end_lambda_expression) (ValaCodeVisitor* self, ValaLambdaExpression* expr);
-	void (*visit_begin_assignment) (ValaCodeVisitor* self, ValaAssignment* a);
-	void (*visit_end_assignment) (ValaCodeVisitor* self, ValaAssignment* a);
+	void (*visit_lambda_expression) (ValaCodeVisitor* self, ValaLambdaExpression* expr);
+	void (*visit_assignment) (ValaCodeVisitor* self, ValaAssignment* a);
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
@@ -154,8 +147,7 @@ void vala_code_visitor_visit_named_argument (ValaCodeVisitor* self, ValaNamedArg
 void vala_code_visitor_visit_type_parameter (ValaCodeVisitor* self, ValaTypeParameter* p);
 void vala_code_visitor_visit_namespace_reference (ValaCodeVisitor* self, ValaNamespaceReference* ns);
 void vala_code_visitor_visit_type_reference (ValaCodeVisitor* self, ValaTypeReference* type);
-void vala_code_visitor_visit_begin_block (ValaCodeVisitor* self, ValaBlock* b);
-void vala_code_visitor_visit_end_block (ValaCodeVisitor* self, ValaBlock* b);
+void vala_code_visitor_visit_block (ValaCodeVisitor* self, ValaBlock* b);
 void vala_code_visitor_visit_empty_statement (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
 void vala_code_visitor_visit_declaration_statement (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
 void vala_code_visitor_visit_local_variable_declaration (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl);
@@ -169,12 +161,10 @@ void vala_code_visitor_visit_switch_label (ValaCodeVisitor* self, ValaSwitchLabe
 void vala_code_visitor_visit_while_statement (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 void vala_code_visitor_visit_do_statement (ValaCodeVisitor* self, ValaDoStatement* stmt);
 void vala_code_visitor_visit_for_statement (ValaCodeVisitor* self, ValaForStatement* stmt);
-void vala_code_visitor_visit_begin_foreach_statement (ValaCodeVisitor* self, ValaForeachStatement* stmt);
-void vala_code_visitor_visit_end_foreach_statement (ValaCodeVisitor* self, ValaForeachStatement* stmt);
+void vala_code_visitor_visit_foreach_statement (ValaCodeVisitor* self, ValaForeachStatement* stmt);
 void vala_code_visitor_visit_break_statement (ValaCodeVisitor* self, ValaBreakStatement* stmt);
 void vala_code_visitor_visit_continue_statement (ValaCodeVisitor* self, ValaContinueStatement* stmt);
-void vala_code_visitor_visit_begin_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
-void vala_code_visitor_visit_end_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
+void vala_code_visitor_visit_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 void vala_code_visitor_visit_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
 void vala_code_visitor_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
 void vala_code_visitor_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
@@ -189,13 +179,11 @@ void vala_code_visitor_visit_null_literal (ValaCodeVisitor* self, ValaNullLitera
 void vala_code_visitor_visit_literal_expression (ValaCodeVisitor* self, ValaLiteralExpression* expr);
 void vala_code_visitor_visit_parenthesized_expression (ValaCodeVisitor* self, ValaParenthesizedExpression* expr);
 void vala_code_visitor_visit_member_access (ValaCodeVisitor* self, ValaMemberAccess* expr);
-void vala_code_visitor_visit_begin_invocation_expression (ValaCodeVisitor* self, ValaInvocationExpression* expr);
-void vala_code_visitor_visit_end_invocation_expression (ValaCodeVisitor* self, ValaInvocationExpression* expr);
+void vala_code_visitor_visit_invocation_expression (ValaCodeVisitor* self, ValaInvocationExpression* expr);
 void vala_code_visitor_visit_element_access (ValaCodeVisitor* self, ValaElementAccess* expr);
 void vala_code_visitor_visit_base_access (ValaCodeVisitor* self, ValaBaseAccess* expr);
 void vala_code_visitor_visit_postfix_expression (ValaCodeVisitor* self, ValaPostfixExpression* expr);
-void vala_code_visitor_visit_begin_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
-void vala_code_visitor_visit_end_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
+void vala_code_visitor_visit_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
 void vala_code_visitor_visit_sizeof_expression (ValaCodeVisitor* self, ValaSizeofExpression* expr);
 void vala_code_visitor_visit_typeof_expression (ValaCodeVisitor* self, ValaTypeofExpression* expr);
 void vala_code_visitor_visit_unary_expression (ValaCodeVisitor* self, ValaUnaryExpression* expr);
@@ -206,10 +194,8 @@ void vala_code_visitor_visit_reference_transfer_expression (ValaCodeVisitor* sel
 void vala_code_visitor_visit_binary_expression (ValaCodeVisitor* self, ValaBinaryExpression* expr);
 void vala_code_visitor_visit_type_check (ValaCodeVisitor* self, ValaTypeCheck* expr);
 void vala_code_visitor_visit_conditional_expression (ValaCodeVisitor* self, ValaConditionalExpression* expr);
-void vala_code_visitor_visit_begin_lambda_expression (ValaCodeVisitor* self, ValaLambdaExpression* expr);
-void vala_code_visitor_visit_end_lambda_expression (ValaCodeVisitor* self, ValaLambdaExpression* expr);
-void vala_code_visitor_visit_begin_assignment (ValaCodeVisitor* self, ValaAssignment* a);
-void vala_code_visitor_visit_end_assignment (ValaCodeVisitor* self, ValaAssignment* a);
+void vala_code_visitor_visit_lambda_expression (ValaCodeVisitor* self, ValaLambdaExpression* expr);
+void vala_code_visitor_visit_assignment (ValaCodeVisitor* self, ValaAssignment* a);
 void vala_code_visitor_visit_end_full_expression (ValaCodeVisitor* self, ValaExpression* expr);
 GType vala_code_visitor_get_type (void);
 
