@@ -1,11 +1,11 @@
 /* valacontinuestatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,19 +19,17 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
-#include "valacontinuestatement.h"
+#include <vala/valacontinuestatement.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valacontinuestatement.h>
 
 enum  {
 	VALA_CONTINUE_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_continue_statement_parent_class = NULL;
+static ValaStatementIface* vala_continue_statement_vala_statement_parent_iface = NULL;
 
 
 /**
@@ -40,22 +38,16 @@ static gpointer vala_continue_statement_parent_class = NULL;
  * @param source reference to source code
  * @return       newly created continue statement
  */
-ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source)
-{
-	GParameter * __params;
-	GParameter * __params_it;
+ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source) {
 	ValaContinueStatement * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_CONTINUE_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CONTINUE_STATEMENT, 0, NULL);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
-static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaContinueStatement * self;
 	self = VALA_CONTINUE_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
@@ -63,24 +55,28 @@ static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVis
 }
 
 
-static void vala_continue_statement_class_init (ValaContinueStatementClass * klass)
-{
+static void vala_continue_statement_class_init (ValaContinueStatementClass * klass) {
 	vala_continue_statement_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_continue_statement_real_accept;
 }
 
 
-static void vala_continue_statement_init (ValaContinueStatement * self)
-{
+static void vala_continue_statement_vala_statement_interface_init (ValaStatementIface * iface) {
+	vala_continue_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
 }
 
 
-GType vala_continue_statement_get_type ()
-{
+static void vala_continue_statement_init (ValaContinueStatement * self) {
+}
+
+
+GType vala_continue_statement_get_type (void) {
 	static GType vala_continue_statement_type_id = 0;
 	if (G_UNLIKELY (vala_continue_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaContinueStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_continue_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaContinueStatement), 0, (GInstanceInitFunc) vala_continue_statement_init };
-		vala_continue_statement_type_id = g_type_register_static (VALA_TYPE_STATEMENT, "ValaContinueStatement", &g_define_type_info, 0);
+		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_continue_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
+		vala_continue_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaContinueStatement", &g_define_type_info, 0);
+		g_type_add_interface_static (vala_continue_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
 	}
 	return vala_continue_statement_type_id;
 }
