@@ -1,11 +1,11 @@
 /* valacreationmethod.vala
  *
- * Copyright (C) 2007  Raffaele Sandrini
+ * Copyright (C) 2007  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,11 +17,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <j@bitron.ch>
+ *	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACREATIONMETHOD_H__
-#define __VALACREATIONMETHOD_H__
+#ifndef __VALA_VALACREATIONMETHOD_H__
+#define __VALA_VALACREATIONMETHOD_H__
 
 #include <glib.h>
 #include <glib-object.h>
