@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valadeclarationstatement.h"
+#include <vala/valadeclarationstatement.h>
 #include <vala/valalocalvariabledeclaration.h>
 #include <vala/valasourcereference.h>
-#include <vala/valadeclarationstatement.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaDeclarationStatementPrivate {
@@ -47,8 +46,7 @@ static void vala_declaration_statement_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created declaration statement
  */
-ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDeclaration* decl, ValaSourceReference* source)
-{
+ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDeclaration* decl, ValaSourceReference* source) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaDeclarationStatement * self;
@@ -68,25 +66,22 @@ ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDecla
 }
 
 
-static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDeclarationStatement * self;
-	self = ((ValaDeclarationStatement*) base);
+	self = VALA_DECLARATION_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_declaration_statement_get_declaration (self)), visitor);
 	vala_code_visitor_visit_declaration_statement (visitor, self);
 }
 
 
-ValaLocalVariableDeclaration* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self)
-{
+ValaLocalVariableDeclaration* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self) {
 	g_return_val_if_fail (VALA_IS_DECLARATION_STATEMENT (self), NULL);
 	return self->priv->_declaration;
 }
 
 
-void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaLocalVariableDeclaration* value)
-{
+void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaLocalVariableDeclaration* value) {
 	ValaLocalVariableDeclaration* _tmp1;
 	g_return_if_fail (VALA_IS_DECLARATION_STATEMENT (self));
 	_tmp1 = NULL;
@@ -94,8 +89,7 @@ void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self,
 }
 
 
-static void vala_declaration_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_declaration_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaDeclarationStatement * self;
 	self = VALA_DECLARATION_STATEMENT (object);
 	switch (property_id) {
@@ -109,8 +103,7 @@ static void vala_declaration_statement_get_property (GObject * object, guint pro
 }
 
 
-static void vala_declaration_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_declaration_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaDeclarationStatement * self;
 	self = VALA_DECLARATION_STATEMENT (object);
 	switch (property_id) {
@@ -124,45 +117,36 @@ static void vala_declaration_statement_set_property (GObject * object, guint pro
 }
 
 
-static void vala_declaration_statement_class_init (ValaDeclarationStatementClass * klass)
-{
+static void vala_declaration_statement_class_init (ValaDeclarationStatementClass * klass) {
 	vala_declaration_statement_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaDeclarationStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_declaration_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_declaration_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_declaration_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_declaration_statement_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DECLARATION_STATEMENT_DECLARATION, g_param_spec_object ("declaration", "foo", "bar", VALA_TYPE_LOCAL_VARIABLE_DECLARATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DECLARATION_STATEMENT_DECLARATION, g_param_spec_object ("declaration", "declaration", "declaration", VALA_TYPE_LOCAL_VARIABLE_DECLARATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_declaration_statement_vala_statement_interface_init (ValaStatementIface * iface)
-{
+static void vala_declaration_statement_vala_statement_interface_init (ValaStatementIface * iface) {
 	vala_declaration_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
 }
 
 
-static void vala_declaration_statement_init (ValaDeclarationStatement * self)
-{
+static void vala_declaration_statement_init (ValaDeclarationStatement * self) {
 	self->priv = VALA_DECLARATION_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_declaration_statement_dispose (GObject * obj)
-{
+static void vala_declaration_statement_dispose (GObject * obj) {
 	ValaDeclarationStatement * self;
-	ValaDeclarationStatementClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_DECLARATION_STATEMENT (obj);
 	(self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL)));
-	klass = VALA_DECLARATION_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_DECLARATION_STATEMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_declaration_statement_parent_class)->dispose (obj);
 }
 
 
-GType vala_declaration_statement_get_type (void)
-{
+GType vala_declaration_statement_get_type (void) {
 	static GType vala_declaration_statement_type_id = 0;
 	if (G_UNLIKELY (vala_declaration_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaDeclarationStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_declaration_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDeclarationStatement), 0, (GInstanceInitFunc) vala_declaration_statement_init };
