@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,11 +21,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaelementaccess.h"
+#include <vala/valaelementaccess.h>
 #include <gee/arraylist.h>
 #include <gee/collection.h>
 #include <gee/readonlylist.h>
-#include <vala/valaelementaccess.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
@@ -43,23 +42,20 @@ static gpointer vala_element_access_parent_class = NULL;
 static void vala_element_access_dispose (GObject * obj);
 
 
-void vala_element_access_append_index (ValaElementAccess* self, ValaExpression* index)
-{
+void vala_element_access_append_index (ValaElementAccess* self, ValaExpression* index) {
 	g_return_if_fail (VALA_IS_ELEMENT_ACCESS (self));
 	g_return_if_fail (VALA_IS_EXPRESSION (index));
 	gee_collection_add (GEE_COLLECTION (self->priv->indices), index);
 }
 
 
-GeeList* vala_element_access_get_indices (ValaElementAccess* self)
-{
+GeeList* vala_element_access_get_indices (ValaElementAccess* self) {
 	g_return_val_if_fail (VALA_IS_ELEMENT_ACCESS (self), NULL);
 	return GEE_LIST (gee_read_only_list_new (g_object_ref, g_object_unref, self->priv->indices));
 }
 
 
-ValaElementAccess* vala_element_access_new (ValaExpression* container, ValaSourceReference* source_reference)
-{
+ValaElementAccess* vala_element_access_new (ValaExpression* container, ValaSourceReference* source_reference) {
 	ValaElementAccess * self;
 	g_return_val_if_fail (container == NULL || VALA_IS_EXPRESSION (container), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
@@ -70,10 +66,9 @@ ValaElementAccess* vala_element_access_new (ValaExpression* container, ValaSourc
 }
 
 
-static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaElementAccess * self;
-	self = ((ValaElementAccess*) base);
+	self = VALA_ELEMENT_ACCESS (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_element_access_get_container (self)), visitor);
 	{
@@ -95,15 +90,13 @@ static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor
 }
 
 
-ValaExpression* vala_element_access_get_container (ValaElementAccess* self)
-{
+ValaExpression* vala_element_access_get_container (ValaElementAccess* self) {
 	g_return_val_if_fail (VALA_IS_ELEMENT_ACCESS (self), NULL);
 	return self->priv->_container;
 }
 
 
-void vala_element_access_set_container (ValaElementAccess* self, ValaExpression* value)
-{
+void vala_element_access_set_container (ValaElementAccess* self, ValaExpression* value) {
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_ELEMENT_ACCESS (self));
 	_tmp1 = NULL;
@@ -111,8 +104,7 @@ void vala_element_access_set_container (ValaElementAccess* self, ValaExpression*
 }
 
 
-static void vala_element_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_element_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaElementAccess * self;
 	self = VALA_ELEMENT_ACCESS (object);
 	switch (property_id) {
@@ -126,8 +118,7 @@ static void vala_element_access_get_property (GObject * object, guint property_i
 }
 
 
-static void vala_element_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_element_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaElementAccess * self;
 	self = VALA_ELEMENT_ACCESS (object);
 	switch (property_id) {
@@ -141,41 +132,33 @@ static void vala_element_access_set_property (GObject * object, guint property_i
 }
 
 
-static void vala_element_access_class_init (ValaElementAccessClass * klass)
-{
+static void vala_element_access_class_init (ValaElementAccessClass * klass) {
 	vala_element_access_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaElementAccessPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_element_access_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_element_access_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_element_access_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_element_access_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ELEMENT_ACCESS_CONTAINER, g_param_spec_object ("container", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ELEMENT_ACCESS_CONTAINER, g_param_spec_object ("container", "container", "container", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_element_access_init (ValaElementAccess * self)
-{
+static void vala_element_access_init (ValaElementAccess * self) {
 	self->priv = VALA_ELEMENT_ACCESS_GET_PRIVATE (self);
 	self->priv->indices = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_element_access_dispose (GObject * obj)
-{
+static void vala_element_access_dispose (GObject * obj) {
 	ValaElementAccess * self;
-	ValaElementAccessClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_ELEMENT_ACCESS (obj);
 	(self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL)));
 	(self->priv->indices == NULL ? NULL : (self->priv->indices = (g_object_unref (self->priv->indices), NULL)));
-	klass = VALA_ELEMENT_ACCESS_CLASS (g_type_class_peek (VALA_TYPE_ELEMENT_ACCESS));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_element_access_parent_class)->dispose (obj);
 }
 
 
-GType vala_element_access_get_type (void)
-{
+GType vala_element_access_get_type (void) {
 	static GType vala_element_access_type_id = 0;
 	if (G_UNLIKELY (vala_element_access_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaElementAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_element_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaElementAccess), 0, (GInstanceInitFunc) vala_element_access_init };
