@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,12 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valafield.h"
+#include <vala/valafield.h>
 #include <vala/valatypereference.h>
 #include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
-#include <vala/valafield.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 #include <vala/valacallback.h>
@@ -59,6 +58,7 @@ static gpointer vala_field_parent_class = NULL;
 static ValaInvokableIface* vala_field_vala_invokable_parent_iface = NULL;
 static ValaLockableIface* vala_field_vala_lockable_parent_iface = NULL;
 static void vala_field_dispose (GObject * obj);
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
 /**
@@ -70,8 +70,7 @@ static void vala_field_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created field
  */
-ValaField* vala_field_new (const char* name, ValaTypeReference* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference)
-{
+ValaField* vala_field_new (const char* name, ValaTypeReference* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference) {
 	ValaField * self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type_reference), NULL);
@@ -86,20 +85,18 @@ ValaField* vala_field_new (const char* name, ValaTypeReference* type_reference,
 }
 
 
-static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaField * self;
-	self = ((ValaField*) base);
+	self = VALA_FIELD (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_field (visitor, self);
 }
 
 
-static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaField * self;
-	self = ((ValaField*) base);
+	self = VALA_FIELD (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_field_get_type_reference (self)), visitor);
 	if (vala_field_get_initializer (self) != NULL) {
@@ -113,50 +110,80 @@ static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor
  *
  * @return the name to be used in C code
  */
-char* vala_field_get_cname (ValaField* self)
-{
-	const char* __temp4;
+char* vala_field_get_cname (ValaField* self) {
+	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	if (self->priv->cname == NULL) {
-		if (!vala_field_get_instance (self)) {
-			char* __temp1;
-			char* __temp0;
-			__temp1 = NULL;
-			__temp0 = NULL;
-			self->priv->cname = (__temp1 = g_strdup_printf ("%s_%s", (__temp0 = vala_symbol_get_lower_case_cname (vala_symbol_get_parent_symbol (((ValaSymbol*) self)), NULL)), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp1);
-			(__temp0 = (g_free (__temp0), NULL));
-		} else {
-			char* __temp3;
-			const char* __temp2;
-			__temp3 = NULL;
-			__temp2 = NULL;
-			self->priv->cname = (__temp3 = (__temp2 = vala_symbol_get_name (((ValaSymbol*) self)), (__temp2 == NULL ? NULL : g_strdup (__temp2))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp3);
-		}
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->cname = (_tmp0 = vala_field_get_default_cname (self), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
 	}
-	__temp4 = NULL;
-	return (__temp4 = self->priv->cname, (__temp4 == NULL ? NULL : g_strdup (__temp4)));
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->cname, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 }
 
 
-static void vala_field_set_cname (ValaField* self, const char* cname)
-{
-	char* __temp6;
+static void vala_field_set_cname (ValaField* self, const char* cname) {
+	char* _tmp0;
 	g_return_if_fail (VALA_IS_FIELD (self));
 	g_return_if_fail (cname != NULL);
-	__temp6 = NULL;
-	self->priv->cname = (__temp6 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp6);
+	_tmp0 = NULL;
+	self->priv->cname = (_tmp0 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
 }
 
 
-static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a)
-{
+/**
+ * Returns the default name of this field as it is used in C code.
+ *
+ * @return the name to be used in C code by default
+ */
+char* vala_field_get_default_cname (ValaField* self) {
+	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
+	if (!vala_field_get_instance (self)) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strconcat ((_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self)), NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	} else {
+		const char* _tmp3;
+		_tmp3 = NULL;
+		return (_tmp3 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+	}
+}
+
+
+static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
-		char* __temp7;
-		__temp7 = NULL;
-		vala_field_set_cname (self, (__temp7 = vala_attribute_get_string (a, "cname")));
-		(__temp7 = (g_free (__temp7), NULL));
+		char* _tmp0;
+		_tmp0 = NULL;
+		vala_field_set_cname (self, (_tmp0 = vala_attribute_get_string (a, "cname")));
+		(_tmp0 = (g_free (_tmp0), NULL));
+	}
+	if (vala_attribute_has_argument (a, "cheader_filename")) {
+		char* val;
+		val = vala_attribute_get_string (a, "cheader_filename");
+		{
+			char** filename_collection;
+			char** filename_it;
+			int filename_collection_length1;
+			filename_collection = g_strsplit (val, ",", 0);
+			filename_collection_length1 = -1;
+			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
+				const char* _tmp1;
+				char* filename;
+				_tmp1 = NULL;
+				filename = (_tmp1 = *filename_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+				{
+					vala_member_add_cheader_filename (VALA_MEMBER (self), filename);
+					(filename = (g_free (filename), NULL));
+				}
+			}
+			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
+		}
+		(val = (g_free (val), NULL));
 	}
 }
 
@@ -164,18 +191,17 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 /**
  * Process all associated attributes.
  */
-void vala_field_process_attributes (ValaField* self)
-{
+void vala_field_process_attributes (ValaField* self) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = ((ValaCodeNode*) self)->attributes;
+		a_collection = VALA_CODE_NODE (self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* __temp8;
+			ValaAttribute* _tmp0;
 			ValaAttribute* a;
-			__temp8 = NULL;
-			a = (__temp8 = a_it->data, (__temp8 == NULL ? NULL : g_object_ref (__temp8)));
+			_tmp0 = NULL;
+			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_field_process_ccode_attribute (self, a);
@@ -191,132 +217,118 @@ void vala_field_process_attributes (ValaField* self)
 }
 
 
-static GeeCollection* vala_field_real_get_parameters (ValaInvokable* base)
-{
+static GeeCollection* vala_field_real_get_parameters (ValaInvokable* base) {
 	ValaField * self;
-	ValaCallback* __temp10;
+	ValaCallback* _tmp1;
 	ValaCallback* cb;
-	GeeCollection* __temp11;
-	self = ((ValaField*) base);
+	GeeCollection* _tmp2;
+	self = VALA_FIELD (base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
-		return GEE_COLLECTION (NULL);
+		return NULL;
 	}
-	__temp10 = NULL;
-	cb = (__temp10 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (__temp10 == NULL ? NULL : g_object_ref (__temp10)));
-	__temp11 = NULL;
-	return (__temp11 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp11);
+	_tmp1 = NULL;
+	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	return (_tmp2 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp2);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
 
 
-static ValaTypeReference* vala_field_real_get_return_type (ValaInvokable* base)
-{
+static ValaTypeReference* vala_field_real_get_return_type (ValaInvokable* base) {
 	ValaField * self;
-	ValaCallback* __temp13;
+	ValaCallback* _tmp1;
 	ValaCallback* cb;
-	ValaTypeReference* __temp14;
-	ValaTypeReference* __temp15;
-	self = ((ValaField*) base);
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp3;
+	self = VALA_FIELD (base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
-		return VALA_TYPE_REFERENCE (NULL);
+		return NULL;
 	}
-	__temp13 = NULL;
-	cb = (__temp13 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (__temp13 == NULL ? NULL : g_object_ref (__temp13)));
-	__temp14 = NULL;
-	__temp15 = NULL;
-	return (__temp15 = (__temp14 = vala_callback_get_return_type (cb), (__temp14 == NULL ? NULL : g_object_ref (__temp14))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp15);
+	_tmp1 = NULL;
+	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	_tmp3 = NULL;
+	return (_tmp3 = (_tmp2 = vala_callback_get_return_type (cb), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp3);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
 
 
-static gboolean vala_field_real_is_invokable (ValaInvokable* base)
-{
+static gboolean vala_field_real_is_invokable (ValaInvokable* base) {
 	ValaField * self;
-	self = ((ValaField*) base);
+	self = VALA_FIELD (base);
 	return (VALA_IS_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))));
 }
 
 
-static gboolean vala_field_real_get_lock_used (ValaLockable* base)
-{
+static gboolean vala_field_real_get_lock_used (ValaLockable* base) {
 	ValaField * self;
-	self = ((ValaField*) base);
+	self = VALA_FIELD (base);
 	return self->priv->lock_used;
 }
 
 
-static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used)
-{
+static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used) {
 	ValaField * self;
-	self = ((ValaField*) base);
+	self = VALA_FIELD (base);
 	self->priv->lock_used = used;
 }
 
 
-ValaTypeReference* vala_field_get_type_reference (ValaField* self)
-{
+ValaTypeReference* vala_field_get_type_reference (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	return self->priv->_type_reference;
 }
 
 
-void vala_field_set_type_reference (ValaField* self, ValaTypeReference* value)
-{
-	ValaTypeReference* __temp19;
+void vala_field_set_type_reference (ValaField* self, ValaTypeReference* value) {
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_FIELD (self));
-	__temp19 = NULL;
-	self->priv->_type_reference = (__temp19 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp19);
+	_tmp1 = NULL;
+	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
 }
 
 
-ValaExpression* vala_field_get_initializer (ValaField* self)
-{
+ValaExpression* vala_field_get_initializer (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	return self->priv->_initializer;
 }
 
 
-void vala_field_set_initializer (ValaField* self, ValaExpression* value)
-{
-	ValaExpression* __temp22;
-	ValaExpression* __temp21;
+void vala_field_set_initializer (ValaField* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_FIELD (self));
-	__temp22 = NULL;
-	__temp21 = NULL;
-	self->priv->_initializer = (__temp22 = (__temp21 = value, (__temp21 == NULL ? NULL : g_object_ref (__temp21))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), __temp22);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
 }
 
 
-gboolean vala_field_get_instance (ValaField* self)
-{
+gboolean vala_field_get_instance (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), FALSE);
 	return self->priv->_instance;
 }
 
 
-void vala_field_set_instance (ValaField* self, gboolean value)
-{
+void vala_field_set_instance (ValaField* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	self->priv->_instance = value;
 }
 
 
-gboolean vala_field_get_no_array_length (ValaField* self)
-{
+gboolean vala_field_get_no_array_length (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), FALSE);
 	return self->priv->_no_array_length;
 }
 
 
-void vala_field_set_no_array_length (ValaField* self, gboolean value)
-{
+void vala_field_set_no_array_length (ValaField* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	self->priv->_no_array_length = value;
 }
 
 
-static void vala_field_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_field_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaField * self;
 	self = VALA_FIELD (object);
 	switch (property_id) {
@@ -332,12 +344,14 @@ static void vala_field_get_property (GObject * object, guint property_id, GValue
 		case VALA_FIELD_NO_ARRAY_LENGTH:
 		g_value_set_boolean (value, vala_field_get_no_array_length (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_field_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_field_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaField * self;
 	self = VALA_FIELD (object);
 	switch (property_id) {
@@ -353,12 +367,14 @@ static void vala_field_set_property (GObject * object, guint property_id, const
 		case VALA_FIELD_NO_ARRAY_LENGTH:
 		vala_field_set_no_array_length (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_field_class_init (ValaFieldClass * klass)
-{
+static void vala_field_class_init (ValaFieldClass * klass) {
 	vala_field_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaFieldPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_field_get_property;
@@ -366,15 +382,14 @@ static void vala_field_class_init (ValaFieldClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_field_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_field_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_field_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INITIALIZER, g_param_spec_object ("initializer", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INITIALIZER, g_param_spec_object ("initializer", "initializer", "initializer", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_field_vala_invokable_interface_init (ValaInvokableIface * iface)
-{
+static void vala_field_vala_invokable_interface_init (ValaInvokableIface * iface) {
 	vala_field_vala_invokable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->get_parameters = vala_field_real_get_parameters;
 	iface->get_return_type = vala_field_real_get_return_type;
@@ -382,39 +397,31 @@ static void vala_field_vala_invokable_interface_init (ValaInvokableIface * iface
 }
 
 
-static void vala_field_vala_lockable_interface_init (ValaLockableIface * iface)
-{
+static void vala_field_vala_lockable_interface_init (ValaLockableIface * iface) {
 	vala_field_vala_lockable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->get_lock_used = vala_field_real_get_lock_used;
 	iface->set_lock_used = vala_field_real_set_lock_used;
 }
 
 
-static void vala_field_init (ValaField * self)
-{
+static void vala_field_init (ValaField * self) {
 	self->priv = VALA_FIELD_GET_PRIVATE (self);
 	self->priv->_instance = TRUE;
 	self->priv->lock_used = FALSE;
 }
 
 
-static void vala_field_dispose (GObject * obj)
-{
+static void vala_field_dispose (GObject * obj) {
 	ValaField * self;
-	ValaFieldClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_FIELD (obj);
 	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
 	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
-	klass = VALA_FIELD_CLASS (g_type_class_peek (VALA_TYPE_FIELD));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_field_parent_class)->dispose (obj);
 }
 
 
-GType vala_field_get_type (void)
-{
+GType vala_field_get_type (void) {
 	static GType vala_field_type_id = 0;
 	if (G_UNLIKELY (vala_field_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaField), 0, (GInstanceInitFunc) vala_field_init };
@@ -428,5 +435,22 @@ GType vala_field_get_type (void)
 }
 
 
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	if (array != NULL && destroy_func != NULL) {
+		int i;
+		if (array_length >= 0)
+		for (i = 0; i < array_length; i = i + 1) {
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
+		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
+	}
+	g_free (array);
+}
+
+
 
 
