@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaifstatement.h"
+#include <vala/valaifstatement.h>
 #include <vala/valablock.h>
 #include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaifstatement.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaIfStatementPrivate {
@@ -54,8 +53,7 @@ static void vala_if_statement_dispose (GObject * obj);
  * @param false_stmt statement to be evaluated if condition is false
  * @return           newly created if statement
  */
-ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_stmt, ValaBlock* false_stmt, ValaSourceReference* source)
-{
+ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_stmt, ValaBlock* false_stmt, ValaSourceReference* source) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaIfStatement * self;
@@ -79,10 +77,9 @@ ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_st
 }
 
 
-static void vala_if_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_if_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaIfStatement * self;
-	self = ((ValaIfStatement*) base);
+	self = VALA_IF_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_if_statement_get_condition (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_if_statement_get_condition (self));
@@ -94,10 +91,9 @@ static void vala_if_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 }
 
 
-static void vala_if_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
-{
+static void vala_if_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
 	ValaIfStatement * self;
-	self = ((ValaIfStatement*) base);
+	self = VALA_IF_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_if_statement_get_condition (self)) == old_node) {
@@ -106,15 +102,13 @@ static void vala_if_statement_real_replace (ValaCodeNode* base, ValaCodeNode* ol
 }
 
 
-ValaExpression* vala_if_statement_get_condition (ValaIfStatement* self)
-{
+ValaExpression* vala_if_statement_get_condition (ValaIfStatement* self) {
 	g_return_val_if_fail (VALA_IS_IF_STATEMENT (self), NULL);
 	return self->priv->_condition;
 }
 
 
-void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* value)
-{
+void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* value) {
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_IF_STATEMENT (self));
 	_tmp1 = NULL;
@@ -123,15 +117,13 @@ void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* val
 }
 
 
-ValaBlock* vala_if_statement_get_true_statement (ValaIfStatement* self)
-{
+ValaBlock* vala_if_statement_get_true_statement (ValaIfStatement* self) {
 	g_return_val_if_fail (VALA_IS_IF_STATEMENT (self), NULL);
 	return self->priv->_true_statement;
 }
 
 
-void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* value)
-{
+void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* value) {
 	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_IF_STATEMENT (self));
 	_tmp1 = NULL;
@@ -139,15 +131,13 @@ void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* val
 }
 
 
-ValaBlock* vala_if_statement_get_false_statement (ValaIfStatement* self)
-{
+ValaBlock* vala_if_statement_get_false_statement (ValaIfStatement* self) {
 	g_return_val_if_fail (VALA_IS_IF_STATEMENT (self), NULL);
 	return self->priv->_false_statement;
 }
 
 
-void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* value)
-{
+void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* value) {
 	ValaBlock* _tmp2;
 	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_IF_STATEMENT (self));
@@ -157,8 +147,7 @@ void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* va
 }
 
 
-static void vala_if_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_if_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaIfStatement * self;
 	self = VALA_IF_STATEMENT (object);
 	switch (property_id) {
@@ -178,8 +167,7 @@ static void vala_if_statement_get_property (GObject * object, guint property_id,
 }
 
 
-static void vala_if_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_if_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaIfStatement * self;
 	self = VALA_IF_STATEMENT (object);
 	switch (property_id) {
@@ -199,8 +187,7 @@ static void vala_if_statement_set_property (GObject * object, guint property_id,
 }
 
 
-static void vala_if_statement_class_init (ValaIfStatementClass * klass)
-{
+static void vala_if_statement_class_init (ValaIfStatementClass * klass) {
 	vala_if_statement_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaIfStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_if_statement_get_property;
@@ -208,41 +195,33 @@ static void vala_if_statement_class_init (ValaIfStatementClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_if_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_if_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace = vala_if_statement_real_replace;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_IF_STATEMENT_CONDITION, g_param_spec_object ("condition", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_IF_STATEMENT_TRUE_STATEMENT, g_param_spec_object ("true-statement", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_IF_STATEMENT_FALSE_STATEMENT, g_param_spec_object ("false-statement", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_IF_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_IF_STATEMENT_TRUE_STATEMENT, g_param_spec_object ("true-statement", "true-statement", "true-statement", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_IF_STATEMENT_FALSE_STATEMENT, g_param_spec_object ("false-statement", "false-statement", "false-statement", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_if_statement_vala_statement_interface_init (ValaStatementIface * iface)
-{
+static void vala_if_statement_vala_statement_interface_init (ValaStatementIface * iface) {
 	vala_if_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
 }
 
 
-static void vala_if_statement_init (ValaIfStatement * self)
-{
+static void vala_if_statement_init (ValaIfStatement * self) {
 	self->priv = VALA_IF_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_if_statement_dispose (GObject * obj)
-{
+static void vala_if_statement_dispose (GObject * obj) {
 	ValaIfStatement * self;
-	ValaIfStatementClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_IF_STATEMENT (obj);
 	(self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (g_object_unref (self->priv->_true_statement), NULL)));
 	(self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (g_object_unref (self->priv->_false_statement), NULL)));
 	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
-	klass = VALA_IF_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_IF_STATEMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_if_statement_parent_class)->dispose (obj);
 }
 
 
-GType vala_if_statement_get_type (void)
-{
+GType vala_if_statement_get_type (void) {
 	static GType vala_if_statement_type_id = 0;
 	if (G_UNLIKELY (vala_if_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaIfStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_if_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaIfStatement), 0, (GInstanceInitFunc) vala_if_statement_init };
