@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,12 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valainvocationexpression.h"
+#include <vala/valainvocationexpression.h>
 #include <gee/arraylist.h>
 #include <gee/readonlycollection.h>
 #include <gee/readonlylist.h>
 #include <vala/valasourcereference.h>
-#include <vala/valainvocationexpression.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaInvocationExpressionPrivate {
@@ -38,6 +37,7 @@ enum  {
 	VALA_INVOCATION_EXPRESSION_CALL
 };
 static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_invocation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_invocation_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
 static gpointer vala_invocation_expression_parent_class = NULL;
 static void vala_invocation_expression_dispose (GObject * obj);
@@ -50,8 +50,7 @@ static void vala_invocation_expression_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created invocation expression
  */
-ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call, ValaSourceReference* source_reference)
-{
+ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call, ValaSourceReference* source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaInvocationExpression * self;
@@ -76,8 +75,7 @@ ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call,
  *
  * @param arg an argument
  */
-void vala_invocation_expression_add_argument (ValaInvocationExpression* self, ValaExpression* arg)
-{
+void vala_invocation_expression_add_argument (ValaInvocationExpression* self, ValaExpression* arg) {
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
 	g_return_if_fail (VALA_IS_EXPRESSION (arg));
 	gee_collection_add (GEE_COLLECTION (self->priv->argument_list), arg);
@@ -90,8 +88,7 @@ void vala_invocation_expression_add_argument (ValaInvocationExpression* self, Va
  *
  * @return argument list
  */
-GeeCollection* vala_invocation_expression_get_argument_list (ValaInvocationExpression* self)
-{
+GeeCollection* vala_invocation_expression_get_argument_list (ValaInvocationExpression* self) {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->argument_list)));
 }
@@ -100,8 +97,7 @@ GeeCollection* vala_invocation_expression_get_argument_list (ValaInvocationExpre
 /**
  * Add an array size C code expression.
  */
-void vala_invocation_expression_append_array_size (ValaInvocationExpression* self, ValaCCodeExpression* size)
-{
+void vala_invocation_expression_append_array_size (ValaInvocationExpression* self, ValaCCodeExpression* size) {
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
 	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (size));
 	gee_collection_add (GEE_COLLECTION (self->priv->array_sizes), size);
@@ -112,20 +108,25 @@ void vala_invocation_expression_append_array_size (ValaInvocationExpression* sel
  * Get the C code expression for array sizes for all dimensions
  * ascending from left to right.
  */
-GeeList* vala_invocation_expression_get_array_sizes (ValaInvocationExpression* self)
-{
+GeeList* vala_invocation_expression_get_array_sizes (ValaInvocationExpression* self) {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
 	return GEE_LIST (gee_read_only_list_new (g_object_ref, g_object_unref, self->priv->array_sizes));
 }
 
 
-static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInvocationExpression * self;
-	self = ((ValaInvocationExpression*) base);
+	self = VALA_INVOCATION_EXPRESSION (base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_invocation_expression (visitor, self);
+}
+
+
+static void vala_invocation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
+	ValaInvocationExpression * self;
+	self = VALA_INVOCATION_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_invocation_expression_get_call (self)), visitor);
-	vala_code_visitor_visit_begin_invocation_expression (visitor, self);
 	{
 		GeeList* expr_collection;
 		GeeIterator* expr_it;
@@ -141,15 +142,13 @@ static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCode
 		}
 		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
-	vala_code_visitor_visit_end_invocation_expression (visitor, self);
 }
 
 
-static void vala_invocation_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
-{
+static void vala_invocation_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
 	ValaInvocationExpression * self;
 	gint index;
-	self = ((ValaInvocationExpression*) base);
+	self = VALA_INVOCATION_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_invocation_expression_get_call (self)) == old_node) {
@@ -163,15 +162,13 @@ static void vala_invocation_expression_real_replace (ValaCodeNode* base, ValaCod
 }
 
 
-ValaExpression* vala_invocation_expression_get_call (ValaInvocationExpression* self)
-{
+ValaExpression* vala_invocation_expression_get_call (ValaInvocationExpression* self) {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
 	return self->_call;
 }
 
 
-void vala_invocation_expression_set_call (ValaInvocationExpression* self, ValaExpression* value)
-{
+void vala_invocation_expression_set_call (ValaInvocationExpression* self, ValaExpression* value) {
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
 	_tmp1 = NULL;
@@ -180,8 +177,7 @@ void vala_invocation_expression_set_call (ValaInvocationExpression* self, ValaEx
 }
 
 
-static void vala_invocation_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_invocation_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (object);
 	switch (property_id) {
@@ -195,8 +191,7 @@ static void vala_invocation_expression_get_property (GObject * object, guint pro
 }
 
 
-static void vala_invocation_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_invocation_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (object);
 	switch (property_id) {
@@ -210,44 +205,37 @@ static void vala_invocation_expression_set_property (GObject * object, guint pro
 }
 
 
-static void vala_invocation_expression_class_init (ValaInvocationExpressionClass * klass)
-{
+static void vala_invocation_expression_class_init (ValaInvocationExpressionClass * klass) {
 	vala_invocation_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaInvocationExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_invocation_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_invocation_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_invocation_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_invocation_expression_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_invocation_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace = vala_invocation_expression_real_replace;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INVOCATION_EXPRESSION_CALL, g_param_spec_object ("call", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INVOCATION_EXPRESSION_CALL, g_param_spec_object ("call", "call", "call", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_invocation_expression_init (ValaInvocationExpression * self)
-{
+static void vala_invocation_expression_init (ValaInvocationExpression * self) {
 	self->priv = VALA_INVOCATION_EXPRESSION_GET_PRIVATE (self);
 	self->priv->argument_list = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->array_sizes = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_invocation_expression_dispose (GObject * obj)
-{
+static void vala_invocation_expression_dispose (GObject * obj) {
 	ValaInvocationExpression * self;
-	ValaInvocationExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_INVOCATION_EXPRESSION (obj);
 	(self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL)));
 	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (g_object_unref (self->priv->argument_list), NULL)));
 	(self->priv->array_sizes == NULL ? NULL : (self->priv->array_sizes = (g_object_unref (self->priv->array_sizes), NULL)));
-	klass = VALA_INVOCATION_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_INVOCATION_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_invocation_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_invocation_expression_get_type (void)
-{
+GType vala_invocation_expression_get_type (void) {
 	static GType vala_invocation_expression_type_id = 0;
 	if (G_UNLIKELY (vala_invocation_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaInvocationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_invocation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInvocationExpression), 0, (GInstanceInitFunc) vala_invocation_expression_init };
