@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,9 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaliteral.h"
-#include <vala/valatypereference.h>
 #include <vala/valaliteral.h>
+#include <vala/valatypereference.h>
 
 struct _ValaLiteralPrivate {
 	ValaTypeReference* _static_type;
@@ -36,15 +35,13 @@ static gpointer vala_literal_parent_class = NULL;
 static void vala_literal_dispose (GObject * obj);
 
 
-ValaTypeReference* vala_literal_get_static_type (ValaLiteral* self)
-{
+ValaTypeReference* vala_literal_get_static_type (ValaLiteral* self) {
 	g_return_val_if_fail (VALA_IS_LITERAL (self), NULL);
 	return self->priv->_static_type;
 }
 
 
-void vala_literal_set_static_type (ValaLiteral* self, ValaTypeReference* value)
-{
+void vala_literal_set_static_type (ValaLiteral* self, ValaTypeReference* value) {
 	ValaTypeReference* _tmp2;
 	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_LITERAL (self));
@@ -54,8 +51,7 @@ void vala_literal_set_static_type (ValaLiteral* self, ValaTypeReference* value)
 }
 
 
-static void vala_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaLiteral * self;
 	self = VALA_LITERAL (object);
 	switch (property_id) {
@@ -69,8 +65,7 @@ static void vala_literal_get_property (GObject * object, guint property_id, GVal
 }
 
 
-static void vala_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaLiteral * self;
 	self = VALA_LITERAL (object);
 	switch (property_id) {
@@ -84,38 +79,30 @@ static void vala_literal_set_property (GObject * object, guint property_id, cons
 }
 
 
-static void vala_literal_class_init (ValaLiteralClass * klass)
-{
+static void vala_literal_class_init (ValaLiteralClass * klass) {
 	vala_literal_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaLiteralPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_literal_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_literal_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_literal_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_LITERAL_STATIC_TYPE, g_param_spec_object ("static-type", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_LITERAL_STATIC_TYPE, g_param_spec_object ("static-type", "static-type", "static-type", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_literal_init (ValaLiteral * self)
-{
+static void vala_literal_init (ValaLiteral * self) {
 	self->priv = VALA_LITERAL_GET_PRIVATE (self);
 }
 
 
-static void vala_literal_dispose (GObject * obj)
-{
+static void vala_literal_dispose (GObject * obj) {
 	ValaLiteral * self;
-	ValaLiteralClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_LITERAL (obj);
 	(self->priv->_static_type == NULL ? NULL : (self->priv->_static_type = (g_object_unref (self->priv->_static_type), NULL)));
-	klass = VALA_LITERAL_CLASS (g_type_class_peek (VALA_TYPE_LITERAL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_literal_parent_class)->dispose (obj);
 }
 
 
-GType vala_literal_get_type (void)
-{
+GType vala_literal_get_type (void) {
 	static GType vala_literal_type_id = 0;
 	if (G_UNLIKELY (vala_literal_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLiteral), 0, (GInstanceInitFunc) vala_literal_init };
