@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,17 +20,17 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valamemberaccess.h"
+#include <vala/valamemberaccess.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
 #include <vala/valasourcereference.h>
-#include <vala/valamemberaccess.h>
 #include <vala/valatypereference.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaMemberAccessPrivate {
 	char* _member_name;
+	gboolean _prototype_access;
 	ValaExpression* _inner;
 	GeeList* type_argument_list;
 };
@@ -38,7 +38,8 @@ struct _ValaMemberAccessPrivate {
 enum  {
 	VALA_MEMBER_ACCESS_DUMMY_PROPERTY,
 	VALA_MEMBER_ACCESS_INNER,
-	VALA_MEMBER_ACCESS_MEMBER_NAME
+	VALA_MEMBER_ACCESS_MEMBER_NAME,
+	VALA_MEMBER_ACCESS_PROTOTYPE_ACCESS
 };
 static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_member_access_real_to_string (ValaCodeNode* base);
@@ -55,8 +56,7 @@ static void vala_member_access_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created member access expression
  */
-ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference)
-{
+ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference) {
 	ValaMemberAccess * self;
 	g_return_val_if_fail (inner == NULL || VALA_IS_EXPRESSION (inner), NULL);
 	g_return_val_if_fail (member_name != NULL, NULL);
@@ -69,8 +69,7 @@ ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* mem
 }
 
 
-ValaMemberAccess* vala_member_access_new_simple (const char* member_name, ValaSourceReference* source_reference)
-{
+ValaMemberAccess* vala_member_access_new_simple (const char* member_name, ValaSourceReference* source_reference) {
 	ValaMemberAccess * self;
 	g_return_val_if_fail (member_name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
@@ -86,8 +85,7 @@ ValaMemberAccess* vala_member_access_new_simple (const char* member_name, ValaSo
  *
  * @param arg a type reference
  */
-void vala_member_access_add_type_argument (ValaMemberAccess* self, ValaTypeReference* arg)
-{
+void vala_member_access_add_type_argument (ValaMemberAccess* self, ValaTypeReference* arg) {
 	g_return_if_fail (VALA_IS_MEMBER_ACCESS (self));
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (arg));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_argument_list), arg);
@@ -99,17 +97,15 @@ void vala_member_access_add_type_argument (ValaMemberAccess* self, ValaTypeRefer
  *
  * @return type argument list
  */
-GeeCollection* vala_member_access_get_type_arguments (ValaMemberAccess* self)
-{
+GeeCollection* vala_member_access_get_type_arguments (ValaMemberAccess* self) {
 	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->type_argument_list)));
 }
 
 
-static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMemberAccess * self;
-	self = ((ValaMemberAccess*) base);
+	self = VALA_MEMBER_ACCESS (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_member_access_get_inner (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_member_access_get_inner (self)), visitor);
@@ -133,26 +129,24 @@ static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 }
 
 
-static char* vala_member_access_real_to_string (ValaCodeNode* base)
-{
+static char* vala_member_access_real_to_string (ValaCodeNode* base) {
 	ValaMemberAccess * self;
-	self = ((ValaMemberAccess*) base);
+	self = VALA_MEMBER_ACCESS (base);
 	if (vala_member_access_get_inner (self) == NULL) {
 		return g_strdup (vala_member_access_get_member_name (self));
 	} else {
-		char* __temp2;
-		char* __temp3;
-		__temp2 = NULL;
-		__temp3 = NULL;
-		return (__temp3 = g_strdup_printf ("%s.%s", (__temp2 = vala_code_node_to_string (VALA_CODE_NODE (vala_member_access_get_inner (self)))), vala_member_access_get_member_name (self)), (__temp2 = (g_free (__temp2), NULL)), __temp3);
+		char* _tmp1;
+		char* _tmp2;
+		_tmp1 = NULL;
+		_tmp2 = NULL;
+		return (_tmp2 = g_strdup_printf ("%s.%s", (_tmp1 = vala_code_node_to_string (VALA_CODE_NODE (vala_member_access_get_inner (self)))), vala_member_access_get_member_name (self)), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
 	}
 }
 
 
-static void vala_member_access_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
-{
+static void vala_member_access_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
 	ValaMemberAccess * self;
-	self = ((ValaMemberAccess*) base);
+	self = VALA_MEMBER_ACCESS (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_member_access_get_inner (self)) == old_node) {
@@ -161,45 +155,52 @@ static void vala_member_access_real_replace (ValaCodeNode* base, ValaCodeNode* o
 }
 
 
-ValaExpression* vala_member_access_get_inner (ValaMemberAccess* self)
-{
+ValaExpression* vala_member_access_get_inner (ValaMemberAccess* self) {
 	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (self), NULL);
 	return self->priv->_inner;
 }
 
 
-void vala_member_access_set_inner (ValaMemberAccess* self, ValaExpression* value)
-{
-	ValaExpression* __temp7;
-	ValaExpression* __temp6;
+void vala_member_access_set_inner (ValaMemberAccess* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_MEMBER_ACCESS (self));
-	__temp7 = NULL;
-	__temp6 = NULL;
-	self->priv->_inner = (__temp7 = (__temp6 = value, (__temp6 == NULL ? NULL : g_object_ref (__temp6))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp7);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 	if (self->priv->_inner != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 	}
 }
 
 
-char* vala_member_access_get_member_name (ValaMemberAccess* self)
-{
+char* vala_member_access_get_member_name (ValaMemberAccess* self) {
 	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (self), NULL);
 	return self->priv->_member_name;
 }
 
 
-void vala_member_access_set_member_name (ValaMemberAccess* self, const char* value)
-{
-	char* __temp9;
+void vala_member_access_set_member_name (ValaMemberAccess* self, const char* value) {
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_MEMBER_ACCESS (self));
-	__temp9 = NULL;
-	self->priv->_member_name = (__temp9 = g_strdup (value), (self->priv->_member_name = (g_free (self->priv->_member_name), NULL)), __temp9);
+	_tmp1 = NULL;
+	self->priv->_member_name = (_tmp1 = g_strdup (value), (self->priv->_member_name = (g_free (self->priv->_member_name), NULL)), _tmp1);
 }
 
 
-static void vala_member_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+gboolean vala_member_access_get_prototype_access (ValaMemberAccess* self) {
+	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (self), FALSE);
+	return self->priv->_prototype_access;
+}
+
+
+void vala_member_access_set_prototype_access (ValaMemberAccess* self, gboolean value) {
+	g_return_if_fail (VALA_IS_MEMBER_ACCESS (self));
+	self->priv->_prototype_access = value;
+}
+
+
+static void vala_member_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaMemberAccess * self;
 	self = VALA_MEMBER_ACCESS (object);
 	switch (property_id) {
@@ -209,12 +210,17 @@ static void vala_member_access_get_property (GObject * object, guint property_id
 		case VALA_MEMBER_ACCESS_MEMBER_NAME:
 		g_value_set_string (value, vala_member_access_get_member_name (self));
 		break;
+		case VALA_MEMBER_ACCESS_PROTOTYPE_ACCESS:
+		g_value_set_boolean (value, vala_member_access_get_prototype_access (self));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_member_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_member_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaMemberAccess * self;
 	self = VALA_MEMBER_ACCESS (object);
 	switch (property_id) {
@@ -224,12 +230,17 @@ static void vala_member_access_set_property (GObject * object, guint property_id
 		case VALA_MEMBER_ACCESS_MEMBER_NAME:
 		vala_member_access_set_member_name (self, g_value_get_string (value));
 		break;
+		case VALA_MEMBER_ACCESS_PROTOTYPE_ACCESS:
+		vala_member_access_set_prototype_access (self, g_value_get_boolean (value));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_member_access_class_init (ValaMemberAccessClass * klass)
-{
+static void vala_member_access_class_init (ValaMemberAccessClass * klass) {
 	vala_member_access_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaMemberAccessPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_member_access_get_property;
@@ -238,35 +249,29 @@ static void vala_member_access_class_init (ValaMemberAccessClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_member_access_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_member_access_real_to_string;
 	VALA_CODE_NODE_CLASS (klass)->replace = vala_member_access_real_replace;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_MEMBER_NAME, g_param_spec_string ("member-name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_MEMBER_NAME, g_param_spec_string ("member-name", "member-name", "member-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_PROTOTYPE_ACCESS, g_param_spec_boolean ("prototype-access", "prototype-access", "prototype-access", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_member_access_init (ValaMemberAccess * self)
-{
+static void vala_member_access_init (ValaMemberAccess * self) {
 	self->priv = VALA_MEMBER_ACCESS_GET_PRIVATE (self);
 	self->priv->type_argument_list = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_member_access_dispose (GObject * obj)
-{
+static void vala_member_access_dispose (GObject * obj) {
 	ValaMemberAccess * self;
-	ValaMemberAccessClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_MEMBER_ACCESS (obj);
 	(self->priv->_member_name = (g_free (self->priv->_member_name), NULL));
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_object_unref (self->priv->type_argument_list), NULL)));
-	klass = VALA_MEMBER_ACCESS_CLASS (g_type_class_peek (VALA_TYPE_MEMBER_ACCESS));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_member_access_parent_class)->dispose (obj);
 }
 
 
-GType vala_member_access_get_type (void)
-{
+GType vala_member_access_get_type (void) {
 	static GType vala_member_access_type_id = 0;
 	if (G_UNLIKELY (vala_member_access_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMemberAccess), 0, (GInstanceInitFunc) vala_member_access_init };
