@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,8 +21,8 @@
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
 
-#ifndef __VALAMETHOD_H__
-#define __VALAMETHOD_H__
+#ifndef __VALA_VALAMETHOD_H__
+#define __VALA_VALAMETHOD_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -88,8 +88,6 @@ gboolean vala_method_get_returns_modified_pointer (ValaMethod* self);
 void vala_method_set_returns_modified_pointer (ValaMethod* self, gboolean value);
 gboolean vala_method_get_instance_last (ValaMethod* self);
 void vala_method_set_instance_last (ValaMethod* self, gboolean value);
-gboolean vala_method_get_instance_by_reference (ValaMethod* self);
-void vala_method_set_instance_by_reference (ValaMethod* self, gboolean value);
 ValaMethod* vala_method_get_base_method (ValaMethod* self);
 void vala_method_set_base_method (ValaMethod* self, ValaMethod* value);
 ValaMethod* vala_method_get_base_interface_method (ValaMethod* self);
