@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,12 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valanamespace.h"
+#include <vala/valanamespace.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
 #include <gee/readonlycollection.h>
 #include <vala/valasourcereference.h>
-#include <vala/valanamespace.h>
 #include <vala/valascope.h>
 #include <vala/valaclass.h>
 #include <vala/valainterface.h>
@@ -50,7 +48,7 @@ struct _ValaNamespacePrivate {
 	GeeList* constants;
 	GeeList* fields;
 	GeeList* methods;
-	char* cprefix;
+	GeeList* cprefixes;
 	char* lower_case_cprefix;
 	GeeList* cheader_filenames;
 	GeeList* namespaces;
@@ -78,8 +76,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
  * @param source_reference reference to source code
  * @return                 newly created namespace
  */
-ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source_reference)
-{
+ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source_reference) {
 	ValaNamespace * self;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_NAMESPACE, 0, NULL);
@@ -95,12 +92,11 @@ ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source
  *
  * @param ns a namespace
  */
-void vala_namespace_add_namespace (ValaNamespace* self, ValaNamespace* ns)
-{
+void vala_namespace_add_namespace (ValaNamespace* self, ValaNamespace* ns) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_NAMESPACE (ns));
 	gee_collection_add (GEE_COLLECTION (self->priv->namespaces), ns);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) ns)), VALA_SYMBOL (ns));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (ns)), VALA_SYMBOL (ns));
 }
 
 
@@ -109,8 +105,7 @@ void vala_namespace_add_namespace (ValaNamespace* self, ValaNamespace* ns)
  *
  * @return namespace list
  */
-GeeCollection* vala_namespace_get_namespaces (ValaNamespace* self)
-{
+GeeCollection* vala_namespace_get_namespaces (ValaNamespace* self) {
 	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->namespaces)));
 }
@@ -121,12 +116,11 @@ GeeCollection* vala_namespace_get_namespaces (ValaNamespace* self)
  *
  * @param cl a class
  */
-void vala_namespace_add_class (ValaNamespace* self, ValaClass* cl)
-{
+void vala_namespace_add_class (ValaNamespace* self, ValaClass* cl) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_CLASS (cl));
 	gee_collection_add (GEE_COLLECTION (self->priv->classes), cl);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) cl)), VALA_SYMBOL (cl));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cl)), VALA_SYMBOL (cl));
 }
 
 
@@ -135,12 +129,11 @@ void vala_namespace_add_class (ValaNamespace* self, ValaClass* cl)
  *
  * @param iface an interface
  */
-void vala_namespace_add_interface (ValaNamespace* self, ValaInterface* iface)
-{
+void vala_namespace_add_interface (ValaNamespace* self, ValaInterface* iface) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_INTERFACE (iface));
 	gee_collection_add (GEE_COLLECTION (self->priv->interfaces), iface);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) iface)), VALA_SYMBOL (iface));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (iface)), VALA_SYMBOL (iface));
 }
 
 
@@ -149,12 +142,11 @@ void vala_namespace_add_interface (ValaNamespace* self, ValaInterface* iface)
  *
  * @param st a struct
  */
-void vala_namespace_add_struct (ValaNamespace* self, ValaStruct* st)
-{
+void vala_namespace_add_struct (ValaNamespace* self, ValaStruct* st) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_STRUCT (st));
 	gee_collection_add (GEE_COLLECTION (self->priv->structs), st);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) st)), VALA_SYMBOL (st));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (st)), VALA_SYMBOL (st));
 }
 
 
@@ -163,12 +155,11 @@ void vala_namespace_add_struct (ValaNamespace* self, ValaStruct* st)
  *
  * @param en an enum
  */
-void vala_namespace_add_enum (ValaNamespace* self, ValaEnum* en)
-{
+void vala_namespace_add_enum (ValaNamespace* self, ValaEnum* en) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_ENUM (en));
 	gee_collection_add (GEE_COLLECTION (self->priv->enums), en);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) en)), VALA_SYMBOL (en));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (en)), VALA_SYMBOL (en));
 }
 
 
@@ -177,12 +168,11 @@ void vala_namespace_add_enum (ValaNamespace* self, ValaEnum* en)
  *
  * @param cb a callback
  */
-void vala_namespace_add_callback (ValaNamespace* self, ValaCallback* cb)
-{
+void vala_namespace_add_callback (ValaNamespace* self, ValaCallback* cb) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_CALLBACK (cb));
 	gee_collection_add (GEE_COLLECTION (self->priv->callbacks), cb);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) cb)), VALA_SYMBOL (cb));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cb)), VALA_SYMBOL (cb));
 }
 
 
@@ -191,8 +181,7 @@ void vala_namespace_add_callback (ValaNamespace* self, ValaCallback* cb)
  *
  * @return struct list
  */
-GeeCollection* vala_namespace_get_structs (ValaNamespace* self)
-{
+GeeCollection* vala_namespace_get_structs (ValaNamespace* self) {
 	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->structs)));
 }
@@ -203,8 +192,7 @@ GeeCollection* vala_namespace_get_structs (ValaNamespace* self)
  *
  * @return class list
  */
-GeeCollection* vala_namespace_get_classes (ValaNamespace* self)
-{
+GeeCollection* vala_namespace_get_classes (ValaNamespace* self) {
 	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->classes)));
 }
@@ -215,8 +203,7 @@ GeeCollection* vala_namespace_get_classes (ValaNamespace* self)
  *
  * @return interface list
  */
-GeeCollection* vala_namespace_get_interfaces (ValaNamespace* self)
-{
+GeeCollection* vala_namespace_get_interfaces (ValaNamespace* self) {
 	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->interfaces)));
 }
@@ -227,12 +214,11 @@ GeeCollection* vala_namespace_get_interfaces (ValaNamespace* self)
  *
  * @param constant a constant
  */
-void vala_namespace_add_constant (ValaNamespace* self, ValaConstant* constant)
-{
+void vala_namespace_add_constant (ValaNamespace* self, ValaConstant* constant) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_CONSTANT (constant));
 	gee_collection_add (GEE_COLLECTION (self->priv->constants), constant);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) constant)), VALA_SYMBOL (constant));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (constant)), VALA_SYMBOL (constant));
 }
 
 
@@ -241,12 +227,11 @@ void vala_namespace_add_constant (ValaNamespace* self, ValaConstant* constant)
  *
  * @param f a field
  */
-void vala_namespace_add_field (ValaNamespace* self, ValaField* f)
-{
+void vala_namespace_add_field (ValaNamespace* self, ValaField* f) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_FIELD (f));
 	gee_collection_add (GEE_COLLECTION (self->priv->fields), f);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) f)), VALA_SYMBOL (f));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (f)), VALA_SYMBOL (f));
 }
 
 
@@ -255,38 +240,35 @@ void vala_namespace_add_field (ValaNamespace* self, ValaField* f)
  *
  * @param m a method
  */
-void vala_namespace_add_method (ValaNamespace* self, ValaMethod* m)
-{
+void vala_namespace_add_method (ValaNamespace* self, ValaMethod* m) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_METHOD (m));
 	if (VALA_IS_CREATION_METHOD (m)) {
-		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) m)), "construction methods may only be declared within classes and structs");
+		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), "construction methods may only be declared within classes and structs");
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
 		return;
 	}
 	if (vala_method_get_instance (m)) {
-		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) m)), "instance methods not allowed outside of data types");
+		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), "instance methods not allowed outside of data types");
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
 		return;
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) m)), VALA_SYMBOL (m));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (m)), VALA_SYMBOL (m));
 }
 
 
-static void vala_namespace_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_namespace_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNamespace * self;
-	self = ((ValaNamespace*) base);
+	self = VALA_NAMESPACE (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_namespace (visitor, self);
 }
 
 
-static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNamespace * self;
-	self = ((ValaNamespace*) base);
+	self = VALA_NAMESPACE (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* ns_collection;
@@ -427,43 +409,45 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 }
 
 
-static char* vala_namespace_real_get_cprefix (ValaSymbol* base)
-{
+static char* vala_namespace_real_get_cprefix (ValaSymbol* base) {
 	ValaNamespace * self;
-	const char* _tmp3;
-	self = ((ValaNamespace*) base);
-	if (self->priv->cprefix == NULL) {
-		if (vala_symbol_get_name (((ValaSymbol*) self)) == NULL) {
-			char* _tmp0;
-			_tmp0 = NULL;
-			self->priv->cprefix = (_tmp0 = g_strdup (""), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp0);
-		} else {
-			char* _tmp2;
+	self = VALA_NAMESPACE (base);
+	if (gee_collection_get_size (GEE_COLLECTION (self->priv->cprefixes)) > 0) {
+		return gee_list_get (((GeeList*) self->priv->cprefixes), 0);
+	} else {
+		if (NULL != vala_symbol_get_name (VALA_SYMBOL (self))) {
 			const char* _tmp1;
-			_tmp2 = NULL;
 			_tmp1 = NULL;
-			self->priv->cprefix = (_tmp2 = (_tmp1 = vala_symbol_get_name (((ValaSymbol*) self)), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp2);
+			return (_tmp1 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+		} else {
+			return g_strdup ("");
 		}
 	}
-	_tmp3 = NULL;
-	return (_tmp3 = self->priv->cprefix, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+}
+
+
+GeeList* vala_namespace_get_cprefixes (ValaNamespace* self) {
+	GeeList* _tmp0;
+	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
+	if (0 == gee_collection_get_size (GEE_COLLECTION (self->priv->cprefixes)) && NULL != vala_symbol_get_name (VALA_SYMBOL (self))) {
+		gee_collection_add (GEE_COLLECTION (self->priv->cprefixes), vala_symbol_get_name (VALA_SYMBOL (self)));
+	}
+	_tmp0 = NULL;
+	return (_tmp0 = self->priv->cprefixes, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 }
 
 
 /**
- * Sets the camel case string to be prepended to the name of members of
+ * Adds a camel case string to be prepended to the name of members of
  * this namespace when used in C code.
  *
- * @param cprefix the camel case prefix to be used in C code
+ * @param cprefixes the camel case prefixes used in C code
  */
-void vala_namespace_set_cprefix (ValaNamespace* self, const char* cprefix)
-{
-	char* _tmp1;
-	const char* _tmp0;
+void vala_namespace_add_cprefix (ValaNamespace* self, const char* cprefix) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->priv->cprefix = (_tmp1 = (_tmp0 = cprefix, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
+	g_return_if_fail (cprefix != NULL);
+	g_return_if_fail (g_utf8_strlen (cprefix, -1) >= 1);
+	gee_collection_add (GEE_COLLECTION (self->priv->cprefixes), cprefix);
 }
 
 
@@ -473,13 +457,12 @@ void vala_namespace_set_cprefix (ValaNamespace* self, const char* cprefix)
  *
  * @return the lower case prefix to be used in C code
  */
-static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base)
-{
+static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base) {
 	ValaNamespace * self;
 	const char* _tmp3;
-	self = ((ValaNamespace*) base);
+	self = VALA_NAMESPACE (base);
 	if (self->priv->lower_case_cprefix == NULL) {
-		if (vala_symbol_get_name (((ValaSymbol*) self)) == NULL) {
+		if (vala_symbol_get_name (VALA_SYMBOL (self)) == NULL) {
 			char* _tmp0;
 			_tmp0 = NULL;
 			self->priv->lower_case_cprefix = (_tmp0 = g_strdup (""), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp0);
@@ -488,7 +471,7 @@ static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base)
 			char* _tmp1;
 			_tmp2 = NULL;
 			_tmp1 = NULL;
-			self->priv->lower_case_cprefix = (_tmp2 = g_strdup_printf ("%s_", (_tmp1 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp2);
+			self->priv->lower_case_cprefix = (_tmp2 = g_strdup_printf ("%s_", (_tmp1 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp2);
 			(_tmp1 = (g_free (_tmp1), NULL));
 		}
 	}
@@ -503,8 +486,7 @@ static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base)
  *
  * @param cprefix the lower case prefix to be used in C code
  */
-void vala_namespace_set_lower_case_cprefix (ValaNamespace* self, const char* cprefix)
-{
+void vala_namespace_set_lower_case_cprefix (ValaNamespace* self, const char* cprefix) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
@@ -514,10 +496,9 @@ void vala_namespace_set_lower_case_cprefix (ValaNamespace* self, const char* cpr
 }
 
 
-static GeeCollection* vala_namespace_real_get_cheader_filenames (ValaSymbol* base)
-{
+static GeeCollection* vala_namespace_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaNamespace * self;
-	self = ((ValaNamespace*) base);
+	self = VALA_NAMESPACE (base);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->cheader_filenames)));
 }
 
@@ -527,8 +508,7 @@ static GeeCollection* vala_namespace_real_get_cheader_filenames (ValaSymbol* bas
  *
  * @return header filename
  */
-char* vala_namespace_get_cheader_filename (ValaNamespace* self)
-{
+char* vala_namespace_get_cheader_filename (ValaNamespace* self) {
 	GString* s;
 	gboolean first;
 	const char* _tmp0;
@@ -570,8 +550,7 @@ char* vala_namespace_get_cheader_filename (ValaNamespace* self)
  *
  * @param cheader_filename header filename
  */
-void vala_namespace_set_cheader_filename (ValaNamespace* self, const char* cheader_filename)
-{
+void vala_namespace_set_cheader_filename (ValaNamespace* self, const char* cheader_filename) {
 	GeeList* _tmp0;
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (cheader_filename != NULL);
@@ -581,21 +560,38 @@ void vala_namespace_set_cheader_filename (ValaNamespace* self, const char* chead
 }
 
 
-static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAttribute* a)
-{
+static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cprefix")) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		vala_namespace_set_cprefix (self, (_tmp0 = vala_attribute_get_string (a, "cprefix")));
-		(_tmp0 = (g_free (_tmp0), NULL));
+		{
+			char* _tmp0;
+			char** _tmp1;
+			char** name_collection;
+			char** name_it;
+			int name_collection_length1;
+			_tmp0 = NULL;
+			_tmp1 = NULL;
+			name_collection = (_tmp1 = g_strsplit ((_tmp0 = vala_attribute_get_string (a, "cprefix")), ",", 0), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+			name_collection_length1 = -1;
+			for (name_it = name_collection; *name_it != NULL; name_it = name_it + 1) {
+				const char* _tmp2;
+				char* name;
+				_tmp2 = NULL;
+				name = (_tmp2 = *name_it, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
+				{
+					vala_namespace_add_cprefix (self, name);
+					(name = (g_free (name), NULL));
+				}
+			}
+			(name_collection = (_vala_array_free (name_collection, name_collection_length1, ((GDestroyNotify) g_free)), NULL));
+		}
 	}
 	if (vala_attribute_has_argument (a, "lower_case_cprefix")) {
-		char* _tmp1;
-		_tmp1 = NULL;
-		vala_namespace_set_lower_case_cprefix (self, (_tmp1 = vala_attribute_get_string (a, "lower_case_cprefix")));
-		(_tmp1 = (g_free (_tmp1), NULL));
+		char* _tmp3;
+		_tmp3 = NULL;
+		vala_namespace_set_lower_case_cprefix (self, (_tmp3 = vala_attribute_get_string (a, "lower_case_cprefix")));
+		(_tmp3 = (g_free (_tmp3), NULL));
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -607,10 +603,10 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 			filename_collection = g_strsplit (val, ",", 0);
 			filename_collection_length1 = -1;
 			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
-				const char* _tmp2;
+				const char* _tmp4;
 				char* filename;
-				_tmp2 = NULL;
-				filename = (_tmp2 = *filename_it, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
+				_tmp4 = NULL;
+				filename = (_tmp4 = *filename_it, (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
 				{
 					gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), filename);
 					(filename = (g_free (filename), NULL));
@@ -626,13 +622,12 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 /**
  * Process all associated attributes.
  */
-void vala_namespace_process_attributes (ValaNamespace* self)
-{
+void vala_namespace_process_attributes (ValaNamespace* self) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = ((ValaCodeNode*) self)->attributes;
+		a_collection = VALA_CODE_NODE (self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
@@ -649,22 +644,19 @@ void vala_namespace_process_attributes (ValaNamespace* self)
 }
 
 
-gboolean vala_namespace_get_pkg (ValaNamespace* self)
-{
+gboolean vala_namespace_get_pkg (ValaNamespace* self) {
 	g_return_val_if_fail (VALA_IS_NAMESPACE (self), FALSE);
 	return self->priv->_pkg;
 }
 
 
-void vala_namespace_set_pkg (ValaNamespace* self, gboolean value)
-{
+void vala_namespace_set_pkg (ValaNamespace* self, gboolean value) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	self->priv->_pkg = value;
 }
 
 
-static void vala_namespace_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_namespace_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaNamespace * self;
 	self = VALA_NAMESPACE (object);
 	switch (property_id) {
@@ -678,8 +670,7 @@ static void vala_namespace_get_property (GObject * object, guint property_id, GV
 }
 
 
-static void vala_namespace_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_namespace_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaNamespace * self;
 	self = VALA_NAMESPACE (object);
 	switch (property_id) {
@@ -693,8 +684,7 @@ static void vala_namespace_set_property (GObject * object, guint property_id, co
 }
 
 
-static void vala_namespace_class_init (ValaNamespaceClass * klass)
-{
+static void vala_namespace_class_init (ValaNamespaceClass * klass) {
 	vala_namespace_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaNamespacePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_namespace_get_property;
@@ -705,12 +695,11 @@ static void vala_namespace_class_init (ValaNamespaceClass * klass)
 	VALA_SYMBOL_CLASS (klass)->get_cprefix = vala_namespace_real_get_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_namespace_real_get_lower_case_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_namespace_real_get_cheader_filenames;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMESPACE_PKG, g_param_spec_boolean ("pkg", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMESPACE_PKG, g_param_spec_boolean ("pkg", "pkg", "pkg", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_namespace_init (ValaNamespace * self)
-{
+static void vala_namespace_init (ValaNamespace * self) {
 	self->priv = VALA_NAMESPACE_GET_PRIVATE (self);
 	self->priv->classes = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->interfaces = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
@@ -720,16 +709,14 @@ static void vala_namespace_init (ValaNamespace * self)
 	self->priv->constants = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->fields = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->methods = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->cprefixes = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
 	self->priv->cheader_filenames = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
 	self->priv->namespaces = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_namespace_dispose (GObject * obj)
-{
+static void vala_namespace_dispose (GObject * obj) {
 	ValaNamespace * self;
-	ValaNamespaceClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_NAMESPACE (obj);
 	(self->priv->classes == NULL ? NULL : (self->priv->classes = (g_object_unref (self->priv->classes), NULL)));
 	(self->priv->interfaces == NULL ? NULL : (self->priv->interfaces = (g_object_unref (self->priv->interfaces), NULL)));
@@ -739,18 +726,15 @@ static void vala_namespace_dispose (GObject * obj)
 	(self->priv->constants == NULL ? NULL : (self->priv->constants = (g_object_unref (self->priv->constants), NULL)));
 	(self->priv->fields == NULL ? NULL : (self->priv->fields = (g_object_unref (self->priv->fields), NULL)));
 	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
-	(self->priv->cprefix = (g_free (self->priv->cprefix), NULL));
+	(self->priv->cprefixes == NULL ? NULL : (self->priv->cprefixes = (g_object_unref (self->priv->cprefixes), NULL)));
 	(self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL));
 	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL)));
 	(self->priv->namespaces == NULL ? NULL : (self->priv->namespaces = (g_object_unref (self->priv->namespaces), NULL)));
-	klass = VALA_NAMESPACE_CLASS (g_type_class_peek (VALA_TYPE_NAMESPACE));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_namespace_parent_class)->dispose (obj);
 }
 
 
-GType vala_namespace_get_type (void)
-{
+GType vala_namespace_get_type (void) {
 	static GType vala_namespace_type_id = 0;
 	if (G_UNLIKELY (vala_namespace_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaNamespaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_namespace_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNamespace), 0, (GInstanceInitFunc) vala_namespace_init };
@@ -760,8 +744,7 @@ GType vala_namespace_get_type (void)
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
-{
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
 		if (array_length >= 0)
