@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAOBJECTCREATIONEXPRESSION_H__
-#define __VALAOBJECTCREATIONEXPRESSION_H__
+#ifndef __VALA_VALAOBJECTCREATIONEXPRESSION_H__
+#define __VALA_VALAOBJECTCREATIONEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -55,6 +55,8 @@ struct _ValaObjectCreationExpressionClass {
 ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAccess* member_name, ValaSourceReference* source_reference);
 void vala_object_creation_expression_add_argument (ValaObjectCreationExpression* self, ValaExpression* arg);
 GeeCollection* vala_object_creation_expression_get_argument_list (ValaObjectCreationExpression* self);
+void vala_object_creation_expression_add_member_initializer (ValaObjectCreationExpression* self, ValaMemberInitializer* init);
+GeeCollection* vala_object_creation_expression_get_object_initializer (ValaObjectCreationExpression* self);
 ValaTypeReference* vala_object_creation_expression_get_type_reference (ValaObjectCreationExpression* self);
 void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpression* self, ValaTypeReference* value);
 ValaMethod* vala_object_creation_expression_get_constructor (ValaObjectCreationExpression* self);
