@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAPARENTHESIZEDEXPRESSION_H__
-#define __VALAPARENTHESIZEDEXPRESSION_H__
+#ifndef __VALA_VALAPARENTHESIZEDEXPRESSION_H__
+#define __VALA_VALAPARENTHESIZEDEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -54,7 +54,7 @@ struct _ValaParenthesizedExpressionClass {
 ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression* _inner, ValaSourceReference* source);
 ValaExpression* vala_parenthesized_expression_get_inner (ValaParenthesizedExpression* self);
 void vala_parenthesized_expression_set_inner (ValaParenthesizedExpression* self, ValaExpression* value);
-GType vala_parenthesized_expression_get_type ();
+GType vala_parenthesized_expression_get_type (void);
 
 G_END_DECLS
 
