@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAPROPERTY_H__
-#define __VALAPROPERTY_H__
+#ifndef __VALA_VALAPROPERTY_H__
+#define __VALA_VALAPROPERTY_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -68,6 +68,8 @@ ValaPropertyAccessor* vala_property_get_set_accessor (ValaProperty* self);
 void vala_property_set_set_accessor (ValaProperty* self, ValaPropertyAccessor* value);
 ValaFormalParameter* vala_property_get_this_parameter (ValaProperty* self);
 void vala_property_set_this_parameter (ValaProperty* self, ValaFormalParameter* value);
+gboolean vala_property_get_notify (ValaProperty* self);
+void vala_property_set_notify (ValaProperty* self, gboolean value);
 gboolean vala_property_get_no_accessor_method (ValaProperty* self);
 void vala_property_set_no_accessor_method (ValaProperty* self, gboolean value);
 gboolean vala_property_get_interface_only (ValaProperty* self);
