@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,9 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valarealliteral.h"
-#include <vala/valasourcereference.h>
 #include <vala/valarealliteral.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaRealLiteralPrivate {
@@ -45,8 +44,7 @@ static void vala_real_literal_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created real literal
  */
-ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* source)
-{
+ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* source) {
 	ValaRealLiteral * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_REAL_LITERAL, 0, NULL);
@@ -56,10 +54,9 @@ ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* sour
 }
 
 
-static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaRealLiteral * self;
-	self = ((ValaRealLiteral*) base);
+	self = VALA_REAL_LITERAL (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_real_literal (visitor, self);
 }
@@ -70,8 +67,7 @@ static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor*
  *
  * @return the name of literal type
  */
-char* vala_real_literal_get_type_name (ValaRealLiteral* self)
-{
+char* vala_real_literal_get_type_name (ValaRealLiteral* self) {
 	g_return_val_if_fail (VALA_IS_REAL_LITERAL (self), NULL);
 	if (g_str_has_suffix (vala_real_literal_get_value (self), "F")) {
 		return g_strdup ("float");
@@ -80,15 +76,13 @@ char* vala_real_literal_get_type_name (ValaRealLiteral* self)
 }
 
 
-char* vala_real_literal_get_value (ValaRealLiteral* self)
-{
+char* vala_real_literal_get_value (ValaRealLiteral* self) {
 	g_return_val_if_fail (VALA_IS_REAL_LITERAL (self), NULL);
 	return self->priv->_value;
 }
 
 
-void vala_real_literal_set_value (ValaRealLiteral* self, const char* value)
-{
+void vala_real_literal_set_value (ValaRealLiteral* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
 	g_return_if_fail (VALA_IS_REAL_LITERAL (self));
@@ -98,8 +92,7 @@ void vala_real_literal_set_value (ValaRealLiteral* self, const char* value)
 }
 
 
-static void vala_real_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_real_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaRealLiteral * self;
 	self = VALA_REAL_LITERAL (object);
 	switch (property_id) {
@@ -113,8 +106,7 @@ static void vala_real_literal_get_property (GObject * object, guint property_id,
 }
 
 
-static void vala_real_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_real_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaRealLiteral * self;
 	self = VALA_REAL_LITERAL (object);
 	switch (property_id) {
@@ -128,39 +120,31 @@ static void vala_real_literal_set_property (GObject * object, guint property_id,
 }
 
 
-static void vala_real_literal_class_init (ValaRealLiteralClass * klass)
-{
+static void vala_real_literal_class_init (ValaRealLiteralClass * klass) {
 	vala_real_literal_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaRealLiteralPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_real_literal_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_real_literal_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_real_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_real_literal_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_REAL_LITERAL_VALUE, g_param_spec_string ("value", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_REAL_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_real_literal_init (ValaRealLiteral * self)
-{
+static void vala_real_literal_init (ValaRealLiteral * self) {
 	self->priv = VALA_REAL_LITERAL_GET_PRIVATE (self);
 }
 
 
-static void vala_real_literal_dispose (GObject * obj)
-{
+static void vala_real_literal_dispose (GObject * obj) {
 	ValaRealLiteral * self;
-	ValaRealLiteralClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_REAL_LITERAL (obj);
 	(self->priv->_value = (g_free (self->priv->_value), NULL));
-	klass = VALA_REAL_LITERAL_CLASS (g_type_class_peek (VALA_TYPE_REAL_LITERAL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_real_literal_parent_class)->dispose (obj);
 }
 
 
-GType vala_real_literal_get_type (void)
-{
+GType vala_real_literal_get_type (void) {
 	static GType vala_real_literal_type_id = 0;
 	if (G_UNLIKELY (vala_real_literal_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaRealLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_real_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaRealLiteral), 0, (GInstanceInitFunc) vala_real_literal_init };
