@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAREPORT_H__
-#define __VALAREPORT_H__
+#ifndef __VALA_VALAREPORT_H__
+#define __VALA_VALAREPORT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -43,6 +43,8 @@ gint vala_report_get_warnings (void);
 gint vala_report_get_errors (void);
 void vala_report_warning (ValaSourceReference* source, const char* message);
 void vala_report_error (ValaSourceReference* source, const char* message);
+ValaReport* vala_report_new (void);
+void vala_report_free (ValaReport* self);
 
 G_END_DECLS
 
