@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valascope.h"
+#include <vala/valascope.h>
 #include <gee/map.h>
 #include <gee/hashmap.h>
 #include <vala/valasymbol.h>
-#include <vala/valascope.h>
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
 
@@ -48,8 +47,7 @@ static void vala_scope_dispose (GObject * obj);
  *
  * @return newly created scope
  */
-ValaScope* vala_scope_new (ValaSymbol* owner)
-{
+ValaScope* vala_scope_new (ValaSymbol* owner) {
 	ValaScope * self;
 	g_return_val_if_fail (owner == NULL || VALA_IS_SYMBOL (owner), NULL);
 	self = g_object_newv (VALA_TYPE_SCOPE, 0, NULL);
@@ -65,8 +63,7 @@ ValaScope* vala_scope_new (ValaSymbol* owner)
  * @param name name for the specified symbol
  * @param sym  a symbol
  */
-void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym)
-{
+void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 	g_return_if_fail (VALA_IS_SCOPE (self));
 	g_return_if_fail (VALA_IS_SYMBOL (sym));
 	if (name != NULL) {
@@ -84,7 +81,7 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym)
 				vala_code_node_set_error (VALA_CODE_NODE (vala_scope_get_owner (self)), TRUE);
 				_tmp4 = NULL;
 				_tmp3 = NULL;
-				vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) vala_scope_get_owner (self))), (_tmp4 = g_strdup_printf ("`%s' already contains a definition for `%s'", (_tmp3 = vala_symbol_get_full_name (vala_scope_get_owner (self))), name)));
+				vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (vala_scope_get_owner (self))), (_tmp4 = g_strdup_printf ("`%s' already contains a definition for `%s'", (_tmp3 = vala_symbol_get_full_name (vala_scope_get_owner (self))), name)));
 				(_tmp4 = (g_free (_tmp4), NULL));
 				(_tmp3 = (g_free (_tmp3), NULL));
 				return;
@@ -103,13 +100,12 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym)
  * @param name name of the symbol to be returned
  * @return     found symbol or null
  */
-ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name)
-{
+ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name) {
 	ValaSymbol* sym;
 	g_return_val_if_fail (VALA_IS_SCOPE (self), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	if (self->priv->symbol_table == NULL) {
-		return VALA_SYMBOL (NULL);
+		return NULL;
 	}
 	sym = gee_map_get (((GeeMap*) self->priv->symbol_table), name);
 	if (sym != NULL && !vala_symbol_get_active (sym)) {
@@ -122,36 +118,31 @@ ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name)
 }
 
 
-ValaSymbol* vala_scope_get_owner (ValaScope* self)
-{
+ValaSymbol* vala_scope_get_owner (ValaScope* self) {
 	g_return_val_if_fail (VALA_IS_SCOPE (self), NULL);
 	return self->priv->_owner;
 }
 
 
-void vala_scope_set_owner (ValaScope* self, ValaSymbol* value)
-{
+void vala_scope_set_owner (ValaScope* self, ValaSymbol* value) {
 	g_return_if_fail (VALA_IS_SCOPE (self));
 	self->priv->_owner = value;
 }
 
 
-ValaScope* vala_scope_get_parent_scope (ValaScope* self)
-{
+ValaScope* vala_scope_get_parent_scope (ValaScope* self) {
 	g_return_val_if_fail (VALA_IS_SCOPE (self), NULL);
 	return self->priv->_parent_scope;
 }
 
 
-void vala_scope_set_parent_scope (ValaScope* self, ValaScope* value)
-{
+void vala_scope_set_parent_scope (ValaScope* self, ValaScope* value) {
 	g_return_if_fail (VALA_IS_SCOPE (self));
 	self->priv->_parent_scope = value;
 }
 
 
-static void vala_scope_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_scope_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaScope * self;
 	self = VALA_SCOPE (object);
 	switch (property_id) {
@@ -168,8 +159,7 @@ static void vala_scope_get_property (GObject * object, guint property_id, GValue
 }
 
 
-static void vala_scope_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_scope_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaScope * self;
 	self = VALA_SCOPE (object);
 	switch (property_id) {
@@ -186,39 +176,31 @@ static void vala_scope_set_property (GObject * object, guint property_id, const
 }
 
 
-static void vala_scope_class_init (ValaScopeClass * klass)
-{
+static void vala_scope_class_init (ValaScopeClass * klass) {
 	vala_scope_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaScopePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_scope_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_scope_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_scope_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SCOPE_OWNER, g_param_spec_object ("owner", "foo", "bar", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SCOPE_PARENT_SCOPE, g_param_spec_object ("parent-scope", "foo", "bar", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SCOPE_OWNER, g_param_spec_object ("owner", "owner", "owner", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SCOPE_PARENT_SCOPE, g_param_spec_object ("parent-scope", "parent-scope", "parent-scope", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_scope_init (ValaScope * self)
-{
+static void vala_scope_init (ValaScope * self) {
 	self->priv = VALA_SCOPE_GET_PRIVATE (self);
 }
 
 
-static void vala_scope_dispose (GObject * obj)
-{
+static void vala_scope_dispose (GObject * obj) {
 	ValaScope * self;
-	ValaScopeClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_SCOPE (obj);
 	(self->priv->symbol_table == NULL ? NULL : (self->priv->symbol_table = (g_object_unref (self->priv->symbol_table), NULL)));
-	klass = VALA_SCOPE_CLASS (g_type_class_peek (VALA_TYPE_SCOPE));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_scope_parent_class)->dispose (obj);
 }
 
 
-GType vala_scope_get_type (void)
-{
+GType vala_scope_get_type (void) {
 	static GType vala_scope_type_id = 0;
 	if (G_UNLIKELY (vala_scope_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaScopeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_scope_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaScope), 0, (GInstanceInitFunc) vala_scope_init };
