@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valasizeofexpression.h"
+#include <vala/valasizeofexpression.h>
 #include <vala/valatypereference.h>
 #include <vala/valasourcereference.h>
-#include <vala/valasizeofexpression.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaSizeofExpressionPrivate {
@@ -46,8 +45,7 @@ static void vala_sizeof_expression_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created sizeof expression
  */
-ValaSizeofExpression* vala_sizeof_expression_new (ValaTypeReference* type, ValaSourceReference* source)
-{
+ValaSizeofExpression* vala_sizeof_expression_new (ValaTypeReference* type, ValaSourceReference* source) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaSizeofExpression * self;
@@ -67,25 +65,22 @@ ValaSizeofExpression* vala_sizeof_expression_new (ValaTypeReference* type, ValaS
 }
 
 
-static void vala_sizeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_sizeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSizeofExpression * self;
-	self = ((ValaSizeofExpression*) base);
+	self = VALA_SIZEOF_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_sizeof_expression_get_type_reference (self)), visitor);
 	vala_code_visitor_visit_sizeof_expression (visitor, self);
 }
 
 
-ValaTypeReference* vala_sizeof_expression_get_type_reference (ValaSizeofExpression* self)
-{
+ValaTypeReference* vala_sizeof_expression_get_type_reference (ValaSizeofExpression* self) {
 	g_return_val_if_fail (VALA_IS_SIZEOF_EXPRESSION (self), NULL);
 	return self->priv->_type_reference;
 }
 
 
-void vala_sizeof_expression_set_type_reference (ValaSizeofExpression* self, ValaTypeReference* value)
-{
+void vala_sizeof_expression_set_type_reference (ValaSizeofExpression* self, ValaTypeReference* value) {
 	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_SIZEOF_EXPRESSION (self));
 	_tmp1 = NULL;
@@ -93,8 +88,7 @@ void vala_sizeof_expression_set_type_reference (ValaSizeofExpression* self, Vala
 }
 
 
-static void vala_sizeof_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_sizeof_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaSizeofExpression * self;
 	self = VALA_SIZEOF_EXPRESSION (object);
 	switch (property_id) {
@@ -108,8 +102,7 @@ static void vala_sizeof_expression_get_property (GObject * object, guint propert
 }
 
 
-static void vala_sizeof_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_sizeof_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaSizeofExpression * self;
 	self = VALA_SIZEOF_EXPRESSION (object);
 	switch (property_id) {
@@ -123,39 +116,31 @@ static void vala_sizeof_expression_set_property (GObject * object, guint propert
 }
 
 
-static void vala_sizeof_expression_class_init (ValaSizeofExpressionClass * klass)
-{
+static void vala_sizeof_expression_class_init (ValaSizeofExpressionClass * klass) {
 	vala_sizeof_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaSizeofExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_sizeof_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_sizeof_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_sizeof_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_sizeof_expression_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_sizeof_expression_init (ValaSizeofExpression * self)
-{
+static void vala_sizeof_expression_init (ValaSizeofExpression * self) {
 	self->priv = VALA_SIZEOF_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_sizeof_expression_dispose (GObject * obj)
-{
+static void vala_sizeof_expression_dispose (GObject * obj) {
 	ValaSizeofExpression * self;
-	ValaSizeofExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_SIZEOF_EXPRESSION (obj);
 	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
-	klass = VALA_SIZEOF_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_SIZEOF_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_sizeof_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_sizeof_expression_get_type (void)
-{
+GType vala_sizeof_expression_get_type (void) {
 	static GType vala_sizeof_expression_type_id = 0;
 	if (G_UNLIKELY (vala_sizeof_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSizeofExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_sizeof_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSizeofExpression), 0, (GInstanceInitFunc) vala_sizeof_expression_init };
