@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valasourcefile.h"
+#include <vala/valasourcefile.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
@@ -69,6 +69,8 @@ enum  {
 	VALA_SOURCE_FILE_MARK,
 	VALA_SOURCE_FILE_CONTEXT
 };
+static char* vala_source_file_get_subdir (ValaSourceFile* self);
+static char* vala_source_file_get_destination_directory (ValaSourceFile* self);
 static gpointer vala_source_file_parent_class = NULL;
 static void vala_source_file_dispose (GObject * obj);
 
@@ -80,8 +82,7 @@ static void vala_source_file_dispose (GObject * obj);
  * @param pkg      true if this is a VAPI package file
  * @return         newly created source file
  */
-ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* filename, gboolean pkg)
-{
+ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* filename, gboolean pkg) {
 	ValaSourceFile * self;
 	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (context), NULL);
 	g_return_val_if_fail (filename != NULL, NULL);
@@ -98,8 +99,7 @@ ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* file
  *
  * @param ns reference to namespace
  */
-void vala_source_file_add_using_directive (ValaSourceFile* self, ValaNamespaceReference* ns)
-{
+void vala_source_file_add_using_directive (ValaSourceFile* self, ValaNamespaceReference* ns) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (VALA_IS_NAMESPACE_REFERENCE (ns));
 	gee_collection_add (GEE_COLLECTION (self->priv->using_directives), ns);
@@ -111,8 +111,7 @@ void vala_source_file_add_using_directive (ValaSourceFile* self, ValaNamespaceRe
  *
  * @return using directive list
  */
-GeeCollection* vala_source_file_get_using_directives (ValaSourceFile* self)
-{
+GeeCollection* vala_source_file_get_using_directives (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->using_directives)));
 }
@@ -123,8 +122,7 @@ GeeCollection* vala_source_file_get_using_directives (ValaSourceFile* self)
  *
  * @param node a code node
  */
-void vala_source_file_add_node (ValaSourceFile* self, ValaCodeNode* node)
-{
+void vala_source_file_add_node (ValaSourceFile* self, ValaCodeNode* node) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (VALA_IS_CODE_NODE (node));
 	gee_collection_add (GEE_COLLECTION (self->priv->nodes), node);
@@ -136,23 +134,20 @@ void vala_source_file_add_node (ValaSourceFile* self, ValaCodeNode* node)
  *
  * @return code node list
  */
-GeeCollection* vala_source_file_get_nodes (ValaSourceFile* self)
-{
+GeeCollection* vala_source_file_get_nodes (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->nodes)));
 }
 
 
-void vala_source_file_accept (ValaSourceFile* self, ValaCodeVisitor* visitor)
-{
+void vala_source_file_accept (ValaSourceFile* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_source_file (visitor, self);
 }
 
 
-void vala_source_file_accept_children (ValaSourceFile* self, ValaCodeVisitor* visitor)
-{
+void vala_source_file_accept_children (ValaSourceFile* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
@@ -188,25 +183,73 @@ void vala_source_file_accept_children (ValaSourceFile* self, ValaCodeVisitor* vi
 }
 
 
+static char* vala_source_file_get_subdir (ValaSourceFile* self) {
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
+	if (vala_code_context_get_basedir (vala_source_file_get_context (self)) == NULL) {
+		return g_strdup ("");
+	}
+	/* filename and basedir are already canonicalized*/
+	if (g_str_has_prefix (vala_source_file_get_filename (self), vala_code_context_get_basedir (vala_source_file_get_context (self)))) {
+		char* basename;
+		char* _tmp1;
+		char* subdir;
+		char* _tmp4;
+		basename = g_path_get_basename (vala_source_file_get_filename (self));
+		_tmp1 = NULL;
+		subdir = (_tmp1 = g_utf8_offset_to_pointer (vala_source_file_get_filename (self), g_utf8_strlen (vala_code_context_get_basedir (vala_source_file_get_context (self)), -1)), g_strndup (_tmp1, g_utf8_offset_to_pointer (_tmp1, g_utf8_strlen (vala_source_file_get_filename (self), -1) - g_utf8_strlen (vala_code_context_get_basedir (vala_source_file_get_context (self)), -1) - g_utf8_strlen (basename, -1)) - _tmp1));
+		while (g_utf8_get_char (g_utf8_offset_to_pointer (subdir, 0)) == '/') {
+			char* _tmp3;
+			const char* _tmp2;
+			_tmp3 = NULL;
+			_tmp2 = NULL;
+			subdir = (_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (subdir, 1), (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (subdir = (g_free (subdir), NULL)), _tmp3);
+		}
+		_tmp4 = NULL;
+		return (_tmp4 = subdir, (basename = (g_free (basename), NULL)), _tmp4);
+		(basename = (g_free (basename), NULL));
+		(subdir = (g_free (subdir), NULL));
+	}
+	return g_strdup ("");
+}
+
+
+static char* vala_source_file_get_destination_directory (ValaSourceFile* self) {
+	char* _tmp1;
+	char* _tmp2;
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
+	if (vala_code_context_get_directory (vala_source_file_get_context (self)) == NULL) {
+		return vala_source_file_get_subdir (self);
+	}
+	_tmp1 = NULL;
+	_tmp2 = NULL;
+	return (_tmp2 = g_strdup_printf ("%s/%s", vala_code_context_get_directory (vala_source_file_get_context (self)), (_tmp1 = vala_source_file_get_subdir (self))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
+}
+
+
 /**
  * Returns the filename to use when generating C header files.
  *
  * @return generated C header filename
  */
-char* vala_source_file_get_cheader_filename (ValaSourceFile* self)
-{
-	const char* __temp3;
+char* vala_source_file_get_cheader_filename (ValaSourceFile* self) {
+	const char* _tmp3;
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	if (self->priv->cheader_filename == NULL) {
 		char* basename;
-		char* __temp2;
+		char* _tmp0;
+		char* _tmp2;
+		char* _tmp1;
 		basename = g_strndup (vala_source_file_get_filename (self), ((guint) (g_utf8_strlen (vala_source_file_get_filename (self), -1) - g_utf8_strlen (".vala", -1))));
-		__temp2 = NULL;
-		self->priv->cheader_filename = (__temp2 = g_strdup_printf ("%s.h", basename), (self->priv->cheader_filename = (g_free (self->priv->cheader_filename), NULL)), __temp2);
+		_tmp0 = NULL;
+		basename = (_tmp0 = g_path_get_basename (basename), (basename = (g_free (basename), NULL)), _tmp0);
+		_tmp2 = NULL;
+		_tmp1 = NULL;
+		self->priv->cheader_filename = (_tmp2 = g_strdup_printf ("%s%s.h", (_tmp1 = vala_source_file_get_destination_directory (self)), basename), (self->priv->cheader_filename = (g_free (self->priv->cheader_filename), NULL)), _tmp2);
+		(_tmp1 = (g_free (_tmp1), NULL));
 		(basename = (g_free (basename), NULL));
 	}
-	__temp3 = NULL;
-	return (__temp3 = self->priv->cheader_filename, (__temp3 == NULL ? NULL : g_strdup (__temp3)));
+	_tmp3 = NULL;
+	return (_tmp3 = self->priv->cheader_filename, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 }
 
 
@@ -215,20 +258,25 @@ char* vala_source_file_get_cheader_filename (ValaSourceFile* self)
  *
  * @return generated C source filename
  */
-char* vala_source_file_get_csource_filename (ValaSourceFile* self)
-{
-	const char* __temp6;
+char* vala_source_file_get_csource_filename (ValaSourceFile* self) {
+	const char* _tmp3;
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	if (self->priv->csource_filename == NULL) {
 		char* basename;
-		char* __temp5;
+		char* _tmp0;
+		char* _tmp2;
+		char* _tmp1;
 		basename = g_strndup (vala_source_file_get_filename (self), ((guint) (g_utf8_strlen (vala_source_file_get_filename (self), -1) - g_utf8_strlen (".vala", -1))));
-		__temp5 = NULL;
-		self->priv->csource_filename = (__temp5 = g_strdup_printf ("%s.c", basename), (self->priv->csource_filename = (g_free (self->priv->csource_filename), NULL)), __temp5);
+		_tmp0 = NULL;
+		basename = (_tmp0 = g_path_get_basename (basename), (basename = (g_free (basename), NULL)), _tmp0);
+		_tmp2 = NULL;
+		_tmp1 = NULL;
+		self->priv->csource_filename = (_tmp2 = g_strdup_printf ("%s%s.c", (_tmp1 = vala_source_file_get_destination_directory (self)), basename), (self->priv->csource_filename = (g_free (self->priv->csource_filename), NULL)), _tmp2);
+		(_tmp1 = (g_free (_tmp1), NULL));
 		(basename = (g_free (basename), NULL));
 	}
-	__temp6 = NULL;
-	return (__temp6 = self->priv->csource_filename, (__temp6 == NULL ? NULL : g_strdup (__temp6)));
+	_tmp3 = NULL;
+	return (_tmp3 = self->priv->csource_filename, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 }
 
 
@@ -238,26 +286,32 @@ char* vala_source_file_get_csource_filename (ValaSourceFile* self)
  *
  * @return C header filename to include
  */
-char* vala_source_file_get_cinclude_filename (ValaSourceFile* self)
-{
-	const char* __temp10;
+char* vala_source_file_get_cinclude_filename (ValaSourceFile* self) {
+	const char* _tmp4;
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	if (self->priv->cinclude_filename == NULL) {
 		char* basename;
+		char* _tmp0;
 		basename = g_strndup (vala_source_file_get_filename (self), ((guint) (g_utf8_strlen (vala_source_file_get_filename (self), -1) - g_utf8_strlen (".vala", -1))));
-		if (vala_code_context_get_library (vala_source_file_get_context (self)) != NULL) {
-			char* __temp8;
-			__temp8 = NULL;
-			self->priv->cinclude_filename = (__temp8 = g_strdup_printf ("%s/%s.h", vala_code_context_get_library (vala_source_file_get_context (self)), basename), (self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL)), __temp8);
+		_tmp0 = NULL;
+		basename = (_tmp0 = g_path_get_basename (basename), (basename = (g_free (basename), NULL)), _tmp0);
+		if (vala_code_context_get_basedir (vala_source_file_get_context (self)) == NULL && vala_code_context_get_library (vala_source_file_get_context (self)) != NULL) {
+			char* _tmp1;
+			/* backward-compatibility*/
+			_tmp1 = NULL;
+			self->priv->cinclude_filename = (_tmp1 = g_strdup_printf ("%s/%s.h", vala_code_context_get_library (vala_source_file_get_context (self)), basename), (self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL)), _tmp1);
 		} else {
-			char* __temp9;
-			__temp9 = NULL;
-			self->priv->cinclude_filename = (__temp9 = g_strdup_printf ("%s.h", basename), (self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL)), __temp9);
+			char* _tmp3;
+			char* _tmp2;
+			_tmp3 = NULL;
+			_tmp2 = NULL;
+			self->priv->cinclude_filename = (_tmp3 = g_strdup_printf ("%s%s.h", (_tmp2 = vala_source_file_get_subdir (self)), basename), (self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL)), _tmp3);
+			(_tmp2 = (g_free (_tmp2), NULL));
 		}
 		(basename = (g_free (basename), NULL));
 	}
-	__temp10 = NULL;
-	return (__temp10 = self->priv->cinclude_filename, (__temp10 == NULL ? NULL : g_strdup (__temp10)));
+	_tmp4 = NULL;
+	return (_tmp4 = self->priv->cinclude_filename, (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
 }
 
 
@@ -268,8 +322,7 @@ char* vala_source_file_get_cinclude_filename (ValaSourceFile* self)
  * @param sym      a symbol
  * @param dep_type type of dependency
  */
-void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* sym, ValaSourceFileDependencyType dep_type)
-{
+void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* sym, ValaSourceFileDependencyType dep_type) {
 	ValaSymbol* s;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (VALA_IS_SYMBOL (sym));
@@ -278,20 +331,20 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 	}
 	s = NULL;
 	if (VALA_IS_DATA_TYPE (sym) || VALA_IS_METHOD (sym) || VALA_IS_FIELD (sym) || VALA_IS_PROPERTY (sym) || VALA_IS_CONSTANT (sym)) {
-		ValaSymbol* __temp12;
-		__temp12 = NULL;
-		s = (__temp12 = g_object_ref (sym), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), __temp12);
+		ValaSymbol* _tmp0;
+		_tmp0 = NULL;
+		s = (_tmp0 = g_object_ref (sym), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), _tmp0);
 	} else {
 		if (VALA_IS_FORMAL_PARAMETER (sym)) {
-			ValaFormalParameter* __temp13;
+			ValaFormalParameter* _tmp1;
 			ValaFormalParameter* fp;
-			ValaSymbol* __temp15;
-			ValaDataType* __temp14;
-			__temp13 = NULL;
-			fp = (__temp13 = VALA_FORMAL_PARAMETER (sym), (__temp13 == NULL ? NULL : g_object_ref (__temp13)));
-			__temp15 = NULL;
-			__temp14 = NULL;
-			s = (__temp15 = VALA_SYMBOL ((__temp14 = vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (fp)), (__temp14 == NULL ? NULL : g_object_ref (__temp14)))), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), __temp15);
+			ValaSymbol* _tmp3;
+			ValaDataType* _tmp2;
+			_tmp1 = NULL;
+			fp = (_tmp1 = VALA_FORMAL_PARAMETER (sym), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			_tmp3 = NULL;
+			_tmp2 = NULL;
+			s = (_tmp3 = VALA_SYMBOL ((_tmp2 = vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (fp)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)))), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), _tmp3);
 			if (s == NULL) {
 				(fp == NULL ? NULL : (fp = (g_object_unref (fp), NULL)));
 				(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
@@ -305,7 +358,7 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 	}
 	/* generic type parameter */
 	if (dep_type == VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE) {
-		if (vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) s))))) {
+		if (vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (s))))) {
 			{
 				GeeCollection* fn_collection;
 				GeeIterator* fn_it;
@@ -343,7 +396,7 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 		(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 		return;
 	}
-	if (vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) s))))) {
+	if (vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (s))))) {
 		{
 			GeeCollection* fn_collection;
 			GeeIterator* fn_it;
@@ -381,9 +434,9 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 			(fn_collection == NULL ? NULL : (fn_collection = (g_object_unref (fn_collection), NULL)));
 			(fn_it == NULL ? NULL : (fn_it = (g_object_unref (fn_it), NULL)));
 		}
-		gee_collection_add (GEE_COLLECTION (self->priv->header_internal_full_dependencies), vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) s))));
+		gee_collection_add (GEE_COLLECTION (self->priv->header_internal_full_dependencies), vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (s))));
 	}
-	gee_collection_add (GEE_COLLECTION (self->priv->header_internal_dependencies), vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) s))));
+	gee_collection_add (GEE_COLLECTION (self->priv->header_internal_dependencies), vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (s))));
 	(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 }
 
@@ -394,8 +447,7 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
  *
  * @return external include list for C header file
  */
-GeeCollection* vala_source_file_get_header_external_includes (ValaSourceFile* self)
-{
+GeeCollection* vala_source_file_get_header_external_includes (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->header_external_includes)));
 }
@@ -407,15 +459,14 @@ GeeCollection* vala_source_file_get_header_external_includes (ValaSourceFile* se
  *
  * @param include internal include for C header file
  */
-void vala_source_file_add_header_internal_include (ValaSourceFile* self, const char* include)
-{
-	char* __temp17;
-	gboolean __temp18;
+void vala_source_file_add_header_internal_include (ValaSourceFile* self, const char* include) {
+	char* _tmp0;
+	gboolean _tmp1;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (include != NULL);
 	/* skip includes to self */
-	__temp17 = NULL;
-	if ((__temp18 = g_utf8_collate (include, (__temp17 = vala_source_file_get_cinclude_filename (self))) != 0, (__temp17 = (g_free (__temp17), NULL)), __temp18)) {
+	_tmp0 = NULL;
+	if ((_tmp1 = g_utf8_collate (include, (_tmp0 = vala_source_file_get_cinclude_filename (self))) != 0, (_tmp0 = (g_free (_tmp0), NULL)), _tmp1)) {
 		gee_collection_add (GEE_COLLECTION (self->priv->header_internal_includes), include);
 	}
 }
@@ -427,8 +478,7 @@ void vala_source_file_add_header_internal_include (ValaSourceFile* self, const c
  *
  * @return internal include list for C header file
  */
-GeeCollection* vala_source_file_get_header_internal_includes (ValaSourceFile* self)
-{
+GeeCollection* vala_source_file_get_header_internal_includes (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->header_internal_includes)));
 }
@@ -440,8 +490,7 @@ GeeCollection* vala_source_file_get_header_internal_includes (ValaSourceFile* se
  *
  * @return include list for C source file
  */
-GeeCollection* vala_source_file_get_source_external_includes (ValaSourceFile* self)
-{
+GeeCollection* vala_source_file_get_source_external_includes (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->source_external_includes)));
 }
@@ -453,8 +502,7 @@ GeeCollection* vala_source_file_get_source_external_includes (ValaSourceFile* se
  *
  * @return include list for C source file
  */
-GeeCollection* vala_source_file_get_source_internal_includes (ValaSourceFile* self)
-{
+GeeCollection* vala_source_file_get_source_internal_includes (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->source_internal_includes)));
 }
@@ -466,8 +514,7 @@ GeeCollection* vala_source_file_get_source_internal_includes (ValaSourceFile* se
  *
  * @return definite source file dependencies
  */
-GeeCollection* vala_source_file_get_header_internal_full_dependencies (ValaSourceFile* self)
-{
+GeeCollection* vala_source_file_get_header_internal_full_dependencies (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (NULL, NULL, GEE_COLLECTION (self->priv->header_internal_full_dependencies)));
 }
@@ -479,123 +526,107 @@ GeeCollection* vala_source_file_get_header_internal_full_dependencies (ValaSourc
  *
  * @return loose source file dependencies
  */
-GeeCollection* vala_source_file_get_header_internal_dependencies (ValaSourceFile* self)
-{
+GeeCollection* vala_source_file_get_header_internal_dependencies (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (NULL, NULL, GEE_COLLECTION (self->priv->header_internal_dependencies)));
 }
 
 
-char* vala_source_file_get_filename (ValaSourceFile* self)
-{
+char* vala_source_file_get_filename (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return self->priv->_filename;
 }
 
 
-void vala_source_file_set_filename (ValaSourceFile* self, const char* value)
-{
-	char* __temp25;
+void vala_source_file_set_filename (ValaSourceFile* self, const char* value) {
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	__temp25 = NULL;
-	self->priv->_filename = (__temp25 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), __temp25);
+	_tmp1 = NULL;
+	self->priv->_filename = (_tmp1 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp1);
 }
 
 
-char* vala_source_file_get_comment (ValaSourceFile* self)
-{
+char* vala_source_file_get_comment (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return self->priv->_comment;
 }
 
 
-void vala_source_file_set_comment (ValaSourceFile* self, const char* value)
-{
-	char* __temp28;
-	const char* __temp27;
+void vala_source_file_set_comment (ValaSourceFile* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	__temp28 = NULL;
-	__temp27 = NULL;
-	self->priv->_comment = (__temp28 = (__temp27 = value, (__temp27 == NULL ? NULL : g_strdup (__temp27))), (self->priv->_comment = (g_free (self->priv->_comment), NULL)), __temp28);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_comment = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_comment = (g_free (self->priv->_comment), NULL)), _tmp2);
 }
 
 
-gboolean vala_source_file_get_pkg (ValaSourceFile* self)
-{
+gboolean vala_source_file_get_pkg (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), FALSE);
 	return self->priv->_pkg;
 }
 
 
-void vala_source_file_set_pkg (ValaSourceFile* self, gboolean value)
-{
+void vala_source_file_set_pkg (ValaSourceFile* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	self->priv->_pkg = value;
 }
 
 
-ValaSourceFileCycle* vala_source_file_get_cycle (ValaSourceFile* self)
-{
+ValaSourceFileCycle* vala_source_file_get_cycle (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return self->priv->_cycle;
 }
 
 
-void vala_source_file_set_cycle (ValaSourceFile* self, ValaSourceFileCycle* value)
-{
-	ValaSourceFileCycle* __temp32;
-	ValaSourceFileCycle* __temp31;
+void vala_source_file_set_cycle (ValaSourceFile* self, ValaSourceFileCycle* value) {
+	ValaSourceFileCycle* _tmp2;
+	ValaSourceFileCycle* _tmp1;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	__temp32 = NULL;
-	__temp31 = NULL;
-	self->priv->_cycle = (__temp32 = (__temp31 = value, (__temp31 == NULL ? NULL : g_object_ref (__temp31))), (self->priv->_cycle == NULL ? NULL : (self->priv->_cycle = (g_object_unref (self->priv->_cycle), NULL))), __temp32);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_cycle = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_cycle == NULL ? NULL : (self->priv->_cycle = (g_object_unref (self->priv->_cycle), NULL))), _tmp2);
 }
 
 
-gboolean vala_source_file_get_is_cycle_head (ValaSourceFile* self)
-{
+gboolean vala_source_file_get_is_cycle_head (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), FALSE);
 	return self->priv->_is_cycle_head;
 }
 
 
-void vala_source_file_set_is_cycle_head (ValaSourceFile* self, gboolean value)
-{
+void vala_source_file_set_is_cycle_head (ValaSourceFile* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	self->priv->_is_cycle_head = value;
 }
 
 
-gint vala_source_file_get_mark (ValaSourceFile* self)
-{
+gint vala_source_file_get_mark (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), 0);
 	return self->priv->_mark;
 }
 
 
-void vala_source_file_set_mark (ValaSourceFile* self, gint value)
-{
+void vala_source_file_set_mark (ValaSourceFile* self, gint value) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	self->priv->_mark = value;
 }
 
 
-ValaCodeContext* vala_source_file_get_context (ValaSourceFile* self)
-{
+ValaCodeContext* vala_source_file_get_context (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return self->priv->_context;
 }
 
 
-void vala_source_file_set_context (ValaSourceFile* self, ValaCodeContext* value)
-{
+void vala_source_file_set_context (ValaSourceFile* self, ValaCodeContext* value) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	self->priv->_context = value;
 }
 
 
-static void vala_source_file_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_source_file_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaSourceFile * self;
 	self = VALA_SOURCE_FILE (object);
 	switch (property_id) {
@@ -620,12 +651,14 @@ static void vala_source_file_get_property (GObject * object, guint property_id,
 		case VALA_SOURCE_FILE_CONTEXT:
 		g_value_set_object (value, vala_source_file_get_context (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_source_file_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_source_file_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaSourceFile * self;
 	self = VALA_SOURCE_FILE (object);
 	switch (property_id) {
@@ -650,29 +683,30 @@ static void vala_source_file_set_property (GObject * object, guint property_id,
 		case VALA_SOURCE_FILE_CONTEXT:
 		vala_source_file_set_context (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_source_file_class_init (ValaSourceFileClass * klass)
-{
+static void vala_source_file_class_init (ValaSourceFileClass * klass) {
 	vala_source_file_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaSourceFilePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_source_file_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_source_file_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_source_file_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_FILENAME, g_param_spec_string ("filename", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_COMMENT, g_param_spec_string ("comment", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_PKG, g_param_spec_boolean ("pkg", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_CYCLE, g_param_spec_object ("cycle", "foo", "bar", VALA_TYPE_SOURCE_FILE_CYCLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_IS_CYCLE_HEAD, g_param_spec_boolean ("is-cycle-head", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_MARK, g_param_spec_int ("mark", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_CONTEXT, g_param_spec_object ("context", "foo", "bar", VALA_TYPE_CODE_CONTEXT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_FILENAME, g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_COMMENT, g_param_spec_string ("comment", "comment", "comment", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_PKG, g_param_spec_boolean ("pkg", "pkg", "pkg", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_CYCLE, g_param_spec_object ("cycle", "cycle", "cycle", VALA_TYPE_SOURCE_FILE_CYCLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_IS_CYCLE_HEAD, g_param_spec_boolean ("is-cycle-head", "is-cycle-head", "is-cycle-head", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_MARK, g_param_spec_int ("mark", "mark", "mark", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_CONTEXT, g_param_spec_object ("context", "context", "context", VALA_TYPE_CODE_CONTEXT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_source_file_init (ValaSourceFile * self)
-{
+static void vala_source_file_init (ValaSourceFile * self) {
 	self->priv = VALA_SOURCE_FILE_GET_PRIVATE (self);
 	self->priv->using_directives = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->nodes = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
@@ -688,11 +722,8 @@ static void vala_source_file_init (ValaSourceFile * self)
 }
 
 
-static void vala_source_file_dispose (GObject * obj)
-{
+static void vala_source_file_dispose (GObject * obj) {
 	ValaSourceFile * self;
-	ValaSourceFileClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_SOURCE_FILE (obj);
 	(self->priv->_filename = (g_free (self->priv->_filename), NULL));
 	(self->priv->_comment = (g_free (self->priv->_comment), NULL));
@@ -708,14 +739,11 @@ static void vala_source_file_dispose (GObject * obj)
 	(self->priv->source_internal_includes == NULL ? NULL : (self->priv->source_internal_includes = (g_object_unref (self->priv->source_internal_includes), NULL)));
 	(self->priv->header_internal_full_dependencies == NULL ? NULL : (self->priv->header_internal_full_dependencies = (g_object_unref (self->priv->header_internal_full_dependencies), NULL)));
 	(self->priv->header_internal_dependencies == NULL ? NULL : (self->priv->header_internal_dependencies = (g_object_unref (self->priv->header_internal_dependencies), NULL)));
-	klass = VALA_SOURCE_FILE_CLASS (g_type_class_peek (VALA_TYPE_SOURCE_FILE));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_source_file_parent_class)->dispose (obj);
 }
 
 
-GType vala_source_file_get_type (void)
-{
+GType vala_source_file_get_type (void) {
 	static GType vala_source_file_type_id = 0;
 	if (G_UNLIKELY (vala_source_file_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSourceFileClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_source_file_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSourceFile), 0, (GInstanceInitFunc) vala_source_file_init };
