@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,14 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALASOURCEFILE_H__
-#define __VALASOURCEFILE_H__
+#ifndef __VALA_VALASOURCEFILE_H__
+#define __VALA_VALASOURCEFILE_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <vala/valasourcefile.h>
+#include <gee/collection.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -58,25 +58,24 @@ typedef enum  {
 	VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE
 } ValaSourceFileDependencyType;
 
-ValaSourceFile* vala_source_file_new (ValaCodeContext* _context, const char* _filename, gboolean _pkg);
+ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* filename, gboolean pkg);
 void vala_source_file_add_using_directive (ValaSourceFile* self, ValaNamespaceReference* ns);
-GList* vala_source_file_get_using_directives (ValaSourceFile* self);
-void vala_source_file_add_namespace (ValaSourceFile* self, ValaNamespace* ns);
-ValaNamespace* vala_source_file_get_global_namespace (ValaSourceFile* self);
-GList* vala_source_file_get_namespaces (ValaSourceFile* self);
+GeeCollection* vala_source_file_get_using_directives (ValaSourceFile* self);
+void vala_source_file_add_node (ValaSourceFile* self, ValaCodeNode* node);
+GeeCollection* vala_source_file_get_nodes (ValaSourceFile* self);
 void vala_source_file_accept (ValaSourceFile* self, ValaCodeVisitor* visitor);
 void vala_source_file_accept_children (ValaSourceFile* self, ValaCodeVisitor* visitor);
 char* vala_source_file_get_cheader_filename (ValaSourceFile* self);
 char* vala_source_file_get_csource_filename (ValaSourceFile* self);
 char* vala_source_file_get_cinclude_filename (ValaSourceFile* self);
 void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* sym, ValaSourceFileDependencyType dep_type);
-GList* vala_source_file_get_header_external_includes (ValaSourceFile* self);
+GeeCollection* vala_source_file_get_header_external_includes (ValaSourceFile* self);
 void vala_source_file_add_header_internal_include (ValaSourceFile* self, const char* include);
-GList* vala_source_file_get_header_internal_includes (ValaSourceFile* self);
-GList* vala_source_file_get_source_external_includes (ValaSourceFile* self);
-GList* vala_source_file_get_source_internal_includes (ValaSourceFile* self);
-GList* vala_source_file_get_header_internal_full_dependencies (ValaSourceFile* self);
-GList* vala_source_file_get_header_internal_dependencies (ValaSourceFile* self);
+GeeCollection* vala_source_file_get_header_internal_includes (ValaSourceFile* self);
+GeeCollection* vala_source_file_get_source_external_includes (ValaSourceFile* self);
+GeeCollection* vala_source_file_get_source_internal_includes (ValaSourceFile* self);
+GeeCollection* vala_source_file_get_header_internal_full_dependencies (ValaSourceFile* self);
+GeeCollection* vala_source_file_get_header_internal_dependencies (ValaSourceFile* self);
 char* vala_source_file_get_filename (ValaSourceFile* self);
 void vala_source_file_set_filename (ValaSourceFile* self, const char* value);
 char* vala_source_file_get_comment (ValaSourceFile* self);
@@ -91,7 +90,7 @@ gint vala_source_file_get_mark (ValaSourceFile* self);
 void vala_source_file_set_mark (ValaSourceFile* self, gint value);
 ValaCodeContext* vala_source_file_get_context (ValaSourceFile* self);
 void vala_source_file_set_context (ValaSourceFile* self, ValaCodeContext* value);
-GType vala_source_file_get_type ();
+GType vala_source_file_get_type (void);
 
 G_END_DECLS
 
