@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,13 +20,12 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valastruct.h"
+#include <vala/valastruct.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
 #include <vala/valamethod.h>
 #include <vala/valasourcereference.h>
-#include <vala/valastruct.h>
 #include <vala/valasymbol.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valascope.h>
@@ -59,6 +58,7 @@ struct _ValaStructPrivate {
 	char* get_value_function;
 	char* set_value_function;
 	char* default_value;
+	gboolean simple_type;
 	ValaMethod* _default_construction_method;
 };
 #define VALA_STRUCT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRUCT, ValaStructPrivate))
@@ -100,8 +100,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
  * @param source_reference reference to source code
  * @return                 newly created struct
  */
-ValaStruct* vala_struct_new (const char* name, ValaSourceReference* source_reference)
-{
+ValaStruct* vala_struct_new (const char* name, ValaSourceReference* source_reference) {
 	ValaStruct * self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
@@ -117,13 +116,12 @@ ValaStruct* vala_struct_new (const char* name, ValaSourceReference* source_refer
  *
  * @param p a type parameter
  */
-void vala_struct_add_type_parameter (ValaStruct* self, ValaTypeParameter* p)
-{
+void vala_struct_add_type_parameter (ValaStruct* self, ValaTypeParameter* p) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_TYPE_PARAMETER (p));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_parameters), p);
 	p->type = VALA_DATA_TYPE (self);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) p)), VALA_SYMBOL (p));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (p)), VALA_SYMBOL (p));
 }
 
 
@@ -132,12 +130,11 @@ void vala_struct_add_type_parameter (ValaStruct* self, ValaTypeParameter* p)
  *
  * @param c a constant
  */
-void vala_struct_add_constant (ValaStruct* self, ValaConstant* c)
-{
+void vala_struct_add_constant (ValaStruct* self, ValaConstant* c) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_CONSTANT (c));
 	gee_collection_add (GEE_COLLECTION (self->priv->constants), c);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) c)), VALA_SYMBOL (c));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (c)), VALA_SYMBOL (c));
 }
 
 
@@ -146,12 +143,11 @@ void vala_struct_add_constant (ValaStruct* self, ValaConstant* c)
  *
  * @param f a field
  */
-void vala_struct_add_field (ValaStruct* self, ValaField* f)
-{
+void vala_struct_add_field (ValaStruct* self, ValaField* f) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_FIELD (f));
 	gee_collection_add (GEE_COLLECTION (self->priv->fields), f);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) f)), VALA_SYMBOL (f));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (f)), VALA_SYMBOL (f));
 }
 
 
@@ -160,8 +156,7 @@ void vala_struct_add_field (ValaStruct* self, ValaField* f)
  *
  * @return list of fields
  */
-GeeCollection* vala_struct_get_fields (ValaStruct* self)
-{
+GeeCollection* vala_struct_get_fields (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->fields)));
 }
@@ -172,8 +167,7 @@ GeeCollection* vala_struct_get_fields (ValaStruct* self)
  *
  * @param m a method
  */
-void vala_struct_add_method (ValaStruct* self, ValaMethod* m)
-{
+void vala_struct_add_method (ValaStruct* self, ValaMethod* m) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_METHOD (m));
 	g_return_if_fail (m != NULL);
@@ -186,13 +180,13 @@ void vala_struct_add_method (ValaStruct* self, ValaMethod* m)
 		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 		vala_type_reference_set_data_type (vala_formal_parameter_get_type_reference (vala_method_get_this_parameter (m)), VALA_DATA_TYPE (self));
-		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) m)), vala_symbol_get_name (((ValaSymbol*) vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
+		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
 	}
-	if (VALA_IS_CREATION_METHOD (m) && vala_symbol_get_name (((ValaSymbol*) m)) == NULL) {
+	if (VALA_IS_CREATION_METHOD (m) && vala_symbol_get_name (VALA_SYMBOL (m)) == NULL) {
 		vala_struct_set_default_construction_method (self, m);
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) m)), VALA_SYMBOL (m));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (m)), VALA_SYMBOL (m));
 }
 
 
@@ -201,27 +195,39 @@ void vala_struct_add_method (ValaStruct* self, ValaMethod* m)
  *
  * @return list of methods
  */
-GeeCollection* vala_struct_get_methods (ValaStruct* self)
-{
+GeeCollection* vala_struct_get_methods (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->methods)));
 }
 
 
-static void vala_struct_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_struct_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaStruct * self;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_struct (visitor, self);
 }
 
 
-static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaStruct * self;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	{
+		GeeList* type_collection;
+		GeeIterator* type_it;
+		type_collection = self->priv->base_types;
+		type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+		while (gee_iterator_next (type_it)) {
+			ValaTypeReference* type;
+			type = gee_iterator_get (type_it);
+			{
+				vala_code_node_accept (VALA_CODE_NODE (type), visitor);
+				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+			}
+		}
+		(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+	}
 	{
 		GeeList* p_collection;
 		GeeIterator* p_it;
@@ -285,11 +291,10 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 }
 
 
-static char* vala_struct_real_get_cname (ValaDataType* base, gboolean const_type)
-{
+static char* vala_struct_real_get_cname (ValaDataType* base, gboolean const_type) {
 	ValaStruct * self;
 	const char* _tmp4;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	if (const_type && self->priv->const_cname != NULL) {
 		const char* _tmp0;
 		_tmp0 = NULL;
@@ -300,7 +305,7 @@ static char* vala_struct_real_get_cname (ValaDataType* base, gboolean const_type
 		char* _tmp2;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		self->priv->cname = (_tmp3 = g_strdup_printf ("%s%s", (_tmp2 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp3);
+		self->priv->cname = (_tmp3 = g_strdup_printf ("%s%s", (_tmp2 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp3);
 		(_tmp2 = (g_free (_tmp2), NULL));
 	}
 	_tmp4 = NULL;
@@ -308,8 +313,7 @@ static char* vala_struct_real_get_cname (ValaDataType* base, gboolean const_type
 }
 
 
-static void vala_struct_set_cname (ValaStruct* self, const char* cname)
-{
+static void vala_struct_set_cname (ValaStruct* self, const char* cname) {
 	char* _tmp0;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (cname != NULL);
@@ -318,8 +322,7 @@ static void vala_struct_set_cname (ValaStruct* self, const char* cname)
 }
 
 
-static void vala_struct_set_const_cname (ValaStruct* self, const char* cname)
-{
+static void vala_struct_set_const_cname (ValaStruct* self, const char* cname) {
 	char* _tmp0;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (cname != NULL);
@@ -328,11 +331,10 @@ static void vala_struct_set_const_cname (ValaStruct* self, const char* cname)
 }
 
 
-static char* vala_struct_real_get_lower_case_cprefix (ValaSymbol* base)
-{
+static char* vala_struct_real_get_lower_case_cprefix (ValaSymbol* base) {
 	ValaStruct * self;
 	const char* _tmp2;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	if (self->priv->lower_case_cprefix == NULL) {
 		char* _tmp1;
 		char* _tmp0;
@@ -346,43 +348,40 @@ static char* vala_struct_real_get_lower_case_cprefix (ValaSymbol* base)
 }
 
 
-static char* vala_struct_get_lower_case_csuffix (ValaStruct* self)
-{
+static char* vala_struct_get_lower_case_csuffix (ValaStruct* self) {
 	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		self->priv->lower_case_csuffix = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp0);
+		self->priv->lower_case_csuffix = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp0);
 	}
 	_tmp1 = NULL;
 	return (_tmp1 = self->priv->lower_case_csuffix, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 }
 
 
-static char* vala_struct_real_get_lower_case_cname (ValaSymbol* base, const char* infix)
-{
+static char* vala_struct_real_get_lower_case_cname (ValaSymbol* base, const char* infix) {
 	ValaStruct * self;
 	char* _tmp1;
 	char* _tmp0;
 	char* _tmp2;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	if (infix == NULL) {
 		infix = "";
 	}
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	_tmp2 = NULL;
-	return (_tmp2 = g_strdup_printf ("%s%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), infix, (_tmp1 = vala_struct_get_lower_case_csuffix (self))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
+	return (_tmp2 = g_strdup_printf ("%s%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), infix, (_tmp1 = vala_struct_get_lower_case_csuffix (self))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
 }
 
 
-static char* vala_struct_real_get_upper_case_cname (ValaDataType* base, const char* infix)
-{
+static char* vala_struct_real_get_upper_case_cname (ValaDataType* base, const char* infix) {
 	ValaStruct * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	return (_tmp1 = g_utf8_strup ((_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), infix)), -1), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
@@ -394,8 +393,7 @@ static char* vala_struct_real_get_upper_case_cname (ValaDataType* base, const ch
  *
  * @return true if this is an integer type, false otherwise
  */
-gboolean vala_struct_is_integer_type (ValaStruct* self)
-{
+gboolean vala_struct_is_integer_type (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), FALSE);
 	return self->priv->integer_type;
 }
@@ -406,8 +404,7 @@ gboolean vala_struct_is_integer_type (ValaStruct* self)
  *
  * @return true if this is a floating point type, false otherwise
  */
-gboolean vala_struct_is_floating_type (ValaStruct* self)
-{
+gboolean vala_struct_is_floating_type (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), FALSE);
 	return self->priv->floating_type;
 }
@@ -418,15 +415,13 @@ gboolean vala_struct_is_floating_type (ValaStruct* self)
  *
  * @return the rank if this is an integer or floating point type
  */
-gint vala_struct_get_rank (ValaStruct* self)
-{
+gint vala_struct_get_rank (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), 0);
 	return self->priv->rank;
 }
 
 
-static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute* a)
-{
+static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
@@ -502,8 +497,7 @@ static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute
 }
 
 
-static void vala_struct_process_integer_type_attribute (ValaStruct* self, ValaAttribute* a)
-{
+static void vala_struct_process_integer_type_attribute (ValaStruct* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	self->priv->integer_type = TRUE;
@@ -513,8 +507,7 @@ static void vala_struct_process_integer_type_attribute (ValaStruct* self, ValaAt
 }
 
 
-static void vala_struct_process_floating_type_attribute (ValaStruct* self, ValaAttribute* a)
-{
+static void vala_struct_process_floating_type_attribute (ValaStruct* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	self->priv->floating_type = TRUE;
@@ -527,13 +520,12 @@ static void vala_struct_process_floating_type_attribute (ValaStruct* self, ValaA
 /**
  * Process all associated attributes.
  */
-void vala_struct_process_attributes (ValaStruct* self)
-{
+void vala_struct_process_attributes (ValaStruct* self) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = ((ValaCodeNode*) self)->attributes;
+		a_collection = VALA_CODE_NODE (self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
@@ -543,11 +535,15 @@ void vala_struct_process_attributes (ValaStruct* self)
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_struct_process_ccode_attribute (self, a);
 				} else {
-					if (g_utf8_collate (vala_attribute_get_name (a), "IntegerType") == 0) {
-						vala_struct_process_integer_type_attribute (self, a);
+					if (g_utf8_collate (vala_attribute_get_name (a), "SimpleType") == 0) {
+						self->priv->simple_type = TRUE;
 					} else {
-						if (g_utf8_collate (vala_attribute_get_name (a), "FloatingType") == 0) {
-							vala_struct_process_floating_type_attribute (self, a);
+						if (g_utf8_collate (vala_attribute_get_name (a), "IntegerType") == 0) {
+							vala_struct_process_integer_type_attribute (self, a);
+						} else {
+							if (g_utf8_collate (vala_attribute_get_name (a), "FloatingType") == 0) {
+								vala_struct_process_floating_type_attribute (self, a);
+							}
 						}
 					}
 				}
@@ -558,17 +554,16 @@ void vala_struct_process_attributes (ValaStruct* self)
 }
 
 
-static char* vala_struct_real_get_type_id (ValaDataType* base)
-{
+static char* vala_struct_real_get_type_id (ValaDataType* base) {
 	ValaStruct * self;
 	const char* _tmp2;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	if (self->priv->type_id == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (_tmp1 = g_strdup_printf ("The type `%s` doesn't declare a type id", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp1 = g_strdup_printf ("The type `%s` doesn't declare a type id", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
 		(_tmp1 = (g_free (_tmp1), NULL));
 		(_tmp0 = (g_free (_tmp0), NULL));
 	}
@@ -577,8 +572,7 @@ static char* vala_struct_real_get_type_id (ValaDataType* base)
 }
 
 
-void vala_struct_set_type_id (ValaStruct* self, const char* name)
-{
+void vala_struct_set_type_id (ValaStruct* self, const char* name) {
 	char* _tmp0;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (name != NULL);
@@ -587,17 +581,16 @@ void vala_struct_set_type_id (ValaStruct* self, const char* name)
 }
 
 
-static char* vala_struct_real_get_marshaller_type_name (ValaDataType* base)
-{
+static char* vala_struct_real_get_marshaller_type_name (ValaDataType* base) {
 	ValaStruct * self;
 	const char* _tmp2;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	if (self->priv->marshaller_type_name == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (_tmp1 = g_strdup_printf ("The type `%s` doesn't declare a marshaller type name", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp1 = g_strdup_printf ("The type `%s` doesn't declare a marshaller type name", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
 		(_tmp1 = (g_free (_tmp1), NULL));
 		(_tmp0 = (g_free (_tmp0), NULL));
 	}
@@ -606,8 +599,7 @@ static char* vala_struct_real_get_marshaller_type_name (ValaDataType* base)
 }
 
 
-static void vala_struct_set_marshaller_type_name (ValaStruct* self, const char* name)
-{
+static void vala_struct_set_marshaller_type_name (ValaStruct* self, const char* name) {
 	char* _tmp0;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (name != NULL);
@@ -616,16 +608,15 @@ static void vala_struct_set_marshaller_type_name (ValaStruct* self, const char*
 }
 
 
-static char* vala_struct_real_get_get_value_function (ValaDataType* base)
-{
+static char* vala_struct_real_get_get_value_function (ValaDataType* base) {
 	ValaStruct * self;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	if (self->priv->get_value_function == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (_tmp1 = g_strdup_printf ("The value type `%s` doesn't declare a GValue get function", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp1 = g_strdup_printf ("The value type `%s` doesn't declare a GValue get function", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
 		(_tmp1 = (g_free (_tmp1), NULL));
 		(_tmp0 = (g_free (_tmp0), NULL));
 		return NULL;
@@ -637,16 +628,15 @@ static char* vala_struct_real_get_get_value_function (ValaDataType* base)
 }
 
 
-static char* vala_struct_real_get_set_value_function (ValaDataType* base)
-{
+static char* vala_struct_real_get_set_value_function (ValaDataType* base) {
 	ValaStruct * self;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	if (self->priv->set_value_function == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (_tmp1 = g_strdup_printf ("The value type `%s` doesn't declare a GValue set function", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp1 = g_strdup_printf ("The value type `%s` doesn't declare a GValue set function", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
 		(_tmp1 = (g_free (_tmp1), NULL));
 		(_tmp0 = (g_free (_tmp0), NULL));
 		return NULL;
@@ -658,8 +648,7 @@ static char* vala_struct_real_get_set_value_function (ValaDataType* base)
 }
 
 
-static void vala_struct_set_get_value_function (ValaStruct* self, const char* function)
-{
+static void vala_struct_set_get_value_function (ValaStruct* self, const char* function) {
 	char* _tmp0;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (function != NULL);
@@ -668,8 +657,7 @@ static void vala_struct_set_get_value_function (ValaStruct* self, const char* fu
 }
 
 
-static void vala_struct_set_set_value_function (ValaStruct* self, const char* function)
-{
+static void vala_struct_set_set_value_function (ValaStruct* self, const char* function) {
 	char* _tmp0;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (function != NULL);
@@ -678,18 +666,16 @@ static void vala_struct_set_set_value_function (ValaStruct* self, const char* fu
 }
 
 
-static char* vala_struct_real_get_default_value (ValaDataType* base)
-{
+static char* vala_struct_real_get_default_value (ValaDataType* base) {
 	ValaStruct * self;
 	const char* _tmp0;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	_tmp0 = NULL;
 	return (_tmp0 = self->priv->default_value, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 }
 
 
-static void vala_struct_set_default_value (ValaStruct* self, const char* value)
-{
+static void vala_struct_set_default_value (ValaStruct* self, const char* value) {
 	char* _tmp0;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (value != NULL);
@@ -703,8 +689,7 @@ static void vala_struct_set_default_value (ValaStruct* self, const char* value)
  *
  * @param type a class or interface reference
  */
-void vala_struct_add_base_type (ValaStruct* self, ValaTypeReference* type)
-{
+void vala_struct_add_base_type (ValaStruct* self, ValaTypeReference* type) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (type));
 	gee_collection_add (GEE_COLLECTION (self->priv->base_types), type);
@@ -716,18 +701,16 @@ void vala_struct_add_base_type (ValaStruct* self, ValaTypeReference* type)
  *
  * @return list of base types
  */
-GeeCollection* vala_struct_get_base_types (ValaStruct* self)
-{
+GeeCollection* vala_struct_get_base_types (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->base_types)));
 }
 
 
-static gint vala_struct_real_get_type_parameter_index (ValaDataType* base, const char* name)
-{
+static gint vala_struct_real_get_type_parameter_index (ValaDataType* base, const char* name) {
 	ValaStruct * self;
 	gint i;
-	self = ((ValaStruct*) base);
+	self = VALA_STRUCT (base);
 	g_return_val_if_fail (name != NULL, 0);
 	i = 0;
 	{
@@ -739,7 +722,7 @@ static gint vala_struct_real_get_type_parameter_index (ValaDataType* base, const
 			ValaTypeParameter* p;
 			p = gee_iterator_get (p_it);
 			{
-				if (g_utf8_collate (vala_symbol_get_name (((ValaSymbol*) p)), name) == 0) {
+				if (g_utf8_collate (vala_symbol_get_name (VALA_SYMBOL (p)), name) == 0) {
 					gint _tmp0;
 					return (_tmp0 = (i), (p == NULL ? NULL : (p = (g_object_unref (p), NULL))), (p_it == NULL ? NULL : (p_it = (g_object_unref (p_it), NULL))), _tmp0);
 				}
@@ -753,15 +736,48 @@ static gint vala_struct_real_get_type_parameter_index (ValaDataType* base, const
 }
 
 
-ValaMethod* vala_struct_get_default_construction_method (ValaStruct* self)
-{
+/**
+ * Returns whether this struct is a simple type, i.e. whether
+ * instances are passed by value.
+ */
+gboolean vala_struct_is_simple_type (ValaStruct* self) {
+	g_return_val_if_fail (VALA_IS_STRUCT (self), FALSE);
+	{
+		GeeList* type_collection;
+		GeeIterator* type_it;
+		type_collection = self->priv->base_types;
+		type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+		while (gee_iterator_next (type_it)) {
+			ValaTypeReference* type;
+			type = gee_iterator_get (type_it);
+			{
+				ValaStruct* _tmp1;
+				ValaDataType* _tmp0;
+				ValaStruct* st;
+				_tmp1 = NULL;
+				_tmp0 = NULL;
+				st = (_tmp1 = (_tmp0 = vala_type_reference_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				if (st != NULL && vala_struct_is_simple_type (st)) {
+					gboolean _tmp2;
+					return (_tmp2 = TRUE, (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), (type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL))), _tmp2);
+				}
+				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+			}
+		}
+		(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+	}
+	return self->priv->simple_type;
+}
+
+
+ValaMethod* vala_struct_get_default_construction_method (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
 	return self->priv->_default_construction_method;
 }
 
 
-void vala_struct_set_default_construction_method (ValaStruct* self, ValaMethod* value)
-{
+void vala_struct_set_default_construction_method (ValaStruct* self, ValaMethod* value) {
 	ValaMethod* _tmp2;
 	ValaMethod* _tmp1;
 	g_return_if_fail (VALA_IS_STRUCT (self));
@@ -771,8 +787,7 @@ void vala_struct_set_default_construction_method (ValaStruct* self, ValaMethod*
 }
 
 
-static void vala_struct_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_struct_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaStruct * self;
 	self = VALA_STRUCT (object);
 	switch (property_id) {
@@ -786,8 +801,7 @@ static void vala_struct_get_property (GObject * object, guint property_id, GValu
 }
 
 
-static void vala_struct_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_struct_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaStruct * self;
 	self = VALA_STRUCT (object);
 	switch (property_id) {
@@ -801,8 +815,7 @@ static void vala_struct_set_property (GObject * object, guint property_id, const
 }
 
 
-static void vala_struct_class_init (ValaStructClass * klass)
-{
+static void vala_struct_class_init (ValaStructClass * klass) {
 	vala_struct_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaStructPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_struct_get_property;
@@ -820,12 +833,11 @@ static void vala_struct_class_init (ValaStructClass * klass)
 	VALA_DATA_TYPE_CLASS (klass)->get_set_value_function = vala_struct_real_get_set_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_default_value = vala_struct_real_get_default_value;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_parameter_index = vala_struct_real_get_type_parameter_index;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD, g_param_spec_object ("default-construction-method", "foo", "bar", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD, g_param_spec_object ("default-construction-method", "default-construction-method", "default-construction-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_struct_init (ValaStruct * self)
-{
+static void vala_struct_init (ValaStruct * self) {
 	self->priv = VALA_STRUCT_GET_PRIVATE (self);
 	self->priv->type_parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->constants = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
@@ -836,11 +848,8 @@ static void vala_struct_init (ValaStruct * self)
 }
 
 
-static void vala_struct_dispose (GObject * obj)
-{
+static void vala_struct_dispose (GObject * obj) {
 	ValaStruct * self;
-	ValaStructClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_STRUCT (obj);
 	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
 	(self->priv->constants == NULL ? NULL : (self->priv->constants = (g_object_unref (self->priv->constants), NULL)));
@@ -859,14 +868,11 @@ static void vala_struct_dispose (GObject * obj)
 	(self->priv->set_value_function = (g_free (self->priv->set_value_function), NULL));
 	(self->priv->default_value = (g_free (self->priv->default_value), NULL));
 	(self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL)));
-	klass = VALA_STRUCT_CLASS (g_type_class_peek (VALA_TYPE_STRUCT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_struct_parent_class)->dispose (obj);
 }
 
 
-GType vala_struct_get_type (void)
-{
+GType vala_struct_get_type (void) {
 	static GType vala_struct_type_id = 0;
 	if (G_UNLIKELY (vala_struct_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaStructClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_struct_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStruct), 0, (GInstanceInitFunc) vala_struct_init };
@@ -876,8 +882,7 @@ GType vala_struct_get_type (void)
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
-{
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
 		if (array_length >= 0)
