@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,12 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaswitchsection.h"
+#include <vala/valaswitchsection.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaswitchsection.h>
 #include <vala/valaswitchlabel.h>
 #include <vala/valastatement.h>
 #include <vala/valacodevisitor.h>
@@ -39,6 +38,7 @@ enum  {
 	VALA_SWITCH_SECTION_DUMMY_PROPERTY
 };
 static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_switch_section_parent_class = NULL;
 static void vala_switch_section_dispose (GObject * obj);
 
@@ -49,8 +49,7 @@ static void vala_switch_section_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created switch section
  */
-ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference)
-{
+ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference) {
 	ValaSwitchSection * self;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_SWITCH_SECTION, 0, NULL);
@@ -64,8 +63,7 @@ ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_referenc
  *
  * @param label a switch label
  */
-void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* label)
-{
+void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* label) {
 	g_return_if_fail (VALA_IS_SWITCH_SECTION (self));
 	g_return_if_fail (VALA_IS_SWITCH_LABEL (label));
 	gee_collection_add (GEE_COLLECTION (self->priv->labels), label);
@@ -77,15 +75,13 @@ void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* la
  *
  * @return switch label list
  */
-GeeCollection* vala_switch_section_get_labels (ValaSwitchSection* self)
-{
+GeeCollection* vala_switch_section_get_labels (ValaSwitchSection* self) {
 	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->labels)));
 }
 
 
-gboolean vala_switch_section_has_default_label (ValaSwitchSection* self)
-{
+gboolean vala_switch_section_has_default_label (ValaSwitchSection* self) {
 	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), FALSE);
 	{
 		GeeList* label_collection;
@@ -114,8 +110,7 @@ gboolean vala_switch_section_has_default_label (ValaSwitchSection* self)
  *
  * @param stmt a statement
  */
-void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement* stmt)
-{
+void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement* stmt) {
 	g_return_if_fail (VALA_IS_SWITCH_SECTION (self));
 	g_return_if_fail (VALA_IS_STATEMENT (stmt));
 	gee_collection_add (GEE_COLLECTION (self->priv->statement_list), stmt);
@@ -127,17 +122,23 @@ void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement*
  *
  * @return statement list
  */
-GeeCollection* vala_switch_section_get_statements (ValaSwitchSection* self)
-{
+GeeCollection* vala_switch_section_get_statements (ValaSwitchSection* self) {
 	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->statement_list)));
 }
 
 
-static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSwitchSection * self;
-	self = ((ValaSwitchSection*) base);
+	self = VALA_SWITCH_SECTION (base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_switch_section (visitor, self);
+}
+
+
+static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
+	ValaSwitchSection * self;
+	self = VALA_SWITCH_SECTION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* label_collection;
@@ -154,7 +155,6 @@ static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor
 		}
 		(label_it == NULL ? NULL : (label_it = (g_object_unref (label_it), NULL)));
 	}
-	vala_code_visitor_visit_begin_block (visitor, VALA_BLOCK (self));
 	{
 		GeeList* st_collection;
 		GeeIterator* st_it;
@@ -170,44 +170,35 @@ static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor
 		}
 		(st_it == NULL ? NULL : (st_it = (g_object_unref (st_it), NULL)));
 	}
-	vala_code_visitor_visit_switch_section (visitor, self);
-	vala_code_visitor_visit_end_block (visitor, VALA_BLOCK (self));
 }
 
 
-static void vala_switch_section_class_init (ValaSwitchSectionClass * klass)
-{
+static void vala_switch_section_class_init (ValaSwitchSectionClass * klass) {
 	vala_switch_section_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaSwitchSectionPrivate));
 	G_OBJECT_CLASS (klass)->dispose = vala_switch_section_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_switch_section_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_switch_section_real_accept_children;
 }
 
 
-static void vala_switch_section_init (ValaSwitchSection * self)
-{
+static void vala_switch_section_init (ValaSwitchSection * self) {
 	self->priv = VALA_SWITCH_SECTION_GET_PRIVATE (self);
 	self->priv->labels = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->statement_list = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_switch_section_dispose (GObject * obj)
-{
+static void vala_switch_section_dispose (GObject * obj) {
 	ValaSwitchSection * self;
-	ValaSwitchSectionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_SWITCH_SECTION (obj);
 	(self->priv->labels == NULL ? NULL : (self->priv->labels = (g_object_unref (self->priv->labels), NULL)));
 	(self->priv->statement_list == NULL ? NULL : (self->priv->statement_list = (g_object_unref (self->priv->statement_list), NULL)));
-	klass = VALA_SWITCH_SECTION_CLASS (g_type_class_peek (VALA_TYPE_SWITCH_SECTION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_switch_section_parent_class)->dispose (obj);
 }
 
 
-GType vala_switch_section_get_type (void)
-{
+GType vala_switch_section_get_type (void) {
 	static GType vala_switch_section_type_id = 0;
 	if (G_UNLIKELY (vala_switch_section_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchSection), 0, (GInstanceInitFunc) vala_switch_section_init };
