@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,13 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALASWITCHSECTION_H__
-#define __VALASWITCHSECTION_H__
+#ifndef __VALA_VALASWITCHSECTION_H__
+#define __VALA_VALASWITCHSECTION_H__
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collection.h>
+#include <vala/valablock.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -43,20 +45,20 @@ typedef struct _ValaSwitchSectionPrivate ValaSwitchSectionPrivate;
  * Represents a switch section in the source code.
  */
 struct _ValaSwitchSection {
-	ValaCodeNode parent;
+	ValaBlock parent;
 	ValaSwitchSectionPrivate * priv;
 };
 struct _ValaSwitchSectionClass {
-	ValaCodeNodeClass parent;
+	ValaBlockClass parent;
 };
 
-ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source);
+ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference);
 void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* label);
-GList* vala_switch_section_get_labels (ValaSwitchSection* self);
+GeeCollection* vala_switch_section_get_labels (ValaSwitchSection* self);
 gboolean vala_switch_section_has_default_label (ValaSwitchSection* self);
 void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement* stmt);
-GList* vala_switch_section_get_statements (ValaSwitchSection* self);
-GType vala_switch_section_get_type ();
+GeeCollection* vala_switch_section_get_statements (ValaSwitchSection* self);
+GType vala_switch_section_get_type (void);
 
 G_END_DECLS
 
