@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valasymbol.h"
+#include <vala/valasymbol.h>
 #include <gee/readonlycollection.h>
 #include <vala/valascope.h>
 
@@ -57,8 +57,7 @@ static void vala_symbol_dispose (GObject * obj);
  * to be listed in header files for instance) by traversing parent symbols
  * and checking their accessibility.
  */
-gboolean vala_symbol_is_internal_symbol (ValaSymbol* self)
-{
+gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
 	{
 		ValaSymbol* sym;
@@ -89,8 +88,7 @@ gboolean vala_symbol_is_internal_symbol (ValaSymbol* self)
  *
  * @return full name
  */
-char* vala_symbol_get_full_name (ValaSymbol* self)
-{
+char* vala_symbol_get_full_name (ValaSymbol* self) {
 	char* _tmp3;
 	gboolean _tmp4;
 	char* _tmp7;
@@ -122,8 +120,7 @@ char* vala_symbol_get_full_name (ValaSymbol* self)
  *
  * @return the camel case prefix to be used in C code
  */
-static char* vala_symbol_real_get_cprefix (ValaSymbol* self)
-{
+static char* vala_symbol_real_get_cprefix (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	if (vala_symbol_get_name (self) == NULL) {
 		return g_strdup ("");
@@ -135,8 +132,7 @@ static char* vala_symbol_real_get_cprefix (ValaSymbol* self)
 }
 
 
-char* vala_symbol_get_cprefix (ValaSymbol* self)
-{
+char* vala_symbol_get_cprefix (ValaSymbol* self) {
 	return VALA_SYMBOL_GET_CLASS (self)->get_cprefix (self);
 }
 
@@ -150,15 +146,13 @@ char* vala_symbol_get_cprefix (ValaSymbol* self)
  *              name or null
  * @return      the lower case name to be used in C code
  */
-static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix)
-{
+static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return NULL;
 }
 
 
-char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix)
-{
+char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix) {
 	return VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cname (self, infix);
 }
 
@@ -169,15 +163,13 @@ char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix)
  *
  * @return      the lower case prefix to be used in C code
  */
-static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self)
-{
+static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return g_strdup ("");
 }
 
 
-char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self)
-{
+char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self) {
 	return VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cprefix (self);
 }
 
@@ -188,15 +180,13 @@ char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self)
  *
  * @return list of C header filenames for this symbol
  */
-static GeeCollection* vala_symbol_real_get_cheader_filenames (ValaSymbol* self)
-{
+static GeeCollection* vala_symbol_real_get_cheader_filenames (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, NULL));
 }
 
 
-GeeCollection* vala_symbol_get_cheader_filenames (ValaSymbol* self)
-{
+GeeCollection* vala_symbol_get_cheader_filenames (ValaSymbol* self) {
 	return VALA_SYMBOL_GET_CLASS (self)->get_cheader_filenames (self);
 }
 
@@ -207,8 +197,7 @@ GeeCollection* vala_symbol_get_cheader_filenames (ValaSymbol* self)
  * @param camel_case a string in camel case
  * @return           the specified string converted to lower case
  */
-char* vala_symbol_camel_case_to_lower_case (const char* camel_case)
-{
+char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 	GString* result;
 	const char* i;
 	gboolean first;
@@ -253,41 +242,36 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case)
 }
 
 
-ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self)
-{
+ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	if (vala_symbol_get_owner (self) == NULL) {
-		return VALA_SYMBOL (NULL);
+		return NULL;
 	} else {
 		return vala_scope_get_owner (vala_symbol_get_owner (self));
 	}
 }
 
 
-ValaScope* vala_symbol_get_owner (ValaSymbol* self)
-{
+ValaScope* vala_symbol_get_owner (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return self->priv->_owner;
 }
 
 
-void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value)
-{
+void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_owner = value;
 	vala_scope_set_parent_scope (self->priv->_scope, value);
 }
 
 
-char* vala_symbol_get_name (ValaSymbol* self)
-{
+char* vala_symbol_get_name (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return self->priv->_name;
 }
 
 
-void vala_symbol_set_name (ValaSymbol* self, const char* value)
-{
+void vala_symbol_set_name (ValaSymbol* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
 	g_return_if_fail (VALA_IS_SYMBOL (self));
@@ -297,57 +281,49 @@ void vala_symbol_set_name (ValaSymbol* self, const char* value)
 }
 
 
-gboolean vala_symbol_get_active (ValaSymbol* self)
-{
+gboolean vala_symbol_get_active (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
 	return self->priv->_active;
 }
 
 
-void vala_symbol_set_active (ValaSymbol* self, gboolean value)
-{
+void vala_symbol_set_active (ValaSymbol* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_active = value;
 }
 
 
-ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self)
-{
+ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), 0);
 	return self->priv->_access;
 }
 
 
-void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value)
-{
+void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_access = value;
 }
 
 
-ValaScope* vala_symbol_get_scope (ValaSymbol* self)
-{
+ValaScope* vala_symbol_get_scope (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return self->priv->_scope;
 }
 
 
-gboolean vala_symbol_get_is_imported (ValaSymbol* self)
-{
+gboolean vala_symbol_get_is_imported (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
 	return self->priv->_is_imported;
 }
 
 
-void vala_symbol_set_is_imported (ValaSymbol* self, gboolean value)
-{
+void vala_symbol_set_is_imported (ValaSymbol* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_is_imported = value;
 }
 
 
-static GObject * vala_symbol_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties)
-{
+static GObject * vala_symbol_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
 	GObject * obj;
 	ValaSymbolClass * klass;
 	GObjectClass * parent_class;
@@ -366,8 +342,7 @@ static GObject * vala_symbol_constructor (GType type, guint n_construct_properti
 }
 
 
-static void vala_symbol_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_symbol_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaSymbol * self;
 	self = VALA_SYMBOL (object);
 	switch (property_id) {
@@ -399,8 +374,7 @@ static void vala_symbol_get_property (GObject * object, guint property_id, GValu
 }
 
 
-static void vala_symbol_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_symbol_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaSymbol * self;
 	self = VALA_SYMBOL (object);
 	switch (property_id) {
@@ -426,8 +400,7 @@ static void vala_symbol_set_property (GObject * object, guint property_id, const
 }
 
 
-static void vala_symbol_class_init (ValaSymbolClass * klass)
-{
+static void vala_symbol_class_init (ValaSymbolClass * klass) {
 	vala_symbol_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaSymbolPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_symbol_get_property;
@@ -438,38 +411,31 @@ static void vala_symbol_class_init (ValaSymbolClass * klass)
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_symbol_real_get_lower_case_cname;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_symbol_real_get_lower_case_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_symbol_real_get_cheader_filenames;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_PARENT_SYMBOL, g_param_spec_object ("parent-symbol", "foo", "bar", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_OWNER, g_param_spec_object ("owner", "foo", "bar", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACTIVE, g_param_spec_boolean ("active", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACCESS, g_param_spec_int ("access", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_SCOPE, g_param_spec_object ("scope", "foo", "bar", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_IS_IMPORTED, g_param_spec_boolean ("is-imported", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_PARENT_SYMBOL, g_param_spec_object ("parent-symbol", "parent-symbol", "parent-symbol", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_OWNER, g_param_spec_object ("owner", "owner", "owner", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACTIVE, g_param_spec_boolean ("active", "active", "active", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACCESS, g_param_spec_int ("access", "access", "access", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_SCOPE, g_param_spec_object ("scope", "scope", "scope", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_IS_IMPORTED, g_param_spec_boolean ("is-imported", "is-imported", "is-imported", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_symbol_init (ValaSymbol * self)
-{
+static void vala_symbol_init (ValaSymbol * self) {
 	self->priv = VALA_SYMBOL_GET_PRIVATE (self);
 }
 
 
-static void vala_symbol_dispose (GObject * obj)
-{
+static void vala_symbol_dispose (GObject * obj) {
 	ValaSymbol * self;
-	ValaSymbolClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_SYMBOL (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL)));
-	klass = VALA_SYMBOL_CLASS (g_type_class_peek (VALA_TYPE_SYMBOL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_symbol_parent_class)->dispose (obj);
 }
 
 
-GType vala_symbol_get_type (void)
-{
+GType vala_symbol_get_type (void) {
 	static GType vala_symbol_type_id = 0;
 	if (G_UNLIKELY (vala_symbol_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSymbolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_symbol_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSymbol), 0, (GInstanceInitFunc) vala_symbol_init };
