@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valavapigen.h"
+#include <vapigen/valavapigen.h>
+#include <stdlib.h>
+#include <string.h>
 #include <vala/valacodecontext.h>
 #include <vala/valareport.h>
 #include <stdio.h>
@@ -31,7 +33,8 @@
 #include <vala/valaattributeprocessor.h>
 #include <vala/valasymbolresolver.h>
 #include <vala/valainterfacewriter.h>
-#include "valagidlparser.h"
+#include <config.h>
+#include "vapigen/valagidlparser.h"
 
 typedef struct _ValaVAPIGen ValaVAPIGen;
 typedef struct _ValaVAPIGenClass ValaVAPIGenClass;
@@ -68,15 +71,17 @@ static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", 0, 0, G_OPTION_
 static gint vala_vapi_gen_quit (ValaVAPIGen* self);
 static char* vala_vapi_gen_get_package_path (ValaVAPIGen* self, const char* pkg);
 static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg);
+static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1);
 static gint vala_vapi_gen_run (ValaVAPIGen* self);
 static gint vala_vapi_gen_main (int args_length1, char** args);
+static ValaVAPIGen* vala_vapi_gen_new (void);
 static gpointer vala_vapi_gen_parent_class = NULL;
 static void vala_vapi_gen_dispose (GObject * obj);
-GType vala_vapi_gen_get_type (void);
+static GType vala_vapi_gen_get_type (void);
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
-static gint vala_vapi_gen_quit (ValaVAPIGen* self)
-{
+static gint vala_vapi_gen_quit (ValaVAPIGen* self) {
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), 0);
 	if (vala_report_get_errors () == 0) {
 		fprintf (stdout, "Generation succeeded - %d warning(s)\n", vala_report_get_warnings ());
@@ -88,32 +93,33 @@ static gint vala_vapi_gen_quit (ValaVAPIGen* self)
 }
 
 
-static char* vala_vapi_gen_get_package_path (ValaVAPIGen* self, const char* pkg)
-{
+static char* vala_vapi_gen_get_package_path (ValaVAPIGen* self, const char* pkg) {
 	char* basename;
 	char* filename;
-	char* __temp5;
-	gpointer __temp7;
+	char* _tmp3;
+	gpointer _tmp5;
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), NULL);
 	g_return_val_if_fail (pkg != NULL, NULL);
-	basename = g_strdup_printf ("%s.vala", pkg);
+	basename = g_strdup_printf ("%s.vapi", pkg);
 	if (vala_vapi_gen_vapi_directories != NULL) {
 		{
 			char** vapidir_collection;
 			char** vapidir_it;
+			int vapidir_collection_length1;
 			vapidir_collection = vala_vapi_gen_vapi_directories;
+			vapidir_collection_length1 = -1;
 			for (vapidir_it = vapidir_collection; *vapidir_it != NULL; vapidir_it = vapidir_it + 1) {
-				const char* __temp3;
+				const char* _tmp1;
 				char* vapidir;
-				__temp3 = NULL;
-				vapidir = (__temp3 = *vapidir_it, (__temp3 == NULL ? NULL : g_strdup (__temp3)));
+				_tmp1 = NULL;
+				vapidir = (_tmp1 = *vapidir_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 				{
 					char* filename;
 					filename = g_build_filename (vapidir, basename, NULL, NULL);
 					if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-						char* __temp2;
-						__temp2 = NULL;
-						return (__temp2 = filename, (vapidir = (g_free (vapidir), NULL)), (basename = (g_free (basename), NULL)), __temp2);
+						char* _tmp0;
+						_tmp0 = NULL;
+						return (_tmp0 = filename, (vapidir = (g_free (vapidir), NULL)), (basename = (g_free (basename), NULL)), _tmp0);
 					}
 					(vapidir = (g_free (vapidir), NULL));
 					(filename = (g_free (filename), NULL));
@@ -123,83 +129,168 @@ static char* vala_vapi_gen_get_package_path (ValaVAPIGen* self, const char* pkg)
 	}
 	filename = g_build_filename ("/usr/local/share/vala/vapi", basename, NULL, NULL);
 	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		char* __temp4;
-		__temp4 = NULL;
-		return (__temp4 = filename, (basename = (g_free (basename), NULL)), __temp4);
+		char* _tmp2;
+		_tmp2 = NULL;
+		return (_tmp2 = filename, (basename = (g_free (basename), NULL)), _tmp2);
 	}
-	__temp5 = NULL;
-	filename = (__temp5 = g_build_filename ("/usr/share/vala/vapi", basename, NULL, NULL), (filename = (g_free (filename), NULL)), __temp5);
+	_tmp3 = NULL;
+	filename = (_tmp3 = g_build_filename ("/usr/share/vala/vapi", basename, NULL, NULL), (filename = (g_free (filename), NULL)), _tmp3);
 	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		char* __temp6;
-		__temp6 = NULL;
-		return (__temp6 = filename, (basename = (g_free (basename), NULL)), __temp6);
+		char* _tmp4;
+		_tmp4 = NULL;
+		return (_tmp4 = filename, (basename = (g_free (basename), NULL)), _tmp4);
 	}
-	return (__temp7 = NULL, (basename = (g_free (basename), NULL)), (filename = (g_free (filename), NULL)), __temp7);
+	return (_tmp5 = NULL, (basename = (g_free (basename), NULL)), (filename = (g_free (filename), NULL)), _tmp5);
 	(basename = (g_free (basename), NULL));
 	(filename = (g_free (filename), NULL));
 }
 
 
-static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg)
-{
+static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
 	char* package_path;
-	ValaSourceFile* __temp9;
-	gboolean __temp10;
+	ValaSourceFile* _tmp2;
+	gboolean _tmp3;
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), FALSE);
 	g_return_val_if_fail (pkg != NULL, FALSE);
+	if (vala_code_context_has_package (self->priv->context, pkg)) {
+		return TRUE;
+	}
+	/* ignore multiple occurences of the same package*/
 	package_path = vala_vapi_gen_get_package_path (self, pkg);
 	if (package_path == NULL) {
-		gboolean __temp8;
-		return (__temp8 = FALSE, (package_path = (g_free (package_path), NULL)), __temp8);
+		gboolean _tmp1;
+		return (_tmp1 = FALSE, (package_path = (g_free (package_path), NULL)), _tmp1);
 	}
-	__temp9 = NULL;
-	vala_code_context_add_source_file (self->priv->context, (__temp9 = vala_source_file_new (self->priv->context, package_path, TRUE)));
-	(__temp9 == NULL ? NULL : (__temp9 = (g_object_unref (__temp9), NULL)));
-	return (__temp10 = TRUE, (package_path = (g_free (package_path), NULL)), __temp10);
+	_tmp2 = NULL;
+	vala_code_context_add_source_file (self->priv->context, (_tmp2 = vala_source_file_new (self->priv->context, package_path, TRUE)));
+	(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+	return (_tmp3 = TRUE, (package_path = (g_free (package_path), NULL)), _tmp3);
 	(package_path = (g_free (package_path), NULL));
 }
 
 
-static gint vala_vapi_gen_run (ValaVAPIGen* self)
-{
-	ValaCodeContext* __temp11;
-	char** __temp19;
+static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1) {
+	GError * inner_error;
+	char* contents;
+	gpointer _tmp2;
+	gpointer _tmp3;
+	inner_error = NULL;
+	contents = NULL;
+	if (g_file_get_contents (depsfile, &contents, NULL, &inner_error)) {
+		char** _tmp0;
+		char** _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = (_tmp0 = g_strsplit (g_strstrip (contents), "\n", 0), *result_length1 = -1, _tmp0), (contents = (g_free (contents), NULL)), _tmp1);
+	}
+	return (_tmp3 = (_tmp2 = NULL, *result_length1 = -1, _tmp2), (contents = (g_free (contents), NULL)), _tmp3);
+	(contents = (g_free (contents), NULL));
+}
+
+
+static gint vala_vapi_gen_run (ValaVAPIGen* self) {
+	ValaCodeContext* _tmp0;
+	char** _tmp16;
 	ValaParser* parser;
-	ValaGIdlParser* gidlparser;
 	ValaAttributeProcessor* attributeprocessor;
+	ValaGIdlParser* gidlparser;
 	ValaSymbolResolver* resolver;
-	gint __temp27;
+	gint _tmp24;
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), 0);
-	__temp11 = NULL;
-	self->priv->context = (__temp11 = g_object_new (VALA_TYPE_CODE_CONTEXT, NULL), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), __temp11);
+	_tmp0 = NULL;
+	self->priv->context = (_tmp0 = vala_code_context_new (), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), _tmp0);
 	/* default package */
 	if (!vala_vapi_gen_add_package (self, "glib-2.0")) {
 		vala_report_error (NULL, "glib-2.0 not found in specified Vala API directories");
 	}
+	{
+		char** source_collection;
+		char** source_it;
+		int source_collection_length1;
+		source_collection = vala_vapi_gen_sources;
+		source_collection_length1 = -1;
+		for (source_it = source_collection; *source_it != NULL; source_it = source_it + 1) {
+			const char* _tmp8;
+			char* source;
+			_tmp8 = NULL;
+			source = (_tmp8 = *source_it, (_tmp8 == NULL ? NULL : g_strdup (_tmp8)));
+			{
+				char* _tmp2;
+				char* _tmp1;
+				char* _tmp3;
+				char* depsfile;
+				char** _tmp5;
+				gint deps_length1;
+				gint _tmp4;
+				char** deps;
+				/* load packages from .deps file */
+				if (!g_str_has_suffix (source, ".gidl")) {
+					(source = (g_free (source), NULL));
+					continue;
+				}
+				_tmp2 = NULL;
+				_tmp1 = NULL;
+				_tmp3 = NULL;
+				depsfile = (_tmp3 = g_strconcat ((_tmp2 = g_utf8_offset_to_pointer (source, 0), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (source, -1) - 4) - _tmp2)), "deps", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp3);
+				if (!g_file_test (depsfile, G_FILE_TEST_EXISTS)) {
+					(source = (g_free (source), NULL));
+					(depsfile = (g_free (depsfile), NULL));
+					continue;
+				}
+				_tmp5 = NULL;
+				deps = (_tmp5 = vala_vapi_gen_get_packages_from_depsfile (depsfile, &_tmp4), deps_length1 = _tmp4, _tmp5);
+				{
+					char** dep_collection;
+					int dep_it;
+					dep_collection = deps;
+					for (dep_it = 0; (deps_length1 != -1 && dep_it < deps_length1) || (deps_length1 == -1 && dep_collection[dep_it] != NULL); dep_it = dep_it + 1) {
+						const char* _tmp7;
+						char* dep;
+						_tmp7 = NULL;
+						dep = (_tmp7 = dep_collection[dep_it], (_tmp7 == NULL ? NULL : g_strdup (_tmp7)));
+						{
+							if (!vala_vapi_gen_add_package (self, dep)) {
+								char* _tmp6;
+								_tmp6 = NULL;
+								vala_report_error (NULL, (_tmp6 = g_strdup_printf ("%s not found in specified Vala API directories", dep)));
+								(_tmp6 = (g_free (_tmp6), NULL));
+							}
+							(dep = (g_free (dep), NULL));
+						}
+					}
+				}
+				(source = (g_free (source), NULL));
+				(depsfile = (g_free (depsfile), NULL));
+				(deps = (_vala_array_free (deps, deps_length1, ((GDestroyNotify) g_free)), NULL));
+			}
+		}
+	}
 	if (vala_vapi_gen_packages != NULL) {
-		char** __temp14;
+		char** _tmp11;
 		{
 			char** package_collection;
 			char** package_it;
+			int package_collection_length1;
 			package_collection = vala_vapi_gen_packages;
+			package_collection_length1 = -1;
 			for (package_it = package_collection; *package_it != NULL; package_it = package_it + 1) {
-				const char* __temp13;
+				const char* _tmp10;
 				char* package;
-				__temp13 = NULL;
-				package = (__temp13 = *package_it, (__temp13 == NULL ? NULL : g_strdup (__temp13)));
+				_tmp10 = NULL;
+				package = (_tmp10 = *package_it, (_tmp10 == NULL ? NULL : g_strdup (_tmp10)));
 				{
 					if (!vala_vapi_gen_add_package (self, package)) {
-						char* __temp12;
-						__temp12 = NULL;
-						vala_report_error (NULL, (__temp12 = g_strdup_printf ("%s not found in specified Vala API directories", package)));
-						(__temp12 = (g_free (__temp12), NULL));
+						char* _tmp9;
+						_tmp9 = NULL;
+						vala_report_error (NULL, (_tmp9 = g_strdup_printf ("%s not found in specified Vala API directories", package)));
+						(_tmp9 = (g_free (_tmp9), NULL));
 					}
 					(package = (g_free (package), NULL));
 				}
 			}
 		}
-		__temp14 = NULL;
-		vala_vapi_gen_packages = (__temp14 = NULL, (vala_vapi_gen_packages = (g_strfreev (vala_vapi_gen_packages), NULL)), __temp14);
+		_tmp11 = NULL;
+		vala_vapi_gen_packages = (_tmp11 = NULL, (vala_vapi_gen_packages = (_vala_array_free (vala_vapi_gen_packages, -1, ((GDestroyNotify) g_free)), NULL)), _tmp11);
 	}
 	if (vala_report_get_errors () > 0) {
 		return vala_vapi_gen_quit (self);
@@ -207,82 +298,83 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self)
 	{
 		char** source_collection;
 		char** source_it;
+		int source_collection_length1;
 		source_collection = vala_vapi_gen_sources;
+		source_collection_length1 = -1;
 		for (source_it = source_collection; *source_it != NULL; source_it = source_it + 1) {
-			const char* __temp18;
+			const char* _tmp15;
 			char* source;
-			__temp18 = NULL;
-			source = (__temp18 = *source_it, (__temp18 == NULL ? NULL : g_strdup (__temp18)));
+			_tmp15 = NULL;
+			source = (_tmp15 = *source_it, (_tmp15 == NULL ? NULL : g_strdup (_tmp15)));
 			{
 				if (g_file_test (source, G_FILE_TEST_EXISTS)) {
-					ValaSourceFile* __temp16;
-					__temp16 = NULL;
-					vala_code_context_add_source_file (self->priv->context, (__temp16 = vala_source_file_new (self->priv->context, source, FALSE)));
-					(__temp16 == NULL ? NULL : (__temp16 = (g_object_unref (__temp16), NULL)));
+					ValaSourceFile* _tmp13;
+					_tmp13 = NULL;
+					vala_code_context_add_source_file (self->priv->context, (_tmp13 = vala_source_file_new (self->priv->context, source, FALSE)));
+					(_tmp13 == NULL ? NULL : (_tmp13 = (g_object_unref (_tmp13), NULL)));
 				} else {
-					char* __temp17;
-					__temp17 = NULL;
-					vala_report_error (NULL, (__temp17 = g_strdup_printf ("%s not found", source)));
-					(__temp17 = (g_free (__temp17), NULL));
+					char* _tmp14;
+					_tmp14 = NULL;
+					vala_report_error (NULL, (_tmp14 = g_strdup_printf ("%s not found", source)));
+					(_tmp14 = (g_free (_tmp14), NULL));
 				}
 				(source = (g_free (source), NULL));
 			}
 		}
 	}
-	__temp19 = NULL;
-	vala_vapi_gen_sources = (__temp19 = NULL, (vala_vapi_gen_sources = (g_strfreev (vala_vapi_gen_sources), NULL)), __temp19);
+	_tmp16 = NULL;
+	vala_vapi_gen_sources = (_tmp16 = NULL, (vala_vapi_gen_sources = (_vala_array_free (vala_vapi_gen_sources, -1, ((GDestroyNotify) g_free)), NULL)), _tmp16);
 	if (vala_report_get_errors () > 0) {
 		return vala_vapi_gen_quit (self);
 	}
-	parser = g_object_new (VALA_TYPE_PARSER, NULL);
+	parser = vala_parser_new ();
 	vala_parser_parse (parser, self->priv->context);
 	if (vala_report_get_errors () > 0) {
-		gint __temp21;
-		return (__temp21 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), __temp21);
+		gint _tmp18;
+		return (_tmp18 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), _tmp18);
 	}
-	gidlparser = g_object_new (VALA_TYPE_GIDL_PARSER, NULL);
-	vala_gidl_parser_parse (gidlparser, self->priv->context);
-	if (vala_report_get_errors () > 0) {
-		gint __temp22;
-		return (__temp22 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), __temp22);
-	}
-	attributeprocessor = g_object_new (VALA_TYPE_ATTRIBUTE_PROCESSOR, NULL);
+	attributeprocessor = vala_attribute_processor_new ();
 	vala_attribute_processor_process (attributeprocessor, self->priv->context);
 	if (vala_report_get_errors () > 0) {
-		gint __temp23;
-		return (__temp23 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), __temp23);
+		gint _tmp19;
+		return (_tmp19 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), _tmp19);
 	}
-	resolver = g_object_new (VALA_TYPE_SYMBOL_RESOLVER, NULL);
+	gidlparser = vala_gidl_parser_new ();
+	vala_gidl_parser_parse (gidlparser, self->priv->context);
+	if (vala_report_get_errors () > 0) {
+		gint _tmp20;
+		return (_tmp20 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), _tmp20);
+	}
+	resolver = vala_symbol_resolver_new ();
 	vala_symbol_resolver_resolve (resolver, self->priv->context);
 	if (vala_report_get_errors () > 0) {
-		gint __temp24;
-		return (__temp24 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (resolver == NULL ? NULL : (resolver = (g_object_unref (resolver), NULL))), __temp24);
+		gint _tmp21;
+		return (_tmp21 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), (resolver == NULL ? NULL : (resolver = (g_object_unref (resolver), NULL))), _tmp21);
 	}
 	if (vala_vapi_gen_library != NULL) {
 		ValaInterfaceWriter* interface_writer;
-		char* __temp25;
-		char* __temp26;
-		interface_writer = g_object_new (VALA_TYPE_INTERFACE_WRITER, NULL);
-		__temp25 = NULL;
-		vala_interface_writer_write_file (interface_writer, self->priv->context, (__temp25 = g_strdup_printf ("%s.vala", vala_vapi_gen_library)));
-		(__temp25 = (g_free (__temp25), NULL));
-		__temp26 = NULL;
-		vala_vapi_gen_library = (__temp26 = NULL, (vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL)), __temp26);
+		char* _tmp22;
+		char* _tmp23;
+		interface_writer = vala_interface_writer_new ();
+		_tmp22 = NULL;
+		vala_interface_writer_write_file (interface_writer, self->priv->context, (_tmp22 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library)));
+		(_tmp22 = (g_free (_tmp22), NULL));
+		_tmp23 = NULL;
+		vala_vapi_gen_library = (_tmp23 = NULL, (vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL)), _tmp23);
 		(interface_writer == NULL ? NULL : (interface_writer = (g_object_unref (interface_writer), NULL)));
 	}
-	return (__temp27 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (resolver == NULL ? NULL : (resolver = (g_object_unref (resolver), NULL))), __temp27);
+	return (_tmp24 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), (resolver == NULL ? NULL : (resolver = (g_object_unref (resolver), NULL))), _tmp24);
 	(parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL)));
-	(gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL)));
 	(attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL)));
+	(gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL)));
 	(resolver == NULL ? NULL : (resolver = (g_object_unref (resolver), NULL)));
 }
 
 
-static gint vala_vapi_gen_main (int args_length1, char** args)
-{
+static gint vala_vapi_gen_main (int args_length1, char** args) {
 	GError * inner_error;
 	ValaVAPIGen* vapigen;
-	gint __temp30;
+	gint _tmp3;
 	inner_error = NULL;
 	{
 		GOptionContext* opt_context;
@@ -313,52 +405,54 @@ static gint vala_vapi_gen_main (int args_length1, char** args)
 	}
 	__finally2:
 	;
+	if (vala_vapi_gen_version) {
+		fprintf (stdout, "Vala API Generator %s\n", PACKAGE_VERSION);
+		return 0;
+	}
 	if (vala_vapi_gen_sources == NULL) {
 		fprintf (stderr, "No source file specified.\n");
 		return 1;
 	}
-	vapigen = g_object_new (VALA_TYPE_VAPI_GEN, NULL);
-	return (__temp30 = vala_vapi_gen_run (vapigen), (vapigen == NULL ? NULL : (vapigen = (g_object_unref (vapigen), NULL))), __temp30);
+	vapigen = vala_vapi_gen_new ();
+	return (_tmp3 = vala_vapi_gen_run (vapigen), (vapigen == NULL ? NULL : (vapigen = (g_object_unref (vapigen), NULL))), _tmp3);
 	(vapigen == NULL ? NULL : (vapigen = (g_object_unref (vapigen), NULL)));
 }
 
 
-int main (int argc, char ** argv)
-{
+int main (int argc, char ** argv) {
 	g_type_init ();
 	return vala_vapi_gen_main (argc, argv);
 }
 
 
-static void vala_vapi_gen_class_init (ValaVAPIGenClass * klass)
-{
+static ValaVAPIGen* vala_vapi_gen_new (void) {
+	ValaVAPIGen * self;
+	self = g_object_newv (VALA_TYPE_VAPI_GEN, 0, NULL);
+	return self;
+}
+
+
+static void vala_vapi_gen_class_init (ValaVAPIGenClass * klass) {
 	vala_vapi_gen_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaVAPIGenPrivate));
 	G_OBJECT_CLASS (klass)->dispose = vala_vapi_gen_dispose;
 }
 
 
-static void vala_vapi_gen_init (ValaVAPIGen * self)
-{
+static void vala_vapi_gen_init (ValaVAPIGen * self) {
 	self->priv = VALA_VAPI_GEN_GET_PRIVATE (self);
 }
 
 
-static void vala_vapi_gen_dispose (GObject * obj)
-{
+static void vala_vapi_gen_dispose (GObject * obj) {
 	ValaVAPIGen * self;
-	ValaVAPIGenClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_VAPI_GEN (obj);
 	(self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL)));
-	klass = VALA_VAPI_GEN_CLASS (g_type_class_peek (VALA_TYPE_VAPI_GEN));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_vapi_gen_parent_class)->dispose (obj);
 }
 
 
-GType vala_vapi_gen_get_type (void)
-{
+static GType vala_vapi_gen_get_type (void) {
 	static GType vala_vapi_gen_type_id = 0;
 	if (G_UNLIKELY (vala_vapi_gen_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPIGenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_gen_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPIGen), 0, (GInstanceInitFunc) vala_vapi_gen_init };
@@ -368,5 +462,22 @@ GType vala_vapi_gen_get_type (void)
 }
 
 
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	if (array != NULL && destroy_func != NULL) {
+		int i;
+		if (array_length >= 0)
+		for (i = 0; i < array_length; i = i + 1) {
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
+		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
+	}
+	g_free (array);
+}
+
+
 
 
